%define current_version 3.18.1.3

%define rcver %{nil}

Name: criu
Version: %{current_version}
Release:        1%{?dist}
Provides: crtools = %{version}-%{release}
Obsoletes: crtools <= 1.0-2
Summary: Tool for Checkpoint/Restore in User-space
Group: System Environment/Base
License: GPLv2
URL: http://criu.org/
Source: %{name}-%{version}.tar.bz2

BuildRequires: protobuf-devel protobuf-c-devel libnl3-devel libcap-devel asciidoc xmlto python2-devel libnet-devel 

Requires: spfs
Requires: nftables
Requires: phaul >= 0.1.71
Requires: ipset
Requires: vzpkgenv414x64

# user-space and kernel changes are only available for x86_64 and ARM
# code is very architecture specific
# once imported in RCS it needs a bug openend explaining the ExclusiveArch
# https://bugzilla.redhat.com/show_bug.cgi?id=902875
ExclusiveArch: x86_64 %{arm}

%description
criu is the user-space part of Checkpoint/Restore in User-space
(CRIU), a project to implement checkpoint/restore functionality for
Linux in user-space.

%package devel
Summary: Header files and libraries for %{name}
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
This package contains header files and libraries for %{name}.

%package -n python-%{name}
Summary: Python bindings for %{name}
Group: Development/Languages
Requires: %{name} = %{version}-%{release}
Requires: protobuf-python
Requires: python-ipaddress
Requires: python-ipaddr
Requires: python-six

%description -n python-%{name}
python-%{name} contains Python bindings for %{name}.

%package -n crit
Summary: CRIU image tool
Requires: python-%{name} = %{version}-%{release}

%description -n crit
crit is a tool designed to decode CRIU binary dump files and show
their content in human-readable form.

%package -n libcompel
Summary: A library to execute arbitrary code in a context of a foreign process
Group: System Environment/Base
Conflicts: %{name} < 3.0.0.11-2

%description -n libcompel
A library to execute arbitrary code in a context of a foreign process.

%package -n libcompel-devel
Summary: Header files and libraries for libcompel
Group: Development/Libraries
Requires: libcompel = %{version}-%{release}
Conflicts: %{name} < 3.0.0.11-2
Conflicts: %{name}-devel < 3.0.0.11-2

%description -n libcompel-devel
The libcompel-devel package contains libraries, scripts and header files for
developing applications that use libcompel.

%prep
%setup -q

%build
# %{?_smp_mflags} does not work
# -fstack-protector breaks build
CFLAGS+=`echo %{optflags} | sed -e 's,-fstack-protector\S*,,g'` make V=1 WERROR=0 PREFIX=%{_prefix} CRIU_VERSION=%{current_version} PYTHON=python2
make docs V=1


%install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d
make install DESTDIR=$RPM_BUILD_ROOT PREFIX=%{_prefix} LIBDIR=%{_libdir} LIBEXECDIR=%{_libexecdir} LOGROTATEDIR=%{_sysconfdir}/logrotate.d CRIU_VERSION=%{current_version} PYTHON=python2

# upstream renamed to binary to criu
ln -s %{_sbindir}/criu $RPM_BUILD_ROOT%{_sbindir}/crtools

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%post -n libcompel -p /sbin/ldconfig
%postun -n libcompel -p /sbin/ldconfig

%files
%{_sbindir}/%{name}
%{_sbindir}/crtools
%{_libdir}/libcriu.so.*
%{_libexecdir}/criu
%doc %{_mandir}/man8/criu.8*
%doc %{_mandir}/man1/crit.1*
%doc %{_mandir}/man1/amdgpu_plugin.1*
%doc README.md COPYING

%files devel
%{_includedir}/criu
%{_libdir}/libcriu.so
%{_libdir}/libcriu.a
%{_libdir}/pkgconfig/criu.pc

%files -n python-%{name}
%{python2_sitelib}/pycriu/*
%{python2_sitelib}/*egg-info

%files -n crit
%{_bindir}/crit

%files -n libcompel
%{_bindir}/compel
%{_libdir}/libcompel.so.*
%{_mandir}/man1/compel*

%files -n libcompel-devel
%{_libdir}/libcompel.a
%{_libdir}/libcompel.so
%{_includedir}/compel
%{_libexecdir}/compel


%changelog

* Mon Jun 19 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.24
 - spfs: do not umount original mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147180)

* Fri Jun 09 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.22
 - spfs: do mount request from mount namespace of nfs mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147276)
 - mount-v2: bind dev proc and sysfs for spfs into restored mount namespace
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-147276)

* Thu Jun 08 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.21
 - mount: skip source check for autofs mounts in bindmount search (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-148081)

* Wed Jun 07 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.20
 - Revert "soccr: do not disable tcp repair when sending unsent data" (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-147346 #PSBM-148050)

* Wed Jun 07 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.19
 - sk-unix: ignore closed or non-empty in-flight sockets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147983)

* Tue Jun 06 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.18
 - soccr: do not disable tcp repair when sending unsent data (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147346)

* Tue Jun 06 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.17
 - filesystems: do binfmt_misc_restore only once (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147930)

* Tue Jun 06 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.16
 - mount-v2: copy flags to wide mount helpers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-148010)
 - overlayfs: fix error handling in __overlayfs_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Wed May 31 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.15
 - zdtm: add overlayfs_nestedns test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - overlayfs: do mount in mntns of lower/upper/workdir mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - mount-v2: add remove_plain_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - mount-v2: export bind_plain_to_other_mntns helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - mount-v2: export create_plain_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - overlayfs: replace ret with exit_code in __overlayfs_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - overlayfs: remove cwd recovery in overlayfs_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)
 - overlayfs: call overlayfs_mount in child process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147254)

* Fri May 26 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.14
 - vz7: systemd-autofs-restart.sh: fix error condition check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147268)

* Thu May 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.13
 - zdtm: add mount_complex_sharing02 test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount: add wide mounts for sharing groups where required (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount: search covering mounts for sharing groups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount: search covering mounts for each superblock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount: introduce covering mounts functionality (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount-v2: introduce custom detect_is_dir (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount: introduce helper mount types (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)
 - mount-v2: rework can_mount_now_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147120)

* Thu Apr 27 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.12
 - zdtm: add scm10 test for scm sent unix sk with closed sender (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: resolve fake queuers vs scm fds in unix sockets fallacy (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: order unixsk sent to other unixsk after it (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)

* Thu Apr 27 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.11
 - jenkins/zdtm: dont run tests using zdtmtst cgroup concurrently (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-147000)
 - cgroupd: unblock SIGTERM as it is needed to stop cgroupd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147000)
 - jenkins/zdtm: use --mntns-compat-mode option without --no- (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-147000)
 - Revert python modules changes. (Artem Vasiliev
<artem.vasiliev@virtuozzo.com>)

* Wed Apr 26 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.10
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz: fix multiple build problems related to python (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)

* Wed Apr 26 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.9
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz: fix multiple build problems related to python (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.8
 - Revert "crit: fix compatibility with Python 3.12" (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)
 - Fix typo (Artem Vasiliev <artem.vasiliev@virtuozzo.com>)
 - Add amdgpu man (Artem Vasiliev <artem.vasiliev@virtuozzo.com>)
 - Revert SPEC to use python2 (artem.vasiliev <artem.vasiliev@virtuozzo.com>)
 - Set proper version for pip PSBM-144416 (artem.vasiliev
<artem.vasiliev@virtuozzo.com>)
 - Adding python-pip for PSBM-144416 (Artem Vasiliev
<artem.vasiliev@virtuozzo.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.6
 - Revert "crit: fix compatibility with Python 3.12" (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)
 - Revert SPEC to use python2 (artem.vasiliev <artem.vasiliev@virtuozzo.com>)
 - Set proper version for pip PSBM-144416 (artem.vasiliev
<artem.vasiliev@virtuozzo.com>)
 - Adding python-pip for PSBM-144416 (Artem Vasiliev
<artem.vasiliev@virtuozzo.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.5
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)
 - Set proper version for pip PSBM-144416 (artem.vasiliev
<artem.vasiliev@virtuozzo.com>)
 - Adding python-pip for PSBM-144416 (Artem Vasiliev
<artem.vasiliev@virtuozzo.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.4
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)
 - Adding python-pip for PSBM-144416 (Artem Vasiliev
<artem.vasiliev@virtuozzo.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.3
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.2
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)

* Tue Apr 25 2023 VZ Auto Builder <builder@virtuozzo.com> 3.18.0.1
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723 #PSBM-144416)
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - kerndat: check availability of mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: fallback to mount(MS_SET_GROUP) if have no openat2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount: define MS_NOSYMFOLLOW for vz7 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: skip openvswitch tests if there is no ovs-dpctl tool (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: mark mnt_root_ext noauto (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: use --nftables-mode=ipt for socket-tcp-* tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: fix netns_lock_iptables test to cleanup iptables before restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-inet: backward compatibility for vz_pktinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398 #PSBM-144416)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix/mount-v2: prepare unix sockets just after their mount is mounted
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: always save to fdstore the bind file of unix socket (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: make fstatat not resolve symlinks and automounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: switch mntns to actual restored mntns for unix socket creation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834 #PSBM-144416)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663 #PSBM-144416)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)
 - vz/sockets: fallback c/r bufer size lock to _vz (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - mount-v2: don't resolve symlink when checking directory bindmounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - cgroup: at restore use fallback values for cpuset.cpus/mems (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-127807 #PSBM-144416)
 - zdtm: add bridge and fdb tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106442 #PSBM-144416)
 - mount: add some more debug messages to umount_overmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: move parse_fdinfo_pid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)
 - net: move ovs genlink detection (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add file_fown_reuse to check dead owner pid reused (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - restorer: make setting tid due to CLONE_CHILD_SETTID not override multilevel
pids (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)
 - infect: print stack for D state process (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122979)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790 #PSBM-144416)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844 #PSBM-144416)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440 #PSBM-144416)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843 #PSBM-144416)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - util: add __get_relative_path version with const arguments and return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106869 #PSBM-144416)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-144416)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871 #PSBM-144416)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161 #PSBM-144416)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - compel: add mount_setattr syscall (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284 #PSBM-144416)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961 #PSBM-144416)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - mount-v2: allow custom fd and flags in __do_bind_mount_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357 #PSBM-144416)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-144416)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123 #PSBM-144416)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: adjust pipe count at pipe04 test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408 #PSBM-144416)
 - mount: prohibit external mounts in non-root mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-144416)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-144416)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022 #PSBM-144416)
 - mount: fix absolute path handling in make_parent_dirs_if_need (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830 #PSBM-144416)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800 #PSBM-144416)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943 #PSBM-144416)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - zdtm: make cgroup04 also check cpuset special props (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - proc_parse: use statfs instead of fstatfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - zdtm: fix cgroup02 test (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095 #PSBM-144416)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335 #PSBM-144416)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583 #PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - zdtm/netns-ipset: run only in ve flavour (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083 #PSBM-144416)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)
 - nft: run nft binary from rpm414x64 chroot (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-125002)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958 #PSBM-144416)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: call iptables_restore in call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531 #PSBM-144416)
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593 #PSBM-144416)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769 #PSBM-144416)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778 #PSBM-144416)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976 #PSBM-144416)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924 #PSBM-144416)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - sk-queue: use flags in dump_sk_queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>) (#PSBM-144416)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>) (#PSBM-144416)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289 #PSBM-144416)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423 #PSBM-85265 #PSBM-144416)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-94405 #PSBM-94706 #PSBM-144416)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616 #PSBM-70929)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-144416)
 - mount/dump: check opts.ve for binfmt_misc earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320 #PSBM-144416)
 - autofs: rename parse_options to parse_autofs_options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889 #PSBM-144416)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775 #PSBM-144416)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - spfs: suppress compilation warnings by roughly approximating path lengths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466 #PSBM-144416)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - spfs: move SPFS manager logs to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199 #PSBM-144416)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-108126 #PSBM-144416)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: nfs: build -- Add install of nfs-ports-allow.sh (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-144416)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-144416)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289 #PSBM-144416)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)
 - cgroup: also restore special props for pre-created directories (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup/device: update device major/minor in device.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: resolve new device numbers for each device (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices: add lookup_device helper function (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - devices/restore: prepare devices_list with all devices from images (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - dump: save external device map to images (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - images: add device entry (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: make read_cgroup_prop detect overflow (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - external.h: explicitly include stdbool.h and common/list.h (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - cgroup: added command line flag to force creation of cgroup namespace
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: add a simple test for --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949 #PSBM-144416)
 - zdtm: add simple ve test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - jenkins: run ve flavor tests without extra pidns in a separate job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ve flavor (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095 #PSBM-144416)
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407 #PSBM-144416)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - build: Switch to v3.18 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144416)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cgroup/restore: split prepare_task_cgroup code into two separate functions
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431 #PSBM-144416)
 - criu: Version 3.18 (Silver Sandpiper) (Andrei Vagin <avagin@google.com>)
 - cr-check: remove excess kerndat_has_nspid from check_ns_pid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: fix timestamp logging when tv_sec>=100 (Michal Clapinski
<mclapinski@google.com>)
 - proc_parse: fix while condition in parse_pid_status (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - netlink: fix netlink fd flags dump/restore failed (hdzhoujie
<zhoujie133@huawei.com>)
 - zdtm: modify rseq01 to include a thread (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: properly apply rseq fixup for all threads (Michal Clapinski
<mclapinski@google.com>)
 - cr-dump: move rseq functions before dump_task_thread (Michal Clapinski
<mclapinski@google.com>)
 - dump: extend parasite_thread_ctl lifetime to dump_task_thread (Michal
Clapinski <mclapinski@google.com>)
 - zdtm: don't ignore rseq_cs mismatch in rseq01 test (Michal Clapinski
<mclapinski@google.com>)
 - ci: cancel preceding workflows run (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: simplify error handling in unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: remove bogus xfree from unix_resolve_name_old (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: fix cwd path freeing (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - crit: fix compatibility with Python 3.12 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: improve id intersection detection in prepare_pstree_for_shell_job
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add MNTNS_ZDTM macro to fix initialization (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow bindmounts for external fuse mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci/archlinux: initialize machine ID (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Optimized shell code with <'s (instead of cat + |) (KKrypt
<sankalpacharya1211@gmail.com>)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup-v2: make new field cg_set optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: make new field is_threaded optional (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - net: fail restore if nftables isn't supported but image is present (Alexander
Mikhalitsyn <aleksandr.mikhalitsyn@canonical.com>)
 - make: disable '-Wdangling-pointer' warning with gcc 12 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86/xsave: Set only used XFEATURE_* in xstate_bv (Dmitry Safonov
<dima@arista.com>)
 - CONTRIBUTING.md: document make lint / indent (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - net: use get_legacy_iptables_bin also on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: add long command-line to coredump test (Adrian Reber
<areber@redhat.com>)
 - coredump: report missing files without a backtrace (Adrian Reber
<areber@redhat.com>)
 - coredump: handle long command-lines (Adrian Reber <areber@redhat.com>)
 - lib/py: reduce code duplication (Kouame Behouba Manasse <behouba@gmail.com>)
 - ci/podman-test: drop crun installation script (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: disable c/r of cgroups with podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/transition/epoll: don't rely on errno in case of zero return (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mailmap: update my email (Alexander Mikhalitsyn
<aleksandr.mikhalitsyn@canonical.com>)
 - dump: improve error printing and readability of task_comm_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: add test for crit info (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - crit: fix empty string comparison (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - lint: exclude tags file from codespell (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Add documentation for --ghost-fiemap (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: Add tests for IP_PKTINFO and IP_FREEBIND sock options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: support IP_PKTINFO and IPV6_RECVPKTINFO options (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-inet: save IP_FREEBIND option for SOCK_RAW sockets also (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check if setsockopt IPV6_FREEBIND is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_parse: Handle btrfs files when map_files is not accessible (Younes
Manton <ymanton@ca.ibm.com>)
 - ci: Add maps00 test in unprivileged mode in user namespace (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Close fd when VMA is copied from /proc/$pid/mem (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: pr_err -> pr_perror (Younes Manton <ymanton@ca.ibm.com>)
 - compel/mips: fix parasite with GCC 12 (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: use IndentGotoLabels to get rid of goto label indentation
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - namespaces: cleanup switch_mnt_ns and restore_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: simplify code around mount_cr_time_mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remap: refactor goto jumping to a while loop (Michał Mirosław
<emmir@google.com>)
 - remap: Fix typo (Michał Mirosław <emmir@google.com>)
 - ci/lint: make push action have at least too commits depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): Add info about unprivileged mode limitations (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Don't bail out on is_memfd() VMAs (Younes Manton
<ymanton@ca.ibm.com>)
 - shmem: Fall back to /proc/$pid/mem if no map_files (Younes Manton
<ymanton@ca.ibm.com>)
 - proc_parse: Set VMA_AREA_REGULAR where needed (Younes Manton
<ymanton@ca.ibm.com>)
 - string: define wrapers __setproctitle and __setproctitle_init to hide bsd
headers (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - string: use our own __strlcpy and __strlcat to remove bsd headers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - log: remove all uses of %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - lint: prohibit to use %m specifier in pr_* functions (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: switch from lgtm to codeql (Adrian Reber <areber@redhat.com>)
 - restorer: add logging on prctl PR_SET_MM_MAP failure (Michal Clapinski
<mclapinski@google.com>)
 - zdtm: add mntns_compare check to mount_complex_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo topology compare to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mountinfo parsing to test lib (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy xmalloc.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/lib: copy list.h (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - clang-format: rework make indent to check specific commits (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts/ci: use Fedora 37 for vagrant based tests (Adrian Reber
<areber@redhat.com>)
 - tty: fix codding-style around for_each_bit call (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: add for_each_bit macros to ForEachMacros (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: fix a frankenstein auto-created by clang-format (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - asm: fix for_each_bit macro (Michal Clapinski <mclapinski@google.com>)
 - crtools: fix help message alignment for --network-lock (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: fix 'zdtm.py list' command (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cgroups: ignore EOPNOTSUPP on setting memory.kmem.limit_in_byte (Andrei Vagin
<avagin@google.com>)
 - test/javaTests: update org.testng:testng (Maven) (Andrei Vagin
<avagin@gmail.com>)
 - sockets: tiny style fix (Andrei Vagin <avagin@gmail.com>)
 - non-root: Don't dump socket option SO_MARK if 0 (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: Rework socket bufs for unprivileged mode (Younes Manton
<ymanton@ca.ibm.com>)
 - Fix typo in comment (Shubham Verma <shubhamv.sv@gmail.com>)
 - zdtm: add two tests for highly sparse ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - files-reg.c: fiemap algorithm for ghost file (Liang-Chun Chen
<featherclc@gmail.com>)
 - ci: fix make indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci/alpine: remove symlink for /usr/bin/python (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci/lint: install ShellCheck with dnf (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix warnings from -Wstrict-prototypes in clang 16.0.0 (Drew Wock
<ajwock@gmail.com>)
 - amdgpu: define __nmk_dir if missing (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Remove execute bit from source file (Mathias Gibbens <mathias@calenhad.com>)
 - cgroup: Remove redundant code that handles zombie tasks (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - kerndat: Mark memfd_create(MFD_HUGETLB) unavailable when ENOSYS is returned
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ci: move cgroup unmounting to run-ci-tests.sh (Adrian Reber
<areber@redhat.com>)
 - ci: Do not fail if latest epel repository definition is already installed
(Adrian Reber <areber@redhat.com>)
 - ci: Make cpuset move to cgroup-v2 hierarchy (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Check threads are restored into correct threaded controllers (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Restore threads in a process into correct threaded controllers
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup-v2: Dump cgroup controllers of every threads in a process (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - zdtm: Add test to check global properties of cgroup-v2 are preserved (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add write_value/read_value helpers into zdtm library (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cgroup-v2: Checkpoint and restore some global properties (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - Switch aarch64 builds to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ipc_sysctl: Prioritize restoring IPC variables using non usernsd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - non-root: add non-root test case to cirrus runs (Adrian Reber
<areber@redhat.com>)
 - non-root: extend zdtm.py to be able to run tests as non-root (Adrian Reber
<areber@redhat.com>)
 - Documentation: add details about --unprivileged (Adrian Reber
<areber@redhat.com>)
 - non-root: Introduce unprivileged mode to kerndat (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: enable non-root checkpoint/restore (Younes Manton
<ymanton@ca.ibm.com>)
 - non-root: add functions to work with capabilities (Adrian Reber
<areber@redhat.com>)
 - non-root: add infrastructure to run as non-root (Adrian Reber
<areber@redhat.com>)
 - ci: enable EPEL for CentOS 7 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix ppc64le parasite stack layout (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add test to check parasite stack setup (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Fix infect test to not override failures (Younes Manton
<ymanton@ca.ibm.com>)
 - compel: Add APIs to facilitate testing (Younes Manton <ymanton@ca.ibm.com>)
 - seize: do not overwrite exit code from failpath (Liu Hua
<weldonliu@tencent.com>)
 - test/others/crit/test.sh: use bash array (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/protobuf-gen.sh: fix (not ignore) shellcheck warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci: rm shellcheck disable annotations (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/run-ci-tests: use bash arrays (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Fix, not ignore, shellcheck SC1091 warnings (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/asan.sh: fix, not ignore, shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - scripts/ci/apt-install: fix (not ignore) shellcheck warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci/gha/lint: install a recent shellcheck (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - files-reg: skip failed mount lookup for shell-job's tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu-ns: capture controlling tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add definition for FSOPEN_CLOEXEC (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Clean up and improve Java testing (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Add Dockerfile for openj9 on Ubuntu (Younes Manton <ymanton@ca.ibm.com>)
 - ci: Rename openj9 Dockerfiles to hotspot (Younes Manton <ymanton@ca.ibm.com>)
 - gitignore: Ignore top-evel build dir only (Younes Manton
<ymanton@ca.ibm.com>)
 - test/unix: check C/R of unix listen queues (Andrei Vagin <avagin@gmail.com>)
 - zdtm: return 1 from pr_err, pr_perror, fail (Andrei Vagin <avagin@gmail.com>)
 - criu: fail migration if data was sent to an in-flight socket (Michal
Clapinski <mclapinski@google.com>)
 - breakpoint: enable breakpoints by default on amd64 and arm64 (fu.lin
<fulin10@huawei.com>)
 - breakpoint: implement hw breakpoint for arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: switch breakpoint functions to non-inline at arm64 platform (fu.lin
<fulin10@huawei.com>)
 - compel: clear a breakpoint right after it's been triggered (Andrei Vagin
<avagin@gmail.com>)
 - compel: set TRACESYSGOOD to distinguish breakpoints from syscalls (Andrei
Vagin <avagin@gmail.com>)
 - ci/cirrus: centos 8 job nits (Kir Kolyshkin <kolyshkin@gmail.com>)
 - ci/cirrus: add CentOS Stream 9 (Kir Kolyshkin <kolyshkin@gmail.com>)
 - docker-test: handle race condition error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Add Alexander Mikhalitsyn to maintainers (Andrei Vagin <avagin@gmail.com>)
 - cr-restore: rseq: use glibc-specific way to unregister only as fallback
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cr-restore: rseq: dynamically handle *libc with rseq (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: optimize check for apparmor stacking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-check: fix check for apparmor stacking (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd installed from package (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Revert "ci: Switch to non overlaysfs tests" (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: fix conflicting headers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: unset XDG_RUNTIME_DIR when invoking podman (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - MAINTAINERS: Add Radostin (myself) to maintainers (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add two tests for large ghost sparse file (Liang-Chun Chen
<featherclc@gmail.com>)
 - unlink_largefile.desc: remove crfail, since criu now can support
unlink_largefile test (Liang-Chun Chen <featherclc@gmail.com>)
 - files-reg.c: modify the check of ghost_limit to support large sparse files
(Liang-Chun Chen <featherclc@gmail.com>)
 - zdtm/mnt_root_ext: don't allow propagation from test mntns to criu mntns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: make root mount private in criu mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vdso-compat: Increase the reserved buffer for compat vdso (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Remove permission part check for skipping vsyscall vma (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - x86/compel/fault-inject: fixup mxcsr for PTRACE_SETFPREGS (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fix headers conflict on Mariner GNU/Linux (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Add --skip-file-rwx-check opt test (Younes Manton <ymanton@ca.ibm.com>)
 - config/files-reg: Add opt to skip file r/w/x check on restore (Younes Manton
<ymanton@ca.ibm.com>)
 - zdtm: add tests for SIGTSTP (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - infect: add SIGTSTP support (Yuriy Vasiliev <yuriy.vasiliev@openvz.org>)
 - config: fail on --track-mem option if dirty tracking is not available (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - hugetlb: don't dump anonymous private hugetlb mapping using memfd approach
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - amdgpu: Add gitignore (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - Fix the check for mnt namespace in criu-ns (Ashutosh Mehra
<asmehra@redhat.com>)
 - github: use git-clang-format instead of make indent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: skip zdtm/static/shm-hugetlb when hugetlb is not supported (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: skip new hugetlb maps09/maps10 tests for pre-dump" (Bui Quang
Minh <minhquangbui99@gmail.com>)
 - mem: Skip pre-dumping on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - criu: Version 3.17.1 (Adrian Reber <areber@redhat.com>)
 - ci: Fix code indent (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: add mnt_root_ext test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - util/mount-v2: fix resolve_mountpoint() to always return freeable pointer
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: test multiple ext bindmounts with no common root and same master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: workaround for multiple external bindmounts with no common root
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: split out restore_one_sharing helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - amdgpu: Set PLUGINDIR to /usr/lib/criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - amdgpu/Makefile: Fix include path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test the read mode of pre-dump (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: refactoring analyze_iov and fill_userbuf (Andrei Vagin
<avagin@gmail.com>)
 - pre-dump: call vmsplice with SPLICE_F_GIFT (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: adjust a buffer to a pipe size (Andrei Vagin <avagin@gmail.com>)
 - page-xfer: use negative values for error codes (Andrei Vagin
<avagin@gmail.com>)
 - page-pipe: fix limiting a pipe size (Andrei Vagin <avagin@gmail.com>)
 - crit: Use same version as criu (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Fix unsafe repository error (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu: Version 3.17 (Adrian Reber <areber@redhat.com>)
 - ci: skip new hugetlb maps09/maps10 tests for pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: handle the case when hugetlb isn't supported (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: workaround race between sit module loading and bridge test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - ci: print kernel modules list (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: install criu in /usr (Adrian Reber <areber@redhat.com>)
 - readme: Add badge links to workflows (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - proc_parse: Fix parsing bpf map_extra (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - bpf: update deprecated API (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - ci: print mountinfo instead of mount cmd output (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: criu-fault: skip inotify_irmap fault-injection on btrfs (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - scripts/ci: fix ZDTM_OPTS variable passing (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: temporary disable rseq02 test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add rseq02 transition test with NO_RESTART CS flag (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: handle rseq/rseq_cs flags properly (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "test: disable rseq also on Archlinux" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add transition/rseq01 test for amd64 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-dump: fixup thread IP when inside rseq cs (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add helpers to get/set instruction pointer (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm/static/rseq00: fix rseq test when linking with a fresh Glibc (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - pie/restorer: unregister (g)libc rseq before memory restoration (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - include: add thread_pointer.h from Glibc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - ci: add Fedora Rawhide based test on Cirrus (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - Revert "ci: disable glibc rseq support" (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add basic static/rseq00 test for rseq C/R (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: fail dump if rseq is used but host doesn't support get_rseq_conf
feature (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - rseq: initial support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - cr-check: Add ptrace rseq conf dump feature (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - util: move fork_and_ptrace_attach helper from cr-check (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - kerndat: check for rseq syscall support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - compel: add rseq syscall into compel std plugin syscall tables (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - cgroup: test for --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix --manage-cgroups=ignore (Adrian Reber <areber@redhat.com>)
 - cgroup: fix "unified" path (Adrian Reber <areber@redhat.com>)
 - ci: add codespell to lint target (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix remaining codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Fix some codespell warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Add .codespellrc (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/exhaustive/unix.py: rename a var (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Rename useable to usable (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: separate \t (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/files.c: some renames (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/javaTests: rename ser to s (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Nit: rename sie to se (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Typo: mmaped -> mmapped (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static: s/NODEL/NO_DEL/ (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm/static/inotify_system.c: s/inot/infd/ (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm/static: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/pie/restorer.c: use param not parm (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/arch/s390/include/asm/restorer.h: fix comments (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - ci: Switch to non overlaysfs tests (Adrian Reber <areber@redhat.com>)
 - criu: generate unique socket names (Andrei Vagin <avagin@google.com>)
 - mount: fix -Wunused-but-set-variable for Clang 15 (Fangrui Song
<maskray@google.com>)
 - style: delete some redundant code (jiang wei <jwcesign@gmail.com>)
 - apparmor: Fix -Wfortify-source for Clang (Fangrui Song <maskray@google.com>)
 - criu-ns: add a helper to hold a pid namespace (Andrei Vagin
<avagin@google.com>)
 - scripts/ci: mount test cgroups once (Andrei Vagin <avagin@google.com>)
 - zdtm: use unique holder for cgroups (Andrei Vagin <avagin@google.com>)
 - mount: make error messages differ in different places (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: make mount engine fallback messages loglevel debug (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable pty-console test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test/jenkins: test for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: make others/mnt_ext_dev also run for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/mount-v2: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_sharing test for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run tests for old mount engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: enable mounts compat mode on restore with --mntns-compat-mode option
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export global variables for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export several functions for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: export common defines for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove double ns_id declaration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: export parent dirs helpers for mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - config/rpc: add new option --mntns-compat-mode for old mount engine (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - crtools: move check_options after kerndat_init and log_init (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add resolve_mountpoint helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: check whether the openat2 syscall is supported (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - compel: add open_tree syscall (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: Check for MOVE_MOUNT_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach clean_one_remap to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: teach create_ghost to work with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: split create_ghost_dentry out of create_ghost (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - path: simplify mnt_get_sibling_path via get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: use ns_mountpoint in mnt_is_overmounted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - autofs: use ns_mountpoint in autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: move root yard tree merge as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: prepare is_overmounted as early as possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper mnt_get_external_bind_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not override master_id to -1 for root binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put external slavery mounts to separate mnt_ext_slave list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add can_receive_master_from_root helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount/restore: leave ns_mountpoint NULL for aux binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root_ro test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mntns_pivot_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_root_bind helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add mnt_ext_collision test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restrict mp-external mount map to init container mntns only (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: rework skipping external mounts in dump_one_mountpoint (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: split mnt_is_external(_bind) and can_receive_master_from_external
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_bind_pick helper to pick the desired bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - unittest: add some tests for get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: skip fstype and source checks for external mounts in mounts_sb_equal
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do not detect non-fsroot mounts as device-external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add mntinfo_add_list_before helper for adding to mntinfo list
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: fix __u64 print format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: fix e_str leak in unix_sk_id_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu/plugin: Add support for criu image streamer (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Store BO contents directly to file (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add whitepaper document (Felix Kuehling
<Felix.Kuehling@amd.com>)
 - criu/plugin: Dockerfile for amdgpu_plugin (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Fix for FDs not allowed to mmap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement sDMA based buffer access (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Restore libhsakmt shared memory files (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Read and write BO contents in parallel (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add unit tests for GPU remapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add parameters to override mapping (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Remap GPUs on checkpoint restore (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Implement system topology parsing (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Adding check for kernel IOCTL version (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Support AMD ROCm Checkpoint Restore with KFD (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Initialize AMD KFD header (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Skip plugin vmas during premap (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Add dedicated flag for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - criu/files: Add function to return unused FD by pid (David Yat Sin
<david.yatsin@amd.com>)
 - criu/plugin: Do not reopen vma fd for plugins (David Yat Sin
<david.yatsin@amd.com>)
 - files: fix inh leak in inherit_fd_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix e_str leak in veth_pair_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config: fix ns leak in parse_join_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: run criu-config tests (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: drop redundant config_inotify_irmap test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: add --criu-config option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: use long form cli options (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: sort import lines (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: refactor main (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - sk-unix: fix uint32_t id variable printf format specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tun: fix tun_link leak in dump_tun_link (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fix cr_imgset leak in dump_one_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix e_str leak in ext_mount_add (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - proc_smaps: remove useless nonlinear check (anatasluo
<luolongjuna@gmail.com>)
 - compel: set mxcsr during error injection to zero (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix missplacement of err=True (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: disable rseq also on Archlinux (Adrian Reber <areber@redhat.com>)
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>)
 - bpfmap: handle new field in fdinfo (Adrian Reber <areber@redhat.com>)
 - ci: skip MAP_HUGETLB tests in stream test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB mappings test for parent-child relationship processes
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add shm hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add memfd hugetlb test (Bui Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Add MAP_HUGETLB memory mapping test (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - uffd: Skip lazy-mode restore on hugetlb mappings (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - mem: Skip premapping hugetlb mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - proc_parse, files: Add support for hugetlb memory mapping (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - memfd, shmem: Add support for checkpoint/restore memfd and anon shared memory
(Bui Quang Minh <minhquangbui99@gmail.com>)
 - ipc: Add support for checkpoint/restore hugetlb System V shared memory (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - kerndat: Collect hugetlb device numbers (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - check: Add a check for using memfd with hugetlb (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - files: generate unique transport socket names (Andrei Vagin
<avagin@gmail.com>)
 - util: add an unique ID of the current criu run (Andrei Vagin
<avagin@gmail.com>)
 - compel: fix how PTRACE_GET_THREAD_AREA errors are handled (Mike Rapoport
<rppt@linux.ibm.com>)
 - restorer: Fix sys_mmap's returned value check (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu-ns: use os.waitstatus_to_exitcode() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: fix exit code o for criu dump (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: when updating sid for shell job also update matching pgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: install libbsd dependency (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Fix formatting in criu documentation (Ashutosh Mehra <asmehra@redhat.com>)
 - test/autofs: fix use-after-free (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: set continue-on-error for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: fix parasite with GCC 12 (Adrian Reber <areber@redhat.com>)
 - criu: fix configuration file scanner with GCC 12 (Adrian Reber
<areber@redhat.com>)
 - compel: fix GCC 12 failure (out of bounds) (Adrian Reber <areber@redhat.com>)
 - zdtm: fix zdtm/static/maps00 case in arm64 (fu.lin <fulin10@huawei.com>)
 - pagemap: tiny fix on truncating memory image (Liu Hua
<weldonliu@tencent.com>)
 - lib: added tests for feature check in libcriu (Adrian Reber
<areber@redhat.com>)
 - lib: introduce feature check in libcriu (Adrian Reber <areber@redhat.com>)
 - ci: added .lgtm.yml file (Adrian Reber <areber@redhat.com>)
 - ci: update to latest Vagrant and Fedora images (Adrian Reber
<areber@redhat.com>)
 - contributing: remove old badges and logo (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - readme: add docker test badge (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: test criu-image-streamer with all tests (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mount/btrfs: make check_mountpoint_fd fallback to get_sdev_from_fd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: add helper to resolve sdev from fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove mnt_fd argument of __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: split check_mountpoint_fd from __open_mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/static/uffd-events: add more log messages (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: print tails of all logs if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - test: log testname.out.inprogress if a test has failed (Andrei Vagin
<avagin@gmail.com>)
 - ci: reenable the lazy-thp test in the lazy-remote mode (Andrei Vagin
<avagin@gmail.com>)
 - page-xfer: stop waiting for a new command after a close command (Andrei Vagin
<avagin@gmail.com>)
 - tls: allow to terminate connections synchronously (Andrei Vagin
<avagin@gmail.com>)
 - uffd: call disconnect_from_page_server to shutdown a page-server connection
(Andrei Vagin <avagin@gmail.com>)
 - tls: add more comments (Radostin Stoyanov <radostin@redhat.com>)
 - tls: use ssize_t for return value (Radostin Stoyanov <radostin@redhat.com>)
 - tls: fix typo (Radostin Stoyanov <radostin@redhat.com>)
 - zdtm: Add SOCK_SEQPACKET variants to unix socket tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Add support for SOCK_SEQPACKET unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - crtools: check that cpuinfo command has sub-command (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: use new opts.mode in image_dir_mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools/rpc: export current criu mode to opts.mode (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - crtools: remove excess always true condition (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: remove mntns-deleted-dst test leftover from git (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: zdtm_ct fix compilation error with strict-prototypes on (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm.py: clean up MAKEFLAGS env variable before running make instance
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - tests: added test for single pre-dump support (Adrian Reber
<areber@redhat.com>)
 - libcriu: add single pre-dump support (Adrian Reber <areber@redhat.com>)
 - ci: disable glibc rseq support (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use unstable release for cross-compile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - libcriu: add setting lsm-mount-context to libcriu (Adrian Reber
<areber@redhat.com>)
 - usernsd: UNS_FDOUT should not require an input descriptor (Andrei Vagin
<avagin@google.com>)
 - Add documentation for --timeout option (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: enable x86 xsave fault injection tests back (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: print the initial seed (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - x86/compel/fault-inject: bound xsave features set (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - test: another try to correctly fix the kernel version (Adrian Reber
<areber@redhat.com>)
 - ci: install procps in Alpine (Radostin Stoyanov <radostin@redhat.com>)
 - ci: Enable disabled unix socket related tests (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - sk-unix: Fix TCP_ESTABLISHED checks in unix sockets (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - util: make page-server IPv6 safe (Adrian Reber <areber@redhat.com>)
 - files-reg: try dump_ghost_remap if link-remap failed with error ENOENT
(ianlang <ianlang@tencent.com>)
 - test: do not use --keep-going for single zdtm tests (Adrian Reber
<areber@redhat.com>)
 - ci: disable broken tests until fixed (Adrian Reber <areber@redhat.com>)
 - make: Explicitly enable FPU on ARMv7 builds (Salvatore Bonaccorso
<carnil@debian.org>)
 - ci: Run cross compile with debian testing (Radostin Stoyanov
<radostin@redhat.com>)
 - ci: Run cross compile on debian stable (Radostin Stoyanov
<radostin@redhat.com>)
 - clang-format: disable wrong struct pointer declaration format (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add ro-mount check after c/r to mntns_ghost01 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - check: cleanup child processes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: switch to centos-stream-8 (Adrian Reber <areber@redhat.com>)
 - crtools: ignore SIGPIPE in swrk mode (Liu Hua <weldonliu@tencent.com>)
 - ci: Use latest Fedora for lint ci runs again (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - seize: restore cgroup freezer to right state (Liu Hua
<weldonliu@tencent.com>)
 - clang-format/zdtm: fix clang complains about strange elseifs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tests: improve the deterministic behavior of the test suite (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm.py: make tests with --link_remap exclusive (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: disable socket-raw test on centos8 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: make x86_ins_capability_mask human-readable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-dump: fail dumping when zombie process with sid 0 (Liu Hua
<weldonliu@tencent.com>)
 - clang-format: do automatic comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: do several manual comment fixups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - clang-format: enable AlignTrailingComments (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - tests: improve the image streamer process control (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - ci: use Fedora 34 for lint CI runs (Adrian Reber <areber@redhat.com>)
 - ci: fix userfaultfd test failures (Adrian Reber <areber@redhat.com>)
 - ci: replace deprecated codecov bash uploader (Adrian Reber
<areber@redhat.com>)
 - net: optimize restore_rule() to not open the CR_FD_RULE image file twice
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - criu-ns: make pidns init first do setsid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: use nftw in rmrf helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - tty: fix the null pointer of get_tty_driver (fu.lin <fulin10@huawei.com>)
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: enable coredump tests (Radostin Stoyanov <radostin@redhat.com>)
 - make: enable lint for coredump (Radostin Stoyanov <radostin@redhat.com>)
 - test/coredump: fix shellcheck errors (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix visually indented line (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: fix comparison to true (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix too many blank lines (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: fix missing whitespace around operator (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: lint fix for block comments (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: drop exec permission (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: drop unused variable (Radostin Stoyanov <radostin@redhat.com>)
 - python: replace equality with identity test (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: convert indentation to spaces (Radostin Stoyanov
<radostin@redhat.com>)
 - coredump: sort imports (Radostin Stoyanov <radostin@redhat.com>)
 - coredump: remove unused import (Radostin Stoyanov <radostin@redhat.com>)
 - Add new files for running criu-coredump via python 2 or 3 (AndreyVV-100
<viazovtsev.av@phystech.edu>)
 - Add support for python3 in criu-coredump (Andrey Vyazovtsev
<viazovtsev.av@phystech.edu>)
 - criu(8): Add more detailed description about --tcp-close dump option (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - zdtm: Dumping/restoring with --tcp-close on TCP_CLOSE socket (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - tcp: Skip restoring TCP state when dumping with --tcp-close (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - criu/files: Don't cache fd ids for device files (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu/plugin: Implement dummy amdgpu plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu: Introduce new device file plugin hooks (Rajneesh Bhardwaj
<rajneesh.bhardwaj@amd.com>)
 - criu(8): add --external net option (Radostin Stoyanov <radostin@redhat.com>)
 - github: update the stale version (Andrei Vagin <avagin@gmail.com>)
 - criu: Version 3.16.1 (Adrian Reber <areber@redhat.com>)
 - Makefile: add shellcheck test/others/libcriu/*.sh (Radostin Stoyanov
<radostin@redhat.com>)
 - test/libcriu: print logs on fail (Radostin Stoyanov <radostin@redhat.com>)
 - test/libcriu: add test case for join-ns (Radostin Stoyanov
<radostin@redhat.com>)
 - libcriu: define log level constants (Radostin Stoyanov <radostin@redhat.com>)
 - libcriu: add join_ns API (Radostin Stoyanov <radostin@redhat.com>)
 - Makefile: install criu-ns only with python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu-ns: change python shebang to python3 (Radostin Stoyanov
<radostin@redhat.com>)
 - criu: Version 3.16 (Adrian Reber <areber@redhat.com>)
 - ci: Update openj9 container images (Radostin Stoyanov <radostin@redhat.com>)
 - mount: fix double-dump file system bug (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - gitignore: add build directory (Radostin Stoyanov <radostin@redhat.com>)
 - podman-test: use crun from git repository (Radostin Stoyanov
<radostin@redhat.com>)
 - lib: install images/rpc.pb-c.h (Radostin Stoyanov <radostin@redhat.com>)
 - sk-unix: fix prep_unix_sk_cwd root and cwd restoring (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: restore current work directory after restoring mnt ns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: use swich_mnt_ns/restore_mnt_ns helpers to simplify code (Liu Hua
<weldonliu@tencent.com>)
 - binfmt_misc: restore current work directory after restoring mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - namespaces: add helpers to switch/restore mnt ns (Liu Hua
<weldonliu@tencent.com>)
 - remove tls parameter description if without GnuTLS support (liuchao173
<55137861+liuchao173@users.noreply.github.com>)
 - kerndat: create separate netns for has_nftables_concat check (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: fix network lock tests when run with --norst (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: use unique table names for nftables based locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - inventory: save network lock method to reuse in restore (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add ipv6 variants of net_lock_socket_* tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables connection locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add iptables per-socket locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add nftables network namespace locking test (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add nftables netns-wide locking/unlocking (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: rename iptables network locking/unlocking functions (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add check for nftables based network locking (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-service: add network_lock option to RPC and libcriu (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add --network-lock option to allow nftables alternative (Zeyad Yasser
<zeyady98@gmail.com>)
 - Run 'make indent' on criu/include/plugin.h (Andrei Vagin <avagin@gmail.com>)
 - workflows/lint: show changes (Andrei Vagin <avagin@gmail.com>)
 - criu/config: fix use-after-free in parse_join_ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - configs: fix used after free cases (Andrei Vagin <avagin@gmail.com>)
 - lsm: do not print a warning if no LSM has been detected (Adrian Reber
<areber@redhat.com>)
 - files-reg: do not print a warning if a file has no build_id (Adrian Reber
<areber@redhat.com>)
 - zdtm/pthread_timers: make sure glibc allocated SIGEV_THREAD's stack (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ci: fix 'crit.sh: 3: source: not found' (Adrian Reber <areber@redhat.com>)
 - docker-test: refactor test scenario (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump: suspend/resume lsm on pre-dump (Andrei Vagin <avagin@gmail.com>)
 - util: add run_command() (Christian Brauner <christian.brauner@ubuntu.com>)
 - zdtm/apparmor_stacking: don't include optional AppArmor namespace separator
(Christian Brauner <christian.brauner@ubuntu.com>)
 - apparmor: actually enable suspend for AppArmor (Christian Brauner
<christian.brauner@ubuntu.com>)
 - lsm: handle SELinux LSM correctly (Christian Brauner
<christian.brauner@ubuntu.com>)
 - tests: add a test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - check: add a feature test for apparmor_stacking (Tycho Andersen
<tycho.andersen@canonical.com>)
 - lsm: support checkpoint/restore of stacked apparmor profiles (Tycho Andersen
<tycho.andersen@canonical.com>)
 - util: add rm -rf function (Tycho Andersen <tycho.andersen@canonical.com>)
 - lsm: change when LSM profiles are collected (Tycho Andersen
<tycho.andersen@canonical.com>)
 - ci: extend lint run to run 'make indent' (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on header files (Adrian Reber <areber@redhat.com>)
 - Run 'make indent' on all C files (Adrian Reber <areber@redhat.com>)
 - criu: introduce clang-format to format source code (Adrian Reber
<areber@redhat.com>)
 - zdtm: fix indentation in Makefile wait_stop target (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: fix Fedora Rawhide (Adrian Reber <areber@redhat.com>)
 - posix-timers: fix getoverrun error handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: use pre-installed Podman (Adrian Reber <areber@redhat.com>)
 - zdtm/pthread_timers: require ns_pid feature and add non-ns test (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - posix-timers: fallback notify thread id encoding for non-pidns and non-nspid
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - proc_parse: make nspid field optional (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: add a test for SIGEV_THREAD timers (Andrei Vagin <avagin@gmail.com>)
 - timers: save tid from a task pid namespace (Andrei Vagin <avagin@gmail.com>)
 - proc_parse: get a thread ID in a thread pidns from /proc/pid/status (Andrei
Vagin <avagin@gmail.com>)
 - criu: dump and restore notify_thread_id of posix timer (Liu Chao
<liuchao173@huawei.com>)
 - criu-ns: add support for 'check' action (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: add top-level conditional execution (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: update script name in help message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Documentation: Add man page for criu-ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - make: install criu-ns (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - zdtm: prioritize /lib/* dependencies in some tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - scripts/build: add a docker file for archlinux (Zeyad Yasser
<zeyady98@gmail.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>)
 - cgroup: cgroup_contains has to update the mask for cgroupv2 (Andrei Vagin
<avagin@gmail.com>)
 - ci: add msgque test case to crit-recode (Adrian Reber <areber@redhat.com>)
 - lib: fix crit-recode msgque errors in Jenkins (Adrian Reber
<areber@redhat.com>)
 - ci/openj9: run mrproper before make (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm: make --sbs also stop on each pre-dump/snap iteration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: cleanup cgroup properly in error path (Liu Hua
<weldonliu@tencent.com>)
 - scripts: run lint also on criu-ns (Adrian Reber <areber@redhat.com>)
 - ci: also test tcp stream crit recoding (Adrian Reber <areber@redhat.com>)
 - lib: fix broken crit-recode test (Adrian Reber <areber@redhat.com>)
 - ci: combine cross compile container definitions (Adrian Reber
<areber@redhat.com>)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-service: move pidfd_store initialization to cr-service (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: tidy up interface and hide unneeded details (Zeyad Yasser
<zeyady98@gmail.com>)
 - pidfd_store: move pidfd_store to a separate file (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/ci: sync netns_lock test and its --post-start hook (Zeyad Yasser
<zeyady98@gmail.com>)
 - test/jenkins: fix netns_lock test multiple iterations failure (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: fix mips64el-cross test (Adrian Reber <areber@redhat.com>)
 - Keep inherit-fd strings alive until task restore (Younes Manton
<ymanton@ca.ibm.com>)
 - pycrit: fix the broken of cli the `crit show xxx.img` (fu.lin
<fulin10@huawei.com>)
 - Add test for new --lsm-mount-context option (Adrian Reber
<areber@redhat.com>)
 - Enable changing of mount context on restore (Adrian Reber
<areber@redhat.com>)
 - Remove unnecessary whitespace (Adrian Reber <areber@redhat.com>)
 - zdtm: add network namespace locking test (Zeyad Yasser <zeyady98@gmail.com>)
 - test: remove exec test (Adrian Reber <areber@redhat.com>)
 - criu: add unit testing for config file parser (Adrian Reber
<areber@redhat.com>)
 - test: add tests for configuration file parsing (Adrian Reber
<areber@redhat.com>)
 - config: make configuration file parser more robust (Adrian Reber
<areber@redhat.com>)
 - criu: add cleanup_free attribute (Adrian Reber <areber@redhat.com>)
 - bfd: loop through read()/write() when the action is incomplete (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - ci: disable some tests on CentOS 7 (Adrian Reber <areber@redhat.com>)
 - ci: remove old workarounds (Adrian Reber <areber@redhat.com>)
 - ci: switch CentOS 7 test to Cirrus CI (Adrian Reber <areber@redhat.com>)
 - ci: disable -x during print_env() (Adrian Reber <areber@redhat.com>)
 - zdtm: allow ignore taint via environment variable (Adrian Reber
<areber@redhat.com>)
 - scripts/vagrant: Use vagrant 2.2.16 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - scripts/vagrant: Use Fedora 34 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - add PKG_CONFIG default in a few more places (Mike Frysinger
<vapier@chromium.org>)
 - crtools: improve error handling on signal setting (Valery Ivanov
<ivalery111@gmail.com>)
 - build: respect $PKG_CONFIG settings (Mike Frysinger <vapier@chromium.org>)
 - docker-test: use latest containerd release (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - zdtm/tun_ns: add per-test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: skip time namespaced tests on <= 5 (Adrian Reber <areber@redhat.com>)
 - ci: update docker test matrix (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - cr_options: handle the case where __dest == __src in SET_CHAR_OPTS (Christian
Brauner <christian.brauner@ubuntu.com>)
 - github: Add templates for new issues and pull requests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu(8): document --join-ns option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - kdat: make uffd_open return errno from syscall separately (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: no longer avoid overlayfs (Adrian Reber <areber@redhat.com>)
 - test/others: refactor loop process (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/others: drop '_exit' function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: add a test to check that sigtrap handlers are restored (Andrei Vagin
<avagin@gmail.com>)
 - ksigset: fix a typo in ksigdelset (Andrei Vagin <avagin@gmail.com>)
 - mem/pidfd: fix poll retry error checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add pidfd store based pid reuse test (Zeyad Yasser
<zeyady98@gmail.com>)
 - zdtm: add --pidfd-store option in RPC mode (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: add pidfd based pid reuse detection for RPC clients (Zeyad Yasser
<zeyady98@gmail.com>)
 - cr-check: add ability to check if pidfd_store feature is supported (Zeyad
Yasser <zeyady98@gmail.com>)
 - cr-service: add pidfd_store_sk option to rpc.proto (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_getfd syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - criu: check if pidfd_open syscall is supported (Zeyad Yasser
<zeyady98@gmail.com>)
 - kerndat: Handle non-root mode when checking uffd (nithin-jaikar
<jaikar006@gmail.com>)
 - test/others/crit: add test for 'x' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - lib/cli.py: Open explore file as a binary (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test/zdtm: check that a penging SIGTRAP handled properly (Andrei Vagin
<avagin@gmail.com>)
 - parasite: don't block SIGTRAP (Andrei Vagin <avagin@gmail.com>)
 - test: create new tls certificates (Adrian Reber <areber@redhat.com>)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: ghost: fix deadlock between peer_fle->stage and fds wake up
(Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - ci: remove hack for netns-nft zdtm test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add combined nftables/iptables netns-nft-ipt test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: skip static/netns-nft test if nftables feature isn't supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - net: skip iptables dump if it has nft backend and nft dump is supported
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - lsm: handle half initialized SELinux setups (Adrian Reber
<areber@redhat.com>)
 - tools.mk: Use Python 3 by default (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: remove empty gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - mips: coding style fixes (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - Allow systemcfg proc file to be dumped (zl-wang <zlwang@ca.ibm.com>)
 - logging: pr_perror() -> pr_msg() when execvp fails in action scripts and
others (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - net: add a #define for increased compatiblity with old distributions (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - restore: fix error message when fork fails (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: end pr_(err|warn|msg|info|debug) with \n (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Whitespace at EOL cleanup and check (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu: make sure to use pr_perror to show errno (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: pr_err / pr_perror fixes (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/others/bers: use pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu/mount.c: fix \n in pr_debug (Kir Kolyshkin <kolyshkin@gmail.com>)
 - scripts: fix shellcheck warnings (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Makefile: amend lint with pr_perror/fail checks (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't pass errno to fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use %m with fail (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use \n with fail() (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: don't use errno for pr_perror (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - test/zdtm: don't use pr_perror where errno is unset (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - criu: don't use errno for pr_error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - Drop \n from pr_perror (Kir Kolyshkin <kolyshkin@gmail.com>)
 - test/zdtm: check that restore can handle precreated veth devices (Andrei
Vagin <avagin@gmail.com>)
 - kerndat: check whether IFLA_NEW_IFINDEX is supported (Andrei Vagin
<avagin@gmail.com>)
 - ci: exclude lazy-thp for remote pages over tls (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: docker-test don't use interactive tty (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Makefile: update excluded tests for docker-test (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use host cgroup & network ns (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: add missing test dependencies (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: re-build criu after clean (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - Dockerfile: use 'git clean' before build (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - tiny fix on function dump_empty_fs (Liu Hua <weldonliu@tencent.com>)
 - net: allow restoring of precreated veth devices (Christian Brauner
<christian.brauner@ubuntu.com>)
 - scripts/build: drop obsolete ENV1 variable (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - images: re-license as Expat license (so-called MIT) (Adrian Reber
<areber@redhat.com>)
 - ci: enable crit tests in CI (Adrian Reber <areber@redhat.com>)
 - test: fix crit test and extend it (Adrian Reber <areber@redhat.com>)
 - lib: also handle extra pipe data correctly (Adrian Reber <areber@redhat.com>)
 - lib: print nice error if crit gets wrong input (Adrian Reber
<areber@redhat.com>)
 - lib: correctly handle stdin/stdout (Python 3) (Adrian Reber
<areber@redhat.com>)
 - criu: Replace faccessat with fstatat when using AT_SYMLINK_NOFOLLOW flag (Bui
Quang Minh <minhquangbui99@gmail.com>)
 - criu: Throw error when parent path is provided but invalid (Bui Quang Minh
<minhquangbui99@gmail.com>)
 - cr-service: fix CRIU_REQ_TYPE__FEATURE_CHECK RPC request (Zeyad Yasser
<zeyady98@gmail.com>)
 - lib: fix crit-recode fix for Python 2 (Adrian Reber <areber@redhat.com>)
 - ci: move CentOS 8 based test to Cirrus (Adrian Reber <areber@redhat.com>)
 - Use a real VM instead of a privileged container (fedor
<fedor@cirruslabs.org>)
 - pstree: don't change sid/gid-s if current sid/gid is the same (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - lib: correctly handle padding of dump images (Adrian Reber
<areber@redhat.com>)
 - lib: fromstring() and tostring() are deprecated (Adrian Reber
<areber@redhat.com>)
 - criu-ns: Merge comparisons with 'in' (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Add unsupported msg for restore-sibling (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Handle restore-detached option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Pass arguments to run_criu() (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Close namespace fd before raise (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract set namespace functions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove unused _umount (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use documentation strings (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract wait for process into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Extract mount new /proc into a function (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Remove space before/after bracket (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert indentation to spaces (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: run zdtm/transition/pid_reuse with pre-dumps in ci tests (Zeyad Yasser
<zeyady98@gmail.com>)
 - ci: remove ccache setup (Adrian Reber <areber@redhat.com>)
 - ci: run recode tests on more input files (Adrian Reber <areber@redhat.com>)
 - lib: fix recode errors seen in Jenkins (Adrian Reber <areber@redhat.com>)
 - ci: remove '-Wl,-z,now' workaround (Adrian Reber <areber@redhat.com>)
 - lib/cli.py: Open out file as a binary (Dmitry Safonov <dima@arista.com>)
 - docker-test: set log file path (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - docker-test: use containerd v1.5.0-beta.0 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: move Travis CI Docker tests to GitHub Actions (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - pstree: check for pid collision before switching to new sid/gid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - test: move vt test to minor 65 on s390x (Adrian Reber <areber@redhat.com>)
 - zdtm/fpu03: Add .desc file to omit running on !x86 (Dmitry Safonov
<dima@arista.com>)
 - Revert "compel: add -ffreestanding to force gcc not to use builtin memcpy,
memset" (Dmitry Safonov <dima@arista.com>)
 - s390: Purge stale comment (Dmitry Safonov <dima@arista.com>)
 - fault-injection: Run fpu corruption tests (Dmitry Safonov <dima@arista.com>)
 - compel: Provide compel_set_task_ext_regs() (Dmitry Safonov <dima@arista.com>)
 - compel: Store extended registers set in the thread context (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu03: Add a test to check fpu C/R in a thread (Dmitry Safonov
<dima@arista.com>)
 - zdtm/fpu00: Simplify ifdeffery (Dmitry Safonov <dima@arista.com>)
 - x86/compel/fault-inject: Add a fault-injection for corrupting extended regset
(Dmitry Safonov <dima@arista.com>)
 - namespaces: properly handle errors of snprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - x86: Use PTRACE_GET_THREAD_AREA instead of sys_get_thread_area() (Dmitry
Safonov <dima@arista.com>)
 - ci/compat: Check if tests are 32-bit ELFs (Dmitry Safonov <dima@arista.com>)
 - github/stale: separate labels with commas without following spaces (Andrei
Vagin <avagin@gmail.com>)
 - ci: fix Fedora rawhide CI failures (Adrian Reber <areber@redhat.com>)
 - plugin: check for plugin path truncation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-unix: check whether a socket name is NULL before printing it (Andrei Vagin
<avagin@gmail.com>)
 - bug: add __builtin_unreachable in BUG_ON_HANDLER (Andrei Vagin
<avagin@gmail.com>)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)
 - zdtm: Add javaTests output to .gitignore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - test: Reduce verbosity of mvn output (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - javaTests: Add --file-locks option (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - file-lock: Add space in error message (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: use runc instead of crun for podman tests (Adrian Reber
<areber@redhat.com>)
 - seccomp: initialize seccomp_mode in all cases (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: add second fifo_upon_unix test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - zdtm: add fifo upon unix socket test case (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: rework unix_resolve_name (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - files-reg: rework strip_deleted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - files: Don't forget on stripping deleted postfix on linked files (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - ci: move coverage run to github (Adrian Reber <areber@redhat.com>)
 - test/zdtm: check that locks are not dumped if --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - dump: dump has to fail if there is locks and --file-locks isn't set (Andrei
Vagin <avagin@gmail.com>)
 - ci: move compat tests to Github Actions (Adrian Reber <areber@redhat.com>)
 - README.md: remove unused badges; add a few new badges (Adrian Reber
<areber@redhat.com>)
 - README.md: remove trailing whitespaces (Adrian Reber <areber@redhat.com>)
 - ci: move asan and image streamer test to github (Adrian Reber
<areber@redhat.com>)
 - vdso: fix segmentation fault caused by char pointer array (anatasluo
<luolongjuna@gmail.com>)
 - Tell podman to use vfs as storage-driver (Adrian Reber <areber@redhat.com>)
 - ci: move Fedora Rawhide based tests away from Travis (Adrian Reber
<areber@redhat.com>)
 - ci: factor out Fedora Rawhide CI setup (Adrian Reber <areber@redhat.com>)
 - ci: skip bpf tests on vagrant (Adrian Reber <areber@redhat.com>)
 - ci: upgrade vagrant and Fedora version (Adrian Reber <areber@redhat.com>)
 - ci: fix syntax error in stale.yml (Adrian Reber <areber@redhat.com>)
 - zdtm: handle a case when a test vma is merged with another one (Andrei Vagin
<avagin@gmail.com>)
 - util: zero the events pointer to avoid its double free (Andrei Vagin
<avagin@gmail.com>)
 - namespaces: handle errors of snprintf (Andrei Vagin <avagin@gmail.com>)
 - ci: also use clang for compel-host-bin (Adrian Reber <areber@redhat.com>)
 - ci: run aarch64 compile tests on Drone (Adrian Reber <areber@redhat.com>)
 - zdtm: cleanup thread-bomb test error handling and printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move vagrant test to cirrus ci (Adrian Reber <areber@redhat.com>)
 - workflows/stale: Don't close issue that has labels 'new feature' or
'enhancement' (Andrei Vagin <avagin@google.com>)
 - fsnotify: rework redundant code (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>)
 - coverity: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - restore: warning: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - servicefd: don't move service fds in case they remain in the same place
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/test: Fix warn_unused_result (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel: Fix missing loff_t in Alpine (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: Enable compel testing (Radostin Stoyanov <rstoyanov@fedoraproject.org>)
 - compel/test: Add main makefile (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/test: Resolve missing includes (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - dump/ppc64,arm,mips: sanitize the ERESTART_RESTARTBLOCK -> EINTR transition
(Andrei Vagin <avagin@gmail.com>)
 - github: auto-close stale issues and pull requests (Adrian Reber
<areber@redhat.com>)
 - zdtm: look up iptables in /sbin and /usr/sbin (Andrei Vagin
<avagin@gmail.com>)
 - test/zdtm_ct: Run zdtm.py in the host time namespace (Andrei Vagin
<avagin@gmail.com>)
 - ci: Alpine's busybox based free does not understand -h (Adrian Reber
<areber@redhat.com>)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ci: move alpine based tests to github actions (Adrian Reber
<areber@redhat.com>)
 - ci: give an overview of the current CI environment (Adrian Reber
<areber@redhat.com>)
 - ci: add Circle CI definition (Adrian Reber <areber@redhat.com>)
 - CONTRIBUTING.md: add component prefix to the subject example (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - .gitignore: Remove qemu-user-static (Dmitry Safonov <dima@arista.com>)
 - scripts/Docerfile.centos8: Use 'powertools' repo name (Dmitry Safonov
<dima@arista.com>)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>)
 - others/ns_ext: restore a process out of PID namespaces into the host PID
namespace (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - compel/handle-elf: override unexpected precalculated addresses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - docs: fix simple typo, clietn -> client (Tim Gates <tim.gates@iress.com>)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: on fail with no error also print the tail of the log (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - uffd: check for exited task when reading uffd_msg (Mike Rapoport
<rppt@linux.ibm.com>)
 - uffd: cleanup read error handling in handle_uffd_event (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: Properly inspect status in sigchld_process() (Dmitry Safonov
<dima@arista.com>)
 - ci: remove special handling for mips (Adrian Reber <areber@redhat.com>)
 - CI: remove centos7 from Travis (Adrian Reber <areber@redhat.com>)
 - ci: use graviton2 for arm64 tests on Travis (Adrian Reber
<areber@redhat.com>)
 - tls: Add logging within send/recv callbacks (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>)
 - uffd: handle xrealloc() failure (Adrian Reber <areber@redhat.com>)
 - uffd: fix 'double free detected in tcache 2' (Adrian Reber
<areber@redhat.com>)
 - ci: add CentOS 8 based CI run (Adrian Reber <areber@redhat.com>)
 - ci: switch centos7 to github actions (Adrian Reber <areber@redhat.com>)
 - travis: rename centos test to centos7 (Adrian Reber <areber@redhat.com>)
 - criu-ns: Remove unreachable statement (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - ci: fix lazy-pages test selection (Mike Rapoport <rppt@linux.ibm.com>)
 - ci: 'fix' lazy tests (Adrian Reber <areber@redhat.com>)
 - namespaces: fix 'Declaring variable "path" without initializer' (Adrian Reber
<areber@redhat.com>)
 - coverity: img_raw_fd() returns a negative number (Adrian Reber
<areber@redhat.com>)
 - sk-unix: ignore coverity chroot() warning (Adrian Reber <areber@redhat.com>)
 - cr-dump: get_service_fd() is passed to a parameter that cannot be negative
(Adrian Reber <areber@redhat.com>)
 - util: fix double_close false positive (Adrian Reber <areber@redhat.com>)
 - dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - coverity: fix parameter_hidden: declaration hides parameter (Adrian Reber
<areber@redhat.com>)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - cr-dump: Potential leak of memory pointed to by 'si' (Adrian Reber
<areber@redhat.com>)
 - vdso-compat: let coverity know that the function does not return (Adrian
Reber <areber@redhat.com>)
 - coverity: ignore CHECKED_RETURN (Adrian Reber <areber@redhat.com>)
 - autofs: Potential leak of memory pointed to by 'token' (Adrian Reber
<areber@redhat.com>)
 - sk-unix: do not overwrite function parameter (Adrian Reber
<areber@redhat.com>)
 - Use 'is None' instead of '== None' (Adrian Reber <areber@redhat.com>)
 - bfd: remove unused line (Adrian Reber <areber@redhat.com>)
 - coredump: remove two unused variables (Adrian Reber <areber@redhat.com>)
 - lib/py: remove unused variable (Adrian Reber <areber@redhat.com>)
 - infect: initialize struct to avoid CLANG_WARNING (Adrian Reber
<areber@redhat.com>)
 - lock: disable clang_analyzer for the LOCK_BUG_ON() macro (Adrian Reber
<areber@redhat.com>)
 - compel: don't mmap parasite as RWX (Michał Cłapiński
<mclapinski@google.com>)
 - cr-restore: Wait child & reap zombies if PID=1 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Use PID 1 on restore (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu-ns: Convert c_char_p strings to bytes object (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Print usage info when no args provided (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu-ns: Convert to python3 style print() syntax (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - python: Replace xrange with range (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - crns.py: New attempt to have --unshare option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - CI: distribute CI jobs between CI systems (Adrian Reber <areber@redhat.com>)
 - CI: rename 'travis' to 'ci' (Adrian Reber <areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)

* Tue Jan 24 2023 VZ Auto Builder <builder@virtuozzo.com> 3.15.5.3
 - zdtm: check that combined nft with iptables-nft c/r works (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144625)
 - net: ignore if one of nft or iptables-nft fails and other succeeds (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144625)

* Mon Jan 09 2023 VZ Auto Builder <builder@virtuozzo.com> 3.15.5.2
 - zdtm: add route tables tests (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)
 - net: dump all route tables (Yuriy Vasilev <yuriy.vasilev@virtuozzo.com>) (#PSBM-144261)

* Thu Jan 05 2023 VZ Auto Builder <builder@virtuozzo.com> 3.15.5.1
 - test: remove test for LOCK_MAND flock (Adrian Reber <areber@redhat.com>) (#PSBM-144187)
 - zdtm: Fix setting up zdtm test env variables (Yuriy Vasilev
<yuriy.vasilev@virtuozzo.com>) (#PSBM-144187)
 - zdtm/ve_flavor: create cgroup namespace for ve if available (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144187)
 - zdtm/ve_flavor: enter nested rdma cgroup if available for vz9 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-144187)
 - zdtm/ve_flavor: set ve.iptables_mask only if available (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144187)
 - kerndat: check for cgroup kmem limit available (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-144187)
 - sk-unix: allocate FdinfoEntry with shmalloc in get_fle_for_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-unix: print message when adding fake queuers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - sk-queue: print message when dumping nested fds from socket (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-143751)
 - vz7/vz9: update version and targets.list for u20 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: bring back scm07 and scm08 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Thu Dec 08 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.16
 - net: dump nft rules via both nft and iptables-nft (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138902)

* Tue Nov 29 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.15
 - zdtm: Add test for IP_PKTINFO sock option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-142872)
 - sk-inet: support of SOL_IP, IP_PKTINFO option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-142872)

* Fri Oct 28 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.14
 - pie/restorer: remove excess hash printf specifier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Fri Oct 21 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.13
 - cgroup: add a comment to restore_cgroup_prop about path argument requirements
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup/freezer: fix out of bound access in restore_cgroup_prop() (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141679)

* Wed Oct 19 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.12
 - zdtm/session04: test reaper and helper parent with different mntns/pidns
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - pstree: make helpers always have same mntns to parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-141587)
 - test: fix test compilation on rawhide (Adrian Reber <areber@redhat.com>)

* Tue Aug 09 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.11
 - cr-restore: leave veX cgroup on error path (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-141122)

* Thu Jun 09 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.10
 - zdtm/scm: add scm09 test with closed sender fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-140415)
 - sk-unix: make add_fake_unix_queuers earier and rework find_queuer_for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140414)

* Tue Jun 07 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.9
 - sk-queue: fix dumping queue packets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-139953)
 - zdtm: add scm08 test having several SCM_RIGHTS and SCM_CREDENTIALS (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-139953)

* Wed May 25 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.8
 - irmap: don't fail early if failed to resolve path on pre-dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-140177)

* Tue May 10 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.7
 - action-scripts: call dump-alive when dumped task is left running (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - cr-dump: do not report success to logs if post-dump script failed (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-138439)
 - filesystems: allow dumping container with nfsd mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-138439)

* Mon May 09 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.6
 - sk-unix: fix overmounted stream sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - mount: remove O_DIRECTORY flag for mount opening helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-139948)

* Tue Apr 26 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.5
 - sk-unix: rework bind_on_deleted() return codes (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)

* Thu Mar 03 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.4
 - zdtm: add test with overmounted unix bindmount (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: allow unix bindmounts to be overmounted (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount: add open_mountpoint_with_flags() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add overmounted unix tests (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: dump overmounted socket (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: implement restore of overmounted unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: distinguish cleanup of leftover sockets from early bind (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use ghost approach for connecting to overmounted sockets (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: rename all references to bindmounts to early bind (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - images: add VZ_OVERMOUNTED to unix uflags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount-v2: separate bind and bindmount stages for unix bindmounted sockets
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: refuse to dump bindmounted unix sockets without mnt_id (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - zdtm: add new test to check mntid of bindmounted unix socket (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: use correct mount for bind() in unix_prepare_bindmount (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: add sk_to_mnt_id helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount-v2: restore unix sockets and bindmounts in correct mntns (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - mount-v2: separate creation and assembling of mount namespaces (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)
 - sk-unix: improve detection of mnt_id of bindmounted sockets for old images
(Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-135398)

* Thu Feb 17 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.3
 - vz9: update targets.list for beta (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - protobuf: remove leading underscores from protobuf structs (Zeyad Yasser
<zeyady98@gmail.com>) (#PSBM-135201)
 - compel: silence std_sprintf returned string size check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - Fix gcc9 build failures (Jeff Law <law@redhat.com>)

* Wed Feb 02 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.2
 - net: run iptables-legacy binaries for VZ9 (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-137826)

* Thu Jan 20 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.4.1
 - cr-restore: fix born_sid check in create_children_and_session (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add some more subreaper reparenting tests (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: child_subreaper_and_reparent test should fail on dump stage (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - zdtm: add a feature to set the "crfail" flag for different zdtm stages (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - pstree/dump: handle child subreaper reparent on dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - cr-dump: add call pstree_insert_pid from dump_one_zombie (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-122618)
 - vz7/vz9: update version and targets.list for u19 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Wed Jan 19 2022 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.12
 - mount-v2: fixup resolve_shared_mounts_v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: make new overmounted_ tests always run with mount-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-137789)

* Mon Dec 20 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.11
 - zdtm: add tests for overmounted procfs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted proc files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted nfs silly renames (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted spfs files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_ghost test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enable overmounted ghost files (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - zdtm: add overmounted_remap test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: enhance remaps to handle overmounted cases (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add open_opath_at_mount() (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: use new resolve_mntfd_and_rpath() helper for dump (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: change nsid to mi for reg files dumping (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: update restore logic (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: introduce mntv2 for link-remaps (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - utils: add resolve_mntfd_and_rpath helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)
 - files-reg: refuse to dump overmounted files in host fs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-127834)

* Wed Dec 08 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.10
 - cgroup: fix wrong mixed paths in info message when preparing properties
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-136411)
 - zdtm: check criu_path permissions before mounting (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: add get_path_check_perm helper that checks for 'x' permissions (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-106009)
 - zdtm: fix cwd path freeing (Yuriy Vasiliev <yuriy.vasiliev@virtuozzo.com>)
 - zdtm: fix cgroup_freezer test compiler warnings (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>)

* Thu Nov 25 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.9
 - rpc: add option to skip 'freezer.state' dump/restore (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-123408)

* Tue Nov 23 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.8
 - zdtm: add test for nested freezers states restoration (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - zdtm: add support for the "freezecg" option in the .desc file (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - freezer: dump nested freezers states and restore them after resume (Yuriy
Vasiliev <yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)
 - seize: recover original freezer sub-tree state after dump (Yuriy Vasiliev
<yuriy.vasiliev@virtuozzo.com>) (#PSBM-107663)

* Fri Nov 19 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.7
 - mount-v2: fix children-parent relative mountpoint checking (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Wed Nov 10 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.6
 - pie/restorer: fix compilation with DEBUG=1 (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-135350)
 - x86/asm: fix compile error in bitops.h (anatasluo <luolongjuna@gmail.com>) (#PSBM-135350)
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)

* Wed Nov 10 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.5
 - zdtm: add new bindmount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sk-unix: resurrect socketpair for bindmount unix sockets (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)

* Tue Oct 26 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.4
 - config: add --ve-clock-fallback option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-134480)

* Thu Oct 21 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.3
 - targets.list: add vz9 into build targets (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - prctl/start_time: change names in accordance with vz9 kernel change (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: fix ve flavor for vz7 (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-134129)

* Tue Oct 19 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.2
 - net: reenable vxlan nla flags (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)
 - libnetlink: add addattr helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123378)

* Tue Oct 19 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.3.1
 - mount: fix declaration of root_yard_mp and mnt_roots (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount-v2: fix nested_pidns_procs declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - vz7/vz8: update version and targets.list for u17 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add another thp_disable test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-123568)

* Mon Aug 16 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.9
 - cgroup: skip restoring ifpriomap (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-132267)

* Thu Aug 12 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.8
 - cgroup: skip beancounter cgroup restore if it's not supported (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131412)

* Thu Aug 12 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.7
 - compel/log: Provide %u specifier parsing (Dmitry Safonov <dima@arista.com>) (#PSBM-131412)
 - compel/log: Stop parsing at unknown format specifier (Dmitry Safonov
<dima@arista.com>) (#PSBM-131412)
 - vdso: Let zero-terminator in vdso_symbol_length (Dmitry Safonov
<dima@arista.com>) (#PSBM-131412)

* Fri Aug 06 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.6
 - zdtm: make sock_opts02 also check lock change by SO_*BUF* (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131580)
 - zdtm: add test for socket buffer size locks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131580)
 - sockets: c/r bufer size locks (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131580)
 - kerndat: check for set/getsockopt SO_BUF_LOCK availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131580)
 - sockets: don't call sk_setbufs asyncronously (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131580)
 - crit: fix error on memfd files parsing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Wed Jun 30 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.5
 - zdtm: listen and connect/accept in different network namespaces (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: handle socket vfs inode bindmount with multiple sockets (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - sk-unix: print real socket inode for found bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-131050)
 - cgroup: dump devices.extra_list instead of devices.list (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129354)

* Wed Jun 23 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.3
 - zdtm: unlink_fstat03: ignore st_dev diff when file on device mapper
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-130519)
 - ps-socket: sanity check that given fd is actually valid (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102629 #PSBM-130507)

* Fri Jun 04 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.2
 - zdtm: improve overmount_file test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - files-reg: add overmounted reg files handling (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - util: add get_relative_path_noempty helper (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - mount: add path_is_overmounted helpers (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)
 - images: add vz_use_relative_path flag to regfile (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-125849)

* Tue May 25 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.2.1
 - mount-v2: prohibit mounts with symlink mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129638)
 - zdtm: fix uninitialized lenght provided to getsockopt (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-129482)
 - vz7/vz8: update version and targets.list for u17 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Fri Mar 12 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.25
 - PSBM-122095 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)
 - PSBM-122095 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122095)

* Sat Feb 20 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.23
 - PSBM-125002 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-125002)

* Fri Feb 19 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.22
 - PSBM-123431 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123431)

* Thu Feb 18 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.21
 - PSBM-124263 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-124263)

* Thu Feb 18 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.20
 - PSBM-123431 (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431)

* Tue Feb 16 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.19
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)
 - PSBM-123668 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123668)

* Tue Feb 16 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.18
 - PSBM-122120 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122120)

* Fri Feb 12 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.17
 - PSBM-122418 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - PSBM-122418 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - PSBM-122418 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)
 - PSBM-122418 (Andrey Zhadchenko <andrey.zhadchenko@virtuozzo.com>) (#PSBM-122418)

* Mon Feb 01 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.15
 - PSBM-125086 (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-125086)

* Thu Jan 28 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.14
 - PSBM-123431 (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-123431)

* Thu Jan 28 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.13
 - PSBM-124623 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124623)
 - PSBM-124538 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)
 - PSBM-124538 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124538)

* Fri Jan 15 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.10

* Fri Jan 15 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.9

* Fri Jan 15 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.7
 - vz7/vz8: fix stupid targets.list copy-paste missprint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)

* Fri Jan 15 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.6
 - vz7/vz8: add targets.list to build both criu versions from same code repo
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123769)

* Fri Jan 15 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.1.5
 - vz7/vz8: add targets.list to build both criu versions from same code repo
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123769)

* Thu Jan 14 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.18
 - plugin: Add criu_get_work_dir_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123778)
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)

* Tue Jan 12 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.17
 - files-reg: show sdev of the file we failed to lookup mount for (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-124422)

* Tue Jan 12 2021 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.16
 - mount: Add fsname to error message for unsupported fs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-124531)

* Wed Dec 30 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.15
 - autofs: support dump of abandoned overmounted autofs mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122727)

* Fri Dec 18 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.14
 - zdtm: extend bind-mount-unix0* tests with ghost sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-123644)
 - zdtm: extend bind-mount-multi test with stream, seqpacket sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - sk-unix: add support of bindmounted STREAM, SEQPACKET sks (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-121925)
 - criu.spec: explictily provide criu version to make (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Thu Dec 17 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.13
 - build: add ability to override CRIU_VERSION from rpmbuild specs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)

* Thu Dec 17 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.12
 - ve/beancounter: don't unlimit beancounter cgroup if it does not exist (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - kerndat: check for beancounter cgroup availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)

* Wed Dec 16 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.11
 - zdtm: workaround ip route dump problem (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: make ns_file_bindmount parent/child sync with futex (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - zdtm/vz8: disable mnt_tracefs test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123769)
 - vxlan: lets temporary disable all NLA_FLAG entries as they were get/set wrong
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - mount: fix errno handling in mount_and_open_binfmt_misc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: openvswitch00: replace snprintf with ssprintf (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm/lib: print errno for mount error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - net: prepare our own xtables lock for network_(un)lock_internal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - sk-unix: fixup snprintf truncation gcc warning (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120728 #PSBM-123769)
 - zdtm: disable cgroup_ifpriomap (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)

* Tue Dec 15 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.10
 - cgroup: change defaults for net_prio cgroup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123648)

* Fri Dec 04 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.9
 - infect: print stack for D state process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-122979)

* Fri Dec 04 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.8
 - restore/ve: do ve start from container init task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-123162)
 - config/rpc: add new option --ve to identify that we deal with VZ ct (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-123162)

* Fri Nov 27 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.7
 - servicefd: don't cleanup new fd in case it is same as old one (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-122957)
 - zdtm: overlay: use ssprintf instead of snprintf (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122375)
 - zdtm: pidns03: do lazy umount /proc (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-122505)
 - zdtm: fix segfault in several tests on new GCC (unaligned stack) (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-120728)

* Thu Nov 26 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.6
 - zdtm: add second fifo_upon_unix test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106582)
 - zdtm: add fifo upon unix socket test case (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106582)
 - sk-unix: rework unix_resolve_name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106582)
 - sk-unix: make criu respect existing files while restoring ghost unix socket
fd (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106582)
 - files-reg: rework strip_deleted (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106582)
 - zdtm: fix overlayfs_fsnotify tests (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-122444)
 - vim: remove wrong 8-space tabs indent from python files (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Fri Nov 20 2020 VZ Auto Builder <builder@virtuozzo.com> 3.15.0.5

* Tue Nov 17 2020 Denis Silakov <dsilakov@virtuozzo.com> 3.15.0.4
 - zdtm: enable tty-inherit tests (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - mount: ignore root change in cgroup mounts in case of container rename (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-108126)
 - spfs: fix usage of new_cg_root_get (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-108126)
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99868)
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-96362)
 - mounts-v2: fallback to compat mount engine in case of old kernel (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-121995)
 - kerndat: Check for mount MS_SET_GROUP availability (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121995)
 - zdtm: add testcase for netlink socket with enobufs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - netlink: save and generate ENOBUFS at restore (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-120976)
 - zdtm: don't mount overlayfs in unprivileged user namespace (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121284)
 - proc_parse: retry to parse fdinfo from ve (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-108122)
 - dump: at exit do not call timing_stop if stats are not initialized (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104289)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96308)
 - zdtm: add new sk-netlink-flags test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - sk-netlink: fix order between restoring queue and file params (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120924)
 - mount: make overlayfs_mount use relative paths to make paths shorter (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120708)
 - nsfs: add some debug to open_ns_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: improve ns_file_bindmount to also check open nsfs bindmount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - nsfs: handle files opened on nsfs bindmounts as special nsfs-files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107790)
 - freezer: wait freezer.state changes to FROZEN after writing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107938)
 - scripts/nfs: make small cleanup of nfs-ports-allow.sh (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107842)
 - zdtm: crfail child_subreaper_and_reparent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: add simple reparenting to CHILD_SUBREAPER case to session04 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: add child subreaper reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: prepare a link for each item to it's child subreaper (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - pstree: save child_subreaper in pstree image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - cr-restore: skip current from search in collect_child_pids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: check process tree topology in session04 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-107418)
 - zdtm: inotify on mqueue test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-107766)
 - freezer: added cmd-line option to skip 'freezer.state' dump/restore (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-106413 #PSBM-107590 #PSBM-107590)
 - zdtm: fix compilation from vzt-cpt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-106860)
 - zdtm: add ovs unshare test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - zdtm: add openvswitch test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: explicitly forbid ovs vports with netnsid (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: specify ifindex for ovs netdevs (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add ovs internal vport support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add openvswitch vxlan support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - net: add initial openvswitch support (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - images: add protobuf for openvswitch structures (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105844)
 - seize: recursively thaw freezers in freeze_processes (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-107590)
 - zdtm: add inotify on cgroup mount test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-105889)
 - mounts-v2: add new criu optioin --mounts-compat and drop --mounts-v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-106066)
 - cgroup: add some additional debugging information (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in criu_opts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to vz specific fields in pstree_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-120974)
 - vz/images: add vz_ prefix to vz specific fields in mnt_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz/images: add VZ_ prefix to NSFS fstype (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz/images: add vz_ prefix to pid_for_children_ns_id field (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - vz: use 1000+x field ids for vz-only field ids (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add testcase for procfs with nested pid namespace on ro / (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - mounts-v2: add posibility to create internal yard on ro mounts (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106440)
 - zdtm: add vxlan interfaces c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843)
 - net: add vxlan interfaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105843)
 - action-scripts: export devtmpfs mount path in service mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - mount: make mount_resolve_path use get_relative_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - mount: remove const from path pointer in mount_resolve_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106869)
 - sk-unix: add some missed error printing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106906)
 - mount-v2: make is_internal_yard check nsid for null (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-106854)
 - sk-unix: add fake queuers only for sockets without peer (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add testcase for bind mounted unix sockets with additional mntns
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - sk-unix: preserve mnt_id for bindmounted unix sockets from SIOCUNIXFILE
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-106703)
 - restore/pstree: make wait_on_helpers_zombies wait on proper pid level (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new detached_namespace_with_bindmount test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - zdtm: put common prepare_dirname function to library (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: handle detached network namespace bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104871)
 - mount: add plain mountpoint for cr_time mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96757 #PSBM-96757 #PSBM-107632)
 - zdtm: bind-mount-unix: fix one another absolute path for vzt-cpt (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96757)
 - zdtm: pidns_proc: use vz dir instead of tty (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: bind-mount-unix: make absolute path always right (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm/jenkins: enable mounts-v2 by default for tests which require it (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add mount_complex_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101807)
 - zdtm: added inotify on overlayfs test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: change overlayfs_fsnotify00 logic for a more generic fsnotify testing
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: renamed overlayfs_fanotify01 to overlayfs_fsnotify00 (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added overlayfs_fanotify02 test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: added sequence number to test overlayfs_fanotify (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: add testcase for multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800)
 - sk-unix: add support of multiple unix sk bindmounts (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800)
 - zdtm: add several extra cases for bindmounted unix sk (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800)
 - sk-unix: make bindmounted unix sockets work on mounts-v2 (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104800)
 - zdtm: add netns_sysfs test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: restore sysfs from proper netns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - mount: add after_parse callback (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - mount: do collect_mntinfo of external mount namespace with no for_dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-105161)
 - zdtm: added overlayfs setup routine to zdtm lib (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: disable overlayfs test for old mounts engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: Added overlayfs_fanotify test (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: optionally skip inode number and fhandle in fanotify_obj_cmp (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - zdtm: moved fanotify-specific code to lib, renamed functions that form api.
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-104961)
 - pstree: set mntns, cgroupns ids in dup_zombie_ids (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-105456)
 - fix mount-v2: temporary mount internal yards to mntns trees (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add new pidns_proc test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: delayed nested pidns owned proc mounting (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_mnt_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: split out __resolve_mnt_path_fd helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: add resolve_fd_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create helpers for ancestors of nested pidns procs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: export mnt_subtree_next helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: dump owner pidns'es of proc mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: temporary mount enabled internal yards to mntns trees (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: prepare to mount internal yard mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: create internal yard mounts for each mntns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make is_dir int and -1 initialized (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: fix criu fail with lazy-pages and pre c\r (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - jenkins: exclude ns_file_bindmount and thp_disable from tests (Andrey
Zhadchenko <andrey.zhadchenko@virtuozzo.com>)
 - pstree: fix nested namespaces for lazy-pages (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-104329)
 - zdtm: fix race in pidns02 test plus small cleanup (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-104930)
 - cr-dump: fix vpid corruption on pre-dump (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-104960)
 - mount: adjust log level for get_clean_mnt (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-96506)
 - mount: adjust log level for mnt_is_dir (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-96506)
 - zdtm: add somaxconn test (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>) (#PSBM-94854)
 - zdtm: fix pidns03 racy test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-104930)
 - pstree: fix race in setpgid prechecks (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add dup_helper_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: add dup_thread_ids helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: fixup ids copying from parent for zombies (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - net: fix external veth pairs name collision (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-29271)
 - ns: fix forward compatibility when we don't know owner userns (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - jenkins: run all tests both for old mounts and mounts-v2 (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add internal overlayfs mounts c/r test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614 #PSBM-121284)
 - overlayfs: add internal overlayfs mounts support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-58614)
 - zdtm: add new test ns_file_bindmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - zdtm: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - mount-v2: support of nsfs bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - namespaces: add get_ns_desc_by_cflags helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - check-mounts: ignore nsids in root check for ns bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - nsfs: parse id for namespace file bindmounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - namespaces: add get_ns_kid helper with plain args (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - check-mounts: pass for_dump false to collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-102357)
 - zdtm: enable mounts-v2 on restore with --mounts-v2 option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: move yard, is_overmounted and merging trees to read_mnt_ns_img (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: restore_mount_sharing_options at the end of forking stage (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cr-restore: move CR_STATE_RESTORE switch to restore_root_task (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: call resolve_shared_mounts_v2 earier from read_mnt_ns_img (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: put mounted to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put mp_fd_id and mnt_fd_id to shared memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make general place for shared variables on mount-info on restore
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: detect unsupported mntns root overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - util: don't take nested lock for call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix broken remounted_rw check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount-v2: use plain_mountpoint explicitly in set_unbindable_v2 (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount-v2: add shared group restore debug (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add one more list validation check to cr_time mount removal (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix mnt_sharing list not initialized (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-105464)
 - mount-v2: treat mount as file-bindmount if mountpoint is not directory (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: remove external sharing check from mnt_ext_sharing (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: add new mounts-v2 engine (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: add plain mountpoints (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - config/rpc: add new option --mounts-v2 to enable new engine for mounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - files-reg: teach create_spfs and open_remap_spfs_linked to work with mounts
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-105661)
 - files-reg: teach clean_one_remap to work with plain mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - files-reg: teach create_ghost to work with plain mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: add service_mountpoint getter for ->mountpoint (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint instead of mountpoint where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint in mnt_depth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint in aufs_parse (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint in collect_mntinfo (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint in mnt_get_sibling_path for relative path (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint for children-overmount check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint in root_path_from_parent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: use ns_mountpoint in validate_children_collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: skip root yard children from mnt_needs_remap check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: move set_is_overmounted before doing trees merge (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: add helper mnt_get_external_nodev (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - autofs: fix autofs_create_dentries (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - util: add get_relative_path helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617 #PSBM-106869)
 - mount: add mnt_get_root helper (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: apply superblock flags to nested ns roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: do search_bindmounts earlier (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - mount: replace CRTIME_MNT_ID with HELPER_MNT_ID (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - spfs: remove unused mountpoint variable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-58617)
 - zdtm: add c/r test for several IPC namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - ipc_ns: add several IPC namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103858 #PSBM-58611)
 - zdtm: add c/r test for several UTS namespaces (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - uts_ns: add several UTS namespaces support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612)
 - namespaces: add prepare_namespaces(), restore_task_ns() helpers (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - namespaces: make nsfd_id/ns_fd union common for all namespaces (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103863 #PSBM-58612 #PSBM-103858 #PSBM-58611)
 - mount: allow nested mount namespaces with different roots (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: dump pipes only on read end (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pipes: print errno on fcntl error (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - userns: disable nested userns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Mark ns tests as auto (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: test pgid is restored fine in nested pidnses (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: Nested pid_ns support (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: leaders wait group members temporary setpgid to their pid (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: add set_pgid function to check everything before real syscall (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: check that all processes see their group leader (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns: add get_relative_pid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add curr_sid/pgid updating them on fork/setsid/setpgid (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add prepare_pstree_leaders to create sid/pgid helpers in advance
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_group_leader helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with tricky setns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: test for new init reparent handling with nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: add test for new init reparent handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: rework init reparent handling for pid namespaces (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: add can_inherit_sid helper (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: make helper items for pgid replaceable (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - cr-restore: make collect_child_pids work for nested pidns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restore: add get_pidns_on_level and have_nested_pidns helpers (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: make equal_pid handle sid comparison between nested pidnses (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add is_session_leader helper and use it where possible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add helper for_each_pssubtree_item to walk item's subtree (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree/pid: add helper to get free pids in pidns and all it's ancestors
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - pstree: add id intersection bug_on to prepare_pstree_for_shell_job (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: Add pidns03 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Restore pid_for_children ns in threads (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: First stage of restore pid_for_children ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - fork: Move ns-specific code to setup_child_task_namespaces() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump threads pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Collect/read pid_for_children ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: add BUG_ON on ns_next_id overflow (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add alternative name for pid namespace (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add possibility to read a ns by alternative name in __get_ns_id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - kerndat: Check for /proc/[pid]/ns/pid_for_children_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - dump: More obvious assignment of top_pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Add pidns02 test (test on zombies) (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Add helpers for ordered linking child task to parent (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Add ns_get_parent() feature (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add ns_get_userns() feature (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: return userns checks to netns_sub_veth (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Delete checks of always existing pstree_item::ids on restore (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Check for always existing task ids on restore (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Convert waited helpers and zombies pids in parent's pid_ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restore: Always set real pid in restore_task_with_children() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Use CLONE_NEWPID only to create child reaper of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Check for equality of getpid() of child to last_level_pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restorer: Set NStids in all pid_ns for thread before we create it. (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - restorer: Close transport socket later (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Teach set_next_pid() working with nested pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Set user_ns before creation of pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Set pid_ns before we create a child (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Wait till pid_ns created before we create a child of this ns (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pid: Create pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add usernsd signal handler (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - cr-restore: Add argument to criu_signals_setup() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Install transport fd socket in usernsd (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add pid ns futex helper_created (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Always start usernsd (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Save created pid_ns fd to fdstore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add fdstore id for pid_ns descriptor (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Always lock last pid file on clone() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - restore: Implement set_next_pid() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Reserve pid_ns helpers (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Extract __pstree_item_by_virt() to act on any pid_ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Make get_free_pid() work for different pid_ns and export it (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Dump and restore NSpid, NSsid etc (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - images: Add NSpids pstree descriptions (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zombie: Kill by last_level_pid, not by vpid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Skip zombie dumping tricks if there is kdat.has_nspid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Collect NSpid, NSsid and NStgid when possible (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Pre-dump ns ids before tasks (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Change arguments in parse_pid_status() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid_ns: Implement pid_ns_root_off() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add pidns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: don't xfree shmalloced memory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - pstree: Implement free_pstree_item() helper (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Implement vpgid(), vsid() and vtid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - kerndat: Check that "/proc/[pid]/status" file has NS{pid, ..} lines (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Make lookup_create_pid() able to create tasks with pid->level > 1
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: initialize rbtree nodes (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: Add MAX_NS_NESTING (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns id argument to lookup_create_pid() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Split lookup_create_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Add pid_ns check in read_pstree_image (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Dump pid and user ns ids for dead tasks (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Assign ids for dead tasks in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Move parent assignment in read_pstree_image() up (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ids: Copy unexisted ids from root_item (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add ns::pid::rb_root (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add top_pid_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Read ids earlier in read_pstree_image() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pstree: Change arguments of read_pstree_ids() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Pass thread pid to caller (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Alloc threads dynamically (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Make pgid and sid be allocated dynamically (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - pid: Add last_level_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add equel_pid() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pid: Add pid::level field and level argument for __alloc_pstree_item()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - pstree: Introduce PID_SIZE() helper (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add proc-self01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns02 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Use rst_new_ns_id() in read_ns_with_hookups() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Replace task argument rst_add_ns_id() with pid (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Set NS_ROOT namespaces after tasks are read (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Override fake pid in rst_add_ns_id() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for fsuid and fsgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for euid, suid, egid and sgid in userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - zdtm: Check for groups list userns01 test (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Keep all clone flags fixups together (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Allow nested user namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Convert task cred's xids to target user ns (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Dump creds xids in root_user_ns (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - rst: Pass pstree_item argument to alloc_groups_copy_creds() (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - shmem: Fixup shmem_wait_and_open() opens foreign /proc/[pid]/fd/[i] (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set target user_ns after net_ns is set (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement set_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Introduce open_fd_of_real_pid() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Set user_ns before net_ns creation (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Generate user_ns tree (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - utils: Move getting real pid functionality to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make write_id_map() use CR_PROC_FD_OFF (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Make prepare_userns() have ns map parameter (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Write/read ns entries in new way (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - proto: Add ns_entry description (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - images: Move uid_gid_extent and userns_entry descriptions (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Implement dup_userns_entry() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set pointer to root_user_ns in ns_ids (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - ns: Provide the case when root_item has !NS_ROOT user_ns in rst_add_ns_id()
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - user_ns: Name loading UsernsEntry mappings on restore "old format" (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Add user and pid ns_id on restore (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Implement target_userns_{u, g}id() and root_userns_{u, g}id() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Rename and export userns_id() and INVALID_ID (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make host_id() working with any mapping and rename it (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - user_ns: Make collect_user_ns() allocate child UsernsEntry mappings (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - ns: Change arguments of dump_user_ns() (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns01 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - zdtm: Add userns00 test (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - net: replace is_zdtm_run with if we dump userns check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: Add raw fork() implementation (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - criu: don't use a glibc cached pid (Andrei Vagin <avagin@virtuozzo.com>)
 - zdtm: Return tun test back as "auto" (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - spfs: fix "uns: message size exceeded" error (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-103828)
 - spfs: nfs link remap EPERM error fix on recent kernels (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102889)
 - util: merge call_helper_process and call_in_child_process (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - util: don not use cached proc self fd in call_in_child_process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101289)
 - mount: replace "internal slavery for external mounts unsupported" error to
warning (Alexander Mikhalitsyn <alexander@mihalicyn.com>) (#PSBM-103051)
 - mount: fix resolving bindmounts of external device mounts (Alexander
Mikhalitsyn <alexander@mihalicyn.com>) (#PSBM-102980)
 - sk-unix: fix not correct assertion in on_stage_change() that fails restore
stage (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-102972)
 - mount: fix failed assertion in mnt_is_external (Alexander Mikhalitsyn
<alexander@mihalicyn.com>) (#PSBM-102791)
 - zdtm: add sk-unix-dgram-ghost test case (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - sk-unix: wake connected sockets strictly after fle stage >= FLE_OPEN
(Alexander Mikhalitsyn <alexander@mihalicyn.com>) (#PSBM-102605)
 - files: add on_stage_change callback to file_desc_ops (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - zdtm/iptables: wait xtables lock in netns-ipset (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: also honor external_slavery and internal_sharing for root mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-100080)
 - mount: add new mnt_ext_master_manual test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: fix handling of binds of external mount with external slavery (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - zdtm: add new mnt_ext_root test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: mount external mount before mounting it's binds (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: add external_slavery detection (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - zdtm: add external sharing to mnt_ext_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: make honest external/internal sharing detection (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: split mnt_is_external and can_receive_master_from_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: setup mnt_bind list before using it in mnt_is_external (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - zdtm: add new mnt_ext_sharing test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - mount: remove source check from mounts_sb_equal (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - zdtm: fix mnt_ext_master test to correspond to it's name (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - zdtm: Added test that covers ipset checkpoint/restore functionality (Valeriy
Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - dump/restore: Support ipsets (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - Makefile/plugin: install more headers (Alexander Stefanov
<astefanov@virtuozzo.com>) (#PSBM-99926)
 - files-reg: temporary remount writable the mount we do unlink on (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - ghost/mount: allocate remounted_rw in shmem to get info from other processes
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - files-reg: add debug for ENOTEMPTY on unlinkat (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - files-reg: fix error handling of rm_parent_dirs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - files-reg: fix error handling in open_path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - dump/restore: Maintain proper start_time param from /proc/[pid]/stat for each
task (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123)
 - cr-restore: handle join_ve0 errors in restore_root_task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - spfs, files-reg: symbolic links support (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)
 - files: also print the mnt_id of the overmounted mount with open files (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)
 - net: add nftables c/r (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958)
 - net: separate tables_restore from iptables_tool_restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-98958)
 - mount: Add missing newline into the log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - pie/restorer: Fix typo in debug print (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-98453)
 - vz7: don't get out VEX cgroup for iptables restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-98702)
 - restore: don't miss futex abort in restore_task_with_children (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz7: systemd-autofs-restart.sh: add --skipowner vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)
 - vz7: systemd-autofs-restart.sh: use exec3 and input from /dev/null (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)
 - vz7: systemd-autofs-restart.sh: add --skiplock vzctl exec option (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)
 - vz7: systemd-autofs-restart.sh: use vzctl instead of nsenter for safety
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)
 - mount: mark mounts of external devices external (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-97810 #PSBM-100775)
 - mount: add a message about found dev-mapping (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: restore shared options in clean mount for external mounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-97787)
 - mount: show more info about why we can't mount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - test: Add pipe04 test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - pipes: Make pipe_data_dump dynamic (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-97048)
 - restorer: Add debug print for clone call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-97408)
 - mount: fix external mounts so that they pass check-mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385)
 - test: transition/epoll -- Don't fail on EINTR (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96981)
 - mount/restore: create mountpoint for auxiliary binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96621)
 - mount: fix error print in case of failed bind-mount (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96082 #PSBM-96362)
 - mount: remove a leftover mnt_path check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96087)
 - mount: check error return of cut_root_for_bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96087)
 - check-mounts/spfs: skip flags check for nfs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96106)
 - check-mounts: check all mntnses before failing to have a full picture (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96106)
 - mount/check-mounts: remove auxiliary cr-time mount from tree after umount
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96082)
 - pie/restorer: Reread last_pid on error (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - pie/restorer: Fix fd leaking on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96105)
 - seize: Print tracer pid for debug sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-96110)
 - mem/pagema-cache: Drop confusing log (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - mem: generate_iovs -- Use pmc_get_pfn_from helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagemap-cache: Provide api for map access (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/pagema-cache: Make sure we're not accessing stale data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775)
 - spfs: make spfs logs relative to criu working directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-59204)
 - pid-reuse: Ensure we're fetching params from ve0 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-95422)
 - fsnotify: Allow to get updated restored wd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - Revert "vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly" (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz: close_fds -- Addition to 6af5df67245755cf7e75553ee65b4a360cbdc602 (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-95035)
 - vz: close_fds -- Skip closing external service fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94949)
 - netlink: Fix for 52828b9aa350cb027c2cb4c1330e0cd7ceac4b46 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: x86,cpu -- Fixup for 4d76e16247621082580e1d137aeba18791040541 (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - log: Increase early log buffer (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: cpu -- Move vz_cpu_parse_cpuid_override to early_init (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-85265)
 - test: bers -- Provide --pidfile option (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fsnotify: Add error print for nexwd failure (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91520)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - spfs: Fix typo in get_spfs_mngr_sock (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-93462)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - zdtm: use --check-mounts by default (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - rpc: Add interface for --check-mounts option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: check that mounts tree restored without any hidden problems (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - epoll: Fix qsort args passing (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022)
 - mount: temporary create needed ancestor directories for deleted root (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022)
 - arch,x86: Investigate OSPKE status when handling PKU (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-91098)
 - ve: tty -- Preallocate space for itty pool (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Drop leftover comment (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Investigate master fds with a mutex taken (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90662)
 - test: tty-inherit -- Don't forget to clean buffer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94706)
 - test: tty-inherit -- Handle parse_pid_stat errors (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-94405)
 - ve: tty -- Add tty-inherit test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Add support of tty inheritance, v2 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-76490 #PSBM-96852)
 - crtools: Show command line in log (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - files: Select proper master fd when collecting fd (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: netns_sub_veth -- Disable for a while (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Fix hang if root task is waiting on zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89830)
 - restore: Don't ignore errors on wait in restore_one_zombie (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: Add more detailed log in wait_exiting_children (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - restore: zombie -- Add more detailed log on signals (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - inet: raw -- Add compatibility layer for old images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - net: Add prefixes for better logging (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mount: cr_pivot_root -- Try temp directory first (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89582)
 - mount: Fix typo in message (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: test -- Improve error messaging in file_fown_dead (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Update file_own_dead to test O_PATH case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - fown: test -- Add file_fown_dead (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - fown: Dont fail if owner is a dead pid (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-88336)
 - ve: tty -- Add more detailed debug print in ctty verification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save pid of a task which setups a controlling terminal (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Save tty_pgrp in process tree upon read (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Don't forget to restore original errno (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - pr-warn: Add missing newlines (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - compel: Don't forget to zap remote_map pointer after release (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89231)
 - ve: tty -- Don't stuck if several ctty opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Save virtual group id (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - ve: tty -- Collect real ppid, pgid, sid on dump (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - unix: Disable switching mount namespace (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-89126)
 - vz7: files-reg -- Show which exactly file can't be created (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Don't forget to close ns descriptor on error path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tun: Add compatibility with old images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: bind-mount-unix -- Implement real connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bind_unix_sk -- Add ability to skip waiters notification (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: make_socket -- Add more detailed logs (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: break_connected -- Add a log recod (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: bindmount -- Show details about queuer (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - test: sk-unix-ucred -- Make compatible with gcc 8 (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - test: cgroup04 -- Disable (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - unix: test -- Add bind-mount-unix test case (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Add support for bindmounted sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-96943)
 - mount: rework phys_stat_dev_match to work directly with mount_info (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)
 - unix: image -- Move uflags into enum (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: sk-unix -- Restore qlen before pushing queued data back (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - spfs: suppress compilation warnings by roughly approximating path lenths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz7/mount: show the real mount which is behind the clean mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz7: reenable not-failing cgroup tests in automatic runs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-86775)
 - zdtm: temporary make mnt_ext_auto and private_bind_propagation noauto (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-85251)
 - net: Add net log prefix (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: net -- Add missing newline into debug message (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - files: Don't forget on stipping deleted postfix on linked files (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-84731)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - vz: test,file_lease00 -- Disable for a while (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,pipe03 -- Don't run in uns (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,transition,fork -- Postpone for a while (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,thread_different_uid_gid -- Postpone for a while (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,sched_policy00 -- Drop ns flag for a while (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,cgroups -- Skip testing via zdtm run (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: test,tty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz: test,pty -- Use ns flavor (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz: zdtm,dump,bc -- Skip bc read/write when testing (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: zdtm -- Don't fail in __construct_root if entries exist (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: net: do iptables restore in ve0 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-58574)
 - vz7: net: iptables_tool_{dump,restore} helpers introduced (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61573 #PSBM-61812)
 - tty: Move session lookup leader into find_session_leader (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fetch ctty index based on sid (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Add is_ctty helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Don't check for group inheritance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - files-reg: Prepare for sysfs entries mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-80095)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: improve prints in spfs_set_mode() and spfs_release_replace() (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: improve SPFS manager start debug and error output (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-78460)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531)
 - action-scripts: Export mount namespace roots via CRIU_MNT_NS_ROOTS (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-71861)
 - mount: Add export_mnt_ns_roots helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-71861)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - tty: collect_one_tty_info_entry -- Move tracking setup into main cycle
(Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-70929)
 - tty: collect_one_tty -- Make sure the index is in range (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_has_active_pair -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: tty_test_and_set -- Make sure no overflow happened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - tty: Fix __tty_verify_active_pairs (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - tty: Use macros for bitmap length (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: images -- Add task_core_entry_vz730 stub (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-67671)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-68738)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: criu: export join_ve helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: mount: allow any types of NFS mount for a while (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-68663)
 - vz7: mounts: support NFS bind-mounts in the same shared group (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-68663)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: mounts: support only shared NFS mounts in inits mount namespace
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66945)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Don't search for siblings inside self (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67723)
 - vz7: cr-service: Init page_ids laterly (Dmitry Safonov
<dsafonov@virtuozzo.com>)
 - vz7: images: Initialize images earlier (before page-server starts) (Dmitry
Safonov <dsafonov@virtuozzo.com>) (#PSBM-67335)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: mounts: print NFS nested mountpoint info (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: tests: shm-unaligned -- Use unique key for simultaneous run (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-66764)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: Makefile: Fix scripts installation (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-65185)
 - vz7: restore_sk_queue -- Show how many bytes already sent (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64628)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-62778)
 - vz7: sk-queue -- Show the creds we're sending (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-64009)
 - vz7: seize -- Wait for seize in thawed state (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Show status of uninterruptable task (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-63211)
 - vz7: ucred -- Drop packets from dead processes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-62603)
 - vz7: test: Add ucreds test (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61095)
 - vz7: Zap file size checking for "atop" (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61459)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-61248)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606 #PSBM-61459 #PSBM-61851)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - vz7: mount: fix mounting non-root shared mounts (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-55494)
 - vz7: pipes -- Restore pipe size via userns call (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-59829)
 - vz7: test: pty05 -- Add testing of multiple devpts instance (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: Unlimit UBC when chekpointing (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-53593 #PSBM-61534 #PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-56407)
 - vz: kdat -- Query zdtm status runtime (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz: zdtm -- Export ZDTM_RUN variable to notify criu (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: Don't use executable stacks in @syscall_ip (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-55989)
 - vz7: util: Add rmdirp helper (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: mount: handle error from restore_shared_options() (Andrei Vagin
<avagin@openvz.org>)
 - vz7: seize: Add additional diagnose messages (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-53929)
 - vz7: mount: bind-mount autofs mounts via a file descriptors (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-53194)
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199)
 - vz7: spfs: move SPFS manager to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: mnt -- Fetch VEID from cgroup for migration sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-52372)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320)
 - vz7: cg: Don't dump devices.list (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-50551)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: mount: create a temporary mount to restore shared and master groups
(Andrey Vagin <avagin@openvz.org>) (#PSBM-47508 #PSBM-96087)
 - vz7: files-reg: fix silly-renamed files migration (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: split create_ghost (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: remove obsolete scripts (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: Makefile: install spfs-release-replace.sh script (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-49726)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: dump: Show task comm early (Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: explicitly pass size and mode to spfs_create_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - restore: pidfile -- write before post-restore stage (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-90289)
 - log: Write more details in write_pidfile (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: compel -- Add support for vz7 specific cpuid masking (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-47748 #PSBM-49423)
 - vz7: tty: Save task current terminal if present (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: files: Allow to dump ploopX files opened (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-49723)
 - vz7: spfs: remove "ns_list" option from "replace" command as obsolete
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: remove bogus command substitution in nfs-ports-allow.sh (Eugene
Kolomeetz <klm@virtuozzo.com>) (#PSBM-44207)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: spfs: do not treat existent file as error in create_reg_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: spfs-release-replace.sh introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: spfs -- Fixup various nits for NFS sake (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs -- Mitigate sock_seqpacket_connect (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: spfs -- Mitigate spfs_manager_socket_path (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: spfs-change-mode.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488 #PSBM-42488)
 - build: Switch to v3.15 vanila branch (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - namespaces: don't set rst on error in switch_ns_by_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - nft: revert nftables c/r via libnftables (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - memfd: use PROC_SELF instead of getpid in __open_proc (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - util: move open_proc_self_fd to service_fd (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - servicefd: fully cleanup parent's shared fd table on service fd update (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - restore: disable clone3 + set_tid code (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cr-restore: setup external pidns only for root task (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - namespaces: make root_ns_mask more consistent (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - cr-restore: make CLONE_NEWPID flag in clone_flags more consistent (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-121533)
 - restore: Value stored to 'ret' is never read (Adrian Reber
<areber@redhat.com>)
 - criu: Version 3.15 (Andrei Vagin <avagin@gmail.com>)
 - travis: install gzip and redhat-rpm-config for Fedora Rawhide based tests
(Adrian Reber <areber@redhat.com>)
 - x86/asm: update test_bit() and test_and_set_bit() (Mike Rapoport
<rppt@linux.ibm.com>)
 - zdtm: add alternative socket filter (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - sockets: fix incorrect malloc size (Andrey Zhadchenko
<andrey.zhadchenko@virtuozzo.com>)
 - compel: Calculate sh_addr if not provided by linker (Wojciech Marczenko
<marczenko@google.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - mount: Explicit null dereferenced (FORWARD_NULL) (Adrian Reber
<areber@redhat.com>)
 - util: Improper use of negative value (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - page-xfer: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - sk-netlink: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - kerndat: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - action-scripts: Improper use of negative value (NEGATIVE_RETURNS) (Adrian
Reber <areber@redhat.com>)
 - cr-dump: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - irmap: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - proc_parse: Copy into fixed size buffer (STRING_OVERFLOW) (Adrian Reber
<areber@redhat.com>)
 - autofs: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup-props: Resource leak (RESOURCE_LEAK) (Adrian Reber
<areber@redhat.com>)
 - filesystem: Double close (USE_AFTER_FREE) (Adrian Reber <areber@redhat.com>)
 - uffd: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - mount: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Logically dead code (DEADCODE) (Adrian Reber <areber@redhat.com>)
 - files-reg: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - pagemap: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - cgroup: Resource leak (RESOURCE_LEAK) (Adrian Reber <areber@redhat.com>)
 - img-streamer: Double close (USE_AFTER_FREE) (Adrian Reber
<areber@redhat.com>)
 - net: Argument cannot be negative (NEGATIVE_RETURNS) (Adrian Reber
<areber@redhat.com>)
 - zdtm: update and refactor tests for BPF array and hash maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: adding support for BPF map name, ifindex and freeze (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: adding support for BPF map file name and ifindex (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding BPF helper functions as a new library (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - servicefd: close temporary fd on error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - criu: check matching the tcp-close option on restore only (Andrei Vagin
<avagin@gmail.com>)
 - tcp: add a separate test for listen sockets (Andrei Vagin <avagin@gmail.com>)
 - tcp: dump shutdown state for unconnected sockets (Andrei Vagin
<avagin@gmail.com>)
 - CI: run cross compile on all branches (Adrian Reber <areber@redhat.com>)
 - CI: add Travis test script to 'lint' (Adrian Reber <areber@redhat.com>)
 - CI: switch to loop based apt-get (Adrian Reber <areber@redhat.com>)
 - tests: only run 'make lint' once in CI (Adrian Reber <areber@redhat.com>)
 - scripts: run shellcheck on the scripts folder (Adrian Reber
<areber@redhat.com>)
 - crtools: Fix --help output line width (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - doc: update documentations for the tcp-close option (Andrei Vagin
<avagin@gmail.com>)
 - tcp: allow to specify --tcp-close on dump (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm: write in a tcp socket has to fail if tcp-close was set (Andrei
Vagin <avagin@gmail.com>)
 - socket/tcp: shutdown tcp sockets if the tcp-close option is set (Andrei Vagin
<avagin@gmail.com>)
 - Switch to python 3 variants of dependencies on debian-based builds
(Sebastiaan van Stijn <github@gone.nl>)
 - mips64: implement vdso_redirect_calls() (Guoyun Sun <sunguoyun@loongson.cn>)
 - zdtm: Add test for SO_LINDER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_LINGER (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_OOBINLINE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: check that unbindable mount flag does not affect restore (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: replace mountpoint to mnt_id in error messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - sk-netlink: Handle case of in-use netlink peer ids (Hello1024
<omattos@gmail.com>)
 - images: kindly ask not to use fields with id 18 in unix_sk_entry (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add new epoll01 test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - eventpoll: fix toff off calculation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - eventpoll: resort toff back by idx (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: use Fedora rawhide images from Fedora (Adrian Reber
<areber@redhat.com>)
 - travis: restore lazy-pages tests for uns flavor (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: don't use the deprecated security_context_t (SELinux) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - scripts: adding libbpf for Travis tests (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - zdtm: adding tests for BPF maps (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: restoring BPF maps (without data) (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - crit: add BPF map data decoding (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping BPF map data (Abhishek Vijeev <abhishek.vijeev@gmail.com>)
 - criu: dumping meta-data about BPF map files (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: parse information about BPF maps from procfs (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - Set Makefile config variables for libbpf (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - criu: define constants for c/r of BPF maps (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - images: protobuf definitions for BPF map meta-data and data (Abhishek Vijeev
<abhishek.vijeev@gmail.com>)
 - travis: add a focal based test run (Adrian Reber <areber@redhat.com>)
 - travis: switch travis to Python 3 (Adrian Reber <areber@redhat.com>)
 - contrib: Add python-future to Debian packages (Pavel Emelyanov
<xemul@openvz.org>)
 - github: disable cross-compule for mips on master branch (Mike Rapoport
<rppt@linux.ibm.com>)
 - criu: the type of a socket inode has to be "unsigned int" (Andrei Vagin
<avagin@gmail.com>)
 - actions: create file for daily rebuild (Adrian Reber <areber@redhat.com>)
 - travis: loop over apt-get to recover from errors (Adrian Reber
<areber@redhat.com>)
 - Makefiles: do not re-generate magic.py every time (Adrian Reber
<areber@redhat.com>)
 - python: Handle byte strings when converting protobuf to dict (Otto Bittner
<otto-bittner@gmx.de>)
 - CONTRIBUTING.md: clarify placement of Fixes: tags (Mike Rapoport
<rppt@linux.ibm.com>)
 - lib/c: extend receive to handle incoming FDs (Adrian Reber
<areber@redhat.com>)
 - log: Ask developers not to use print_on_level directly (Pavel Emelyanov
<xemul@openvz.org>)
 - log: Hide vprint_on_level in log.c (Pavel Emelyanov <xemul@openvz.org>)
 - util: Use pr_info in vma printing (Pavel Emelyanov <xemul@openvz.org>)
 - ipc: Use pr_info() instead of print_on_level(PR_INFO...) (Pavel Emelyanov
<xemul@openvz.org>)
 - proc_parse: Do not feed loglevel into restore_loginuid (Pavel Emelyanov
<xemul@openvz.org>)
 - check: Use pr_foo macros (Pavel Emelyanov <xemul@openvz.org>)
 - vagrant: Update to Fedora 32 (Radostin Stoyanov
<rstoyanov@fedoraproject.org>)
 - criu/files-reg.c: build-id size bug fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: build-id from multiple headers fix (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - compel/infect: Don't adjust stack/args alignment (Dmitry Safonov
<dima@arista.com>)
 - compel: allocate the GOT table to avoid memory corruption (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: remove x86/prologue.S (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: x86 parasite_service entry point simplification (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: rewrite parasite cmd and args manipulation from assembly to C
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: stop rounding up the parasite blob size and args region to PAGE_SIZE
(Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - compel: remove "addr_" from offset variable names (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: pass the parasite_blob_desc to compel_relocs_apply() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - compel: add error message for COMMON symbols (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: make cgroup_yard to be aware of cgroup2 (Andrei Vagin
<avagin@gmail.com>)
 - tests: skip cgroup04 and cgroup_ifpriomap on pure cgroup2 systems (Andrei
Vagin <avagin@gmail.com>)
 - zdtm.py: add the cgroup2 freezer support (Andrei Vagin <avagin@gmail.com>)
 - cgroup: Add the initial support for cgroup2 (Andrei Vagin <avagin@gmail.com>)
 - pidns: fixup (Adrian Reber <areber@redhat.com>)
 - criu/config.c: added cli option for build-id (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - criu/files-reg.c: add build-id validation functionality (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - images/regfile.proto: adds additional fields to RegFileEntry (Ajay Bharadwaj
<ajayrbharadwaj@gmail.com>)
 - restore: skip unnecessary setgroups calls (Angie Ni <avtni@google.com>)
 - tests: criu-image-streamer change dev branch to master branch (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - test/zdtm/autofs: use sigaction instead of the deprecated siginterrupt
(Andrei Vagin <avagin@gmail.com>)
 - Add error logging to config + crtools init (Angie Ni <avtni@google.com>)
 - Add error logging to kerndat init (Angie Ni <avtni@google.com>)
 - test: test external namespace support (Adrian Reber <areber@redhat.com>)
 - pidns: add external pidns to man-page (Adrian Reber <areber@redhat.com>)
 - pidns: support external PID namespaces (Adrian Reber <areber@redhat.com>)
 - pidns: write and read pidns information (Adrian Reber <areber@redhat.com>)
 - pidns: add pidns image file definition (Adrian Reber <areber@redhat.com>)
 - zdtm: add zombie_leader test (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - cgroup: make prepare_task_cgroup lookup current cgset in ancestors (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (Cyrill
Gorcunov <gorcunov@virtuozzo.com>)
 - test: skip vdso test on non-vdso systems (Adrian Reber <areber@redhat.com>)
 - uffd: uffd_open prints info, caller prints error (Angie Ni
<avtni@google.com>)
 - CONTRIBUTING.md: add pull request guidelines (Mike Rapoport
<rppt@linux.ibm.com>)
 - CONTRIBUTING.md: add sections about patch description and splitting (Mike
Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: minor formatting fixes (Mike Rapoport <rppt@linux.ibm.com>)
 - CONTRIBUTING.md: import "How to submit patches" from criu.org (Mike Rapoport
<rppt@linux.ibm.com>)
 - Add CONTRIBUTING.md (Mike Rapoport <rppt@linux.ibm.com>)
 - arch/x86: Fix calculation of xstate_size (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - criu swrk: fix usage, allow common options (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - Travis: use Vagrant to run VMs (Adrian Reber <areber@redhat.com>)
 - Also report clone3() errors correctly (Adrian Reber <areber@redhat.com>)
 - test/others/libcriu: test version library calls (Adrian Reber
<areber@redhat.com>)
 - lib/c: add criu_get_version() (Adrian Reber <areber@redhat.com>)
 - criu: optimize find_unix_sk_by_ino() (ZeyadYasser <zeyady98@gmail.com>)
 - swrk: send notification instead of using status fd (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - close_service_fd: rename to status_ready (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - clang: Branch condition evaluates to a garbage value (Adrian Reber
<areber@redhat.com>)
 - coverity: fix FORWARD_NULL in criu/proc_parse.c: 1481 (Adrian Reber
<areber@redhat.com>)
 - coverity: fix RESOURCE_LEAK criu/timens.c: 67 (Adrian Reber
<areber@redhat.com>)
 - libcriu: Add space between 'if' and parenthesis (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - libcriu: Use spaces around '=' (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - libcriu: Add orphan pts master (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - cr-service: spell out an error (Kir Kolyshkin <kolyshkin@gmail.com>)
 - cr-service: fix wording in debug messages (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - tests: move cross compilation to github actions (Adrian Reber
<areber@redhat.com>)
 - travis: use bionic almost everywhere (Adrian Reber <areber@redhat.com>)
 - Remove dupe of "deprecated stuff on" msg (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - soccr/test: Fix error logging in libsoccr tcp-test (Josh Abraham
<sinisterpatrician@gmail.com>)
 - mips: fix fail when run zdtm test pthread01.c (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips: impliment arch_shmat() (Guoyun Sun <sunguoyun@loongson.cn>)
 - test/jenkins: use bash to run shell scripts (Andrei Vagin <avagin@gmail.com>)
 - style: fix typos (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - mips:support  docker-cross compile (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu: Enable mips in criu (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:criu/arch/mips: Add mips parts to criu (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:proto: Add mips to protocol buffer files (Guoyun Sun
<sunguoyun@loongson.cn>)
 - mips:compel: Enable mips in compel/ (Guoyun Sun <sunguoyun@loongson.cn>)
 - mips:compel/arch/mips: Add architecture support to compel tool and libraries
(Guoyun Sun <sunguoyun@loongson.cn>)
 - net: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: Remove deprecated print_data() routine (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - page-read: Warn about async read w/o completion cb (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tests: run tests with criu-image-streamer with --stream (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img-streamer: introduction of criu-image-streamer (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - pipes: loop over splice() when dumping a pipe's data (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - remote: Use tmp file buffer when restore ip dump (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: Fix addr casting for IPv4/IPv6 in autobind (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: fix flake8 errors (Adrian Reber <areber@redhat.com>)
 - travis: fix alpine builds (Adrian Reber <areber@redhat.com>)
 - Update certificates for failing tls based tests (Adrian Reber
<areber@redhat.com>)
 - criu: Version π (Pavel Emelyanov <xemul@openvz.org>)
 - get_clean_mount: demote an error to a warning (Kir Kolyshkin
<kolyshkin@gmail.com>)
 - proc: parse clock symbolic names in /proc/pid/timens_offsets (Andrei Vagin
<avagin@gmail.com>)
 - pstree: improve error handling in read_pstree_image (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - kerndat remove duplicate call to kerndat_nsid() (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - parasite-msg: %u is not implemented for parasite code (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - kerndat: remove duplicate call to kerndat_socket_netns() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - criu: put statement continuation on the same line as the closing bracket
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - autofs: fix integer overflow in mount options parsing (Alexander Mikhalitsyn
<alexander@mihalicyn.com>)
 - mem: avoid re-opening CR_FD_PAGES when not needed (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - img: rellocate a PATH_MAX buffer from the bss section to the stack (Nicolas
Viennot <Nicolas.Viennot@twosigma.com>)
 - img: fix image_name() when image is empty (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: fail if test with the crfail tag passes (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: limit the line length for ps by 160 symbols (Andrei Vagin
<avagin@gmail.com>)
 - timens: restore processes in a new timens to restore clocks (Andrei Vagin
<avagin@gmail.com>)
 - test: check that C/R of nested time namespaces fails (Andrei Vagin
<avagin@gmail.com>)
 - zdtm_ct: run each test in a new time namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a new test to check c/r of time namespaces (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - namespace: fail if ns/time_for_children isn't equal to ns/time (Andrei Vagin
<avagin@gmail.com>)
 - criu: Add support for time namespaces (Andrei Vagin <avagin@gmail.com>)
 - MAINTAINERS: Add Pavel (myself) to maintainers (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - remove header include statements duplicates (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memfd: split the struct memfd_inode (Andrei Vagin <avagin@gmail.com>)
 - memfd: save all memfd inodes in one image (Andrei Vagin <avagin@gmail.com>)
 - Add build directory to gitignore (Byeonggon Lee <gonny952@gmail.com>)
 - namespaces: fix error handling in dump_user_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - config/nftables: include string.h for strlen (Andrei Vagin
<avagin@gmail.com>)
 - test/fifo_loop: change sizes of all fifo-s to fit a test buffer (Andrei Vagin
<avagin@gmail.com>)
 - test/pipe03: check that pipe size is restored (Andrei Vagin
<avagin@gmail.com>)
 - pipe: restore pipe size even if a pipe is empty (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: Use safe helper function to initialize unix socket sockaddr structure
(Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - zdtm: Implemented get_current_dir_name wrapper that checks for 'x'
permissions (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>)
 - test/zdtmp: add a test to C/R shared memory file descriptors (Andrei Vagin
<avagin@gmail.com>)
 - mem/vma: set VMA_FILE_{PRIVATE,SHARED} if a vma file is borrowed (Andrei
Vagin <avagin@gmail.com>)
 - mem: dump shared memory file descriptors (Andrei Vagin <avagin@gmail.com>)
 - make: use cflags/ldflags for config.h detection mechanism (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - mailmap: update my email (Andrei Vagin <avagin@gmail.com>)
 - travis: add ppc64-cross test on amd64 (Mike Rapoport <rppt@linux.ibm.com>)
 - crit-recode: skip (not try to parse) nftables raw image (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: Use debian/buster as base for cross build tests (Dmitry Safonov
<dima@arista.com>)
 - travis: Add aarch64-cross test on amd64 (Dmitry Safonov <dima@arista.com>)
 - compel: Remove compel.h (Dmitry Safonov <dima@arista.com>)
 - criu: Remove compel.h includes (Dmitry Safonov <dima@arista.com>)
 - zdtm/fifo_loop: don't try to write more than pipe size (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: add a test on open symlink migration (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files: allow dumping opened symlinks (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - zdtm: add a test for files opened with O_PATH (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - fown: Don't fail on dumping files opened with O_PATH (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - zdtm/inhfd: force python to read new data from a file (Andrei Vagin
<avagin@gmail.com>)
 - memfd: don't corrupt a state of the dumped fd (Andrei Vagin
<avagin@gmail.com>)
 - fs: use __open_proc instead of open("/proc/...", ... ) (Andrei Vagin
<avagin@gmail.com>)
 - cgroup2: add minimal cgroup2 support (Adrian Reber <areber@redhat.com>)
 - seize: support cgroup v2 freezer (Adrian Reber <areber@redhat.com>)
 - seize: factor out opening and writing the freezer state (Adrian Reber
<areber@redhat.com>)
 - seize: prepare for cgroupv2 freezer (Adrian Reber <areber@redhat.com>)
 - criu(8): Convert tabs to spaces (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - criu(8): Add documentation for --enable-fs (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - uffd: use userns_call() to execute ioctl(UFFDIO_API) (Mike Rapoport
<rppt@linux.ibm.com>)
 - test/jenkins: remove empty line at the end of file (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - criu: Use strlcpy() instead of strncpy() (Dmitry Safonov <dima@arista.com>)
 - memfd: add tests (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - inhfd_test: add support for non-pair files (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add seals support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - memfd: add memory mapping support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add --inherit-fd support (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: increase path buffer size in inherited_fd() (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - memfd: add file support (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - MAINTAINERS: Add Dima and Adrian to maintainers (Andrei Vagin
<avagin@google.com>)
 - MAINTAINERS: add Mike (Mike Rapoport <rppt@linux.ibm.com>)
 - Maintainers: Suggest the maintainers codex (#932) (Pavel Emelyanov
<xemul@openvz.org>)
 - python: sort imports (Andrei Vagin <avagin@gmail.com>)
 - test/zdtm/inhfd: update dump options one each iteration (Andrei Vagin
<avagin@gmail.com>)
 - Travis: fix podman test case (Adrian Reber <areber@redhat.com>)
 - zdtm: mntns_rw_ro_rw update error msg (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - vdso: Don't page-align vvar (Dmitry Safonov <dima@arista.com>)
 - vdso: Repair !CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - vdso: Add vdso_is_present() helper (Dmitry Safonov <dima@arista.com>)
 - zdtm: Make test_{doc,author} weak variables (Dmitry Safonov
<dima@arista.com>)
 - criu: Make use strlcpy() to copy into allocated strings (Dmitry Safonov
<dima@arista.com>)
 - typo: fix missing space in error message (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - vdso: use correct offsets to remap vdso and vvar mappings (Andrei Vagin
<avagin@gmail.com>)
 - test/vdso: check the code path when here is no API to map vDSO (Andrei Vagin
<avagin@gmail.com>)
 - criu: fix build failure against gcc-10 (Sergei Trofimovich
<slyfox@gentoo.org>)
 - criu(8): fix for asciidoctor (Kir Kolyshkin <kolyshkin@gmail.com>)
 - criu(8): some minor rewording (Kir Kolyshkin <kolyshkin@gmail.com>)
 - doc/Makefile: don't hide xmlto stderr (Kir Kolyshkin <kolyshkin@gmail.com>)
 - compel: add -ffreestanding to force gcc not to use builtin memcpy, memset
(Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - travis: fix warning and errors from validation (Adrian Reber
<areber@redhat.com>)
 - arm: use clone3() if it exists (Adrian Reber <areber@redhat.com>)
 - aarch64: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - clone3: handle clone3() with CLONE_PARENT (Adrian Reber <areber@redhat.com>)
 - ppc64le: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - arm: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - s390x: use clone3() if possible (Adrian Reber <areber@redhat.com>)
 - s390x: remove stack pointer from clobber list (Adrian Reber
<areber@redhat.com>)
 - Use clone3() with set_tid to create processes (Adrian Reber
<areber@redhat.com>)
 - Add assembler wrapper for clone3() (Adrian Reber <areber@redhat.com>)
 - kerndat: detect if system support clone3() with set_tid (Adrian Reber
<areber@redhat.com>)
 - travis: reduce the number of podman tests (Adrian Reber <areber@redhat.com>)
 - image: core -- Reserve start_time field (Valeriy Vdovin
<valeriy.vdovin@virtuozzo.com>)
 - ppc64le: remove register '1' from clobber list (Adrian Reber
<areber@redhat.com>)
 - Switch open-j9 alpine tests to python3 (Nidhi Gupta <itsnidhi16@gmail.com>)
 - Add Socket-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - travis: switch alpine to python3 (Adrian Reber <areber@redhat.com>)
 - files: Add FD_CLOEXEC test (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - files: Remove O_CLOEXEC from file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - python: Improve decoding of file flags (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - files: fix ghost file error path (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - zdtm: nft tables preservation test (Alexander Mikhalitsyn
<alexander.mikhalitsyn@virtuozzo.com>)
 - net: add nftables c/r (Alexander Mikhalitsyn <alexander@mihalicyn.com>)
 - style: Enforce kernel style -Wstrict-prototypes (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - style: Enforce kernel style -Wdeclaration-after-statement (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - Fix tests on Ubuntu (Adrian Reber <areber@redhat.com>)
 - zdtm: Add test for SO_KEEPALIVE (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - socket: c/r support for SO_KEEPALIVE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - sockets: Remove duplicate variable assignment (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: alpine: Install py2 packages with pip (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - crit: fix python3 encoding issues (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - x86/cpu: cleanup and improve xfeatures_mask check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: sysctl net.unix.max_dgram_qlen value preservation test (Alexander
Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>)
 - unix: sysctl -- Preserve max_dgram_qlen value (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>)
 - restorer/inotify: reorder inotify cleanup after waiting helpers and zombies
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - readme: github pull-requests is the preferred way to contribute (Andrei Vagin
<avagin@gmail.com>)
 - cgroup: use new mount API to open the cgroup file system (Andrei Vagin
<avagin@gmail.com>)
 - net: use new mount API to open the sysfs file system (Andrei Vagin
<avagin@gmail.com>)
 - mount: use new mount API to open the proc file system (Andrei Vagin
<avagin@gmail.com>)
 - util: introduce the mount_detached_fs helper (Andrei Vagin
<avagin@gmail.com>)
 - kerndat: check whether the new mount API is supported of not (Andrei Vagin
<avagin@gmail.com>)
 - travis: ignore fails of podman-test (Andrei Vagin <avagin@gmail.com>)
 - Add File-based Java Functional Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - zdtm/socket-tcp-fin-wait1: Use array index fro TEST_MSG (Dmitry Safonov
<dima@arista.com>)
 - Documentation: Add a hint about docker build (Dmitry Safonov
<dima@arista.com>)
 - travis: Add armv7-cross as cross-compile test (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Use pkg-config to find includes/libs (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Makefile hack for travis aarch64/armv8l (Dmitry Safonov
<dima@arista.com>)
 - build/zdtm: Support cross-build (Dmitry Safonov <dima@arista.com>)
 - build: Use SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Provide proper SUBARCH (Dmitry Safonov <dima@arista.com>)
 - build/nmk: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - build: Remove SRCARCH (Dmitry Safonov <dima@arista.com>)
 - zdtm: Set --root path to 0700 on restore (Andrei Vagin <avagin@gmail.com>)
 - zdtm: Replace if->continue with if->elif->else (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - man: Describe --root option requirements (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - restore: Create temp proc in /tmp (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - mount: Bind-mount root via userns_call (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: Add error messages (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - travis: exclude uns tests for lazy-pages on newer kernels (Mike Rapoport
<rppt@linux.ibm.com>)
 - travis: group lazy-pages options (Mike Rapoport <rppt@linux.ibm.com>)
 - Checkpoint only specified controllers (Michał Cłapiński
<mclapinski@google.com>)
 - compel/criu: Add __must_check (Dmitry Safonov <dima@arista.com>)
 - criu: Kill tasks even when the network is unlocked (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Detach but fail compel_resume_task() (Dmitry Safonov
<dima@arista.com>)
 - parasite-syscall: Log if can't cure on failed infection (Dmitry Safonov
<dima@arista.com>)
 - cr-restore: Warn if restorer can't be unmapped (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Warn if unmapping local memfd failed (Dmitry Safonov
<dima@arista.com>)
 - cr-dump: Try to cure remote on err-pathes (Dmitry Safonov <dima@arista.com>)
 - lib/infect: Check if compel succeed in executing munmap (Dmitry Safonov
<dima@arista.com>)
 - compel: Mark compat argument of __NR() as used (Dmitry Safonov
<dima@arista.com>)
 - compel/infect: Warn if close() failed on memfd (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Be more elaborate about failures (Dmitry Safonov
<dima@arista.com>)
 - lib/ptrace: Allow PTRACE_PEEKDATA with errno != 0 (Dmitry Safonov
<dima@arista.com>)
 - travis: remove group from .travis.yml (Adrian Reber <areber@redhat.com>)
 - travis: switch pcp64le and s390x to real hardware (Adrian Reber
<areber@redhat.com>)
 - travis: switch all arm related tests to real hardware (Adrian Reber
<areber@redhat.com>)
 - Makefile hack for travis aarch64/armv8l (Adrian Reber <areber@redhat.com>)
 - travis: Do not run privileged containers in LXD (Adrian Reber
<areber@redhat.com>)
 - travis: fix copy paste error from previous commit (Adrian Reber
<areber@redhat.com>)
 - Run java functional tests on travis (Nidhi Gupta <itsnidhi16@gmail.com>)
 - mount: make mnt_resort_siblings nonrecursive and reuse friendly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: Disallow failures on ia32 (Dmitry Safonov <dima@arista.com>)
 - test/java: Add FileRead Tests (Nidhi Gupta <itsnidhi16@gmail.com>)
 - test/static:conntracks: Support nftables (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - travis: start to use aarch64 hardware (Adrian Reber <areber@redhat.com>)
 - Fix broken web-links (Sergey Bronnikov <estetus@gmail.com>)
 - Action scripts should be invoked with normal signal behavior (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - early-log: Print warnings only if the buffer is full (Dmitry Safonov
<dima@arista.com>)
 - Add `criu` to PATH env variable in libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - Enable libcriu testing in travis jobs (Ashutosh Mehra <asmehra1@in.ibm.com>)
 - Couple of fixes to build and run libcriu tests (Ashutosh Mehra
<asmehra1@in.ibm.com>)
 - service: Use space on stack for msg buffer (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - image-desc: Remove CR_FD_FILE_LOCKS_PID (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - cgroup: fix cg_yard leak on error path in prepare_cgroup_sfd (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - page-pipe: Resize up to PIPE_MAX_SIZE (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Guard against empty file lock status (Nicolas Viennot
<Nicolas.Viennot@twosigma.com>)
 - image: avoid name conflicts in image files (Andrei Vagin <avagin@gmail.com>)
 - criu: use atomic_add instead of atomic_sub (Andrei Vagin <avagin@gmail.com>)
 - lib/c: fix a compile time error (Andrei Vagin <avagin@gmail.com>)
 - zdtm: handle --pre-dump-mode in the rpc mode (Andrei Vagin
<avagin@gmail.com>)
 - Refactor time accounting macros (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - read mode pre-dump implementation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding cnt_sub for stats manipulation (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Skip adding PROT_READ to non-PROT_READ mappings (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Handling iov generation for non-PROT_READ regions (Abhishek Dubey
<dubeyabhishek777@gmail.com>)
 - Adding --pre-dump-mode option (Abhishek Dubey <dubeyabhishek777@gmail.com>)
 - restorer/inotify: Don't overflow PIE stack (Dmitry Safonov <dima@arista.com>)
 - Cleanup do_full_int80() (Nicolas Viennot <Nicolas.Viennot@twosigma.com>)
 - unix: print inode numbers as unsigned int (Andrei Vagin <avagin@gmail.com>)
 - pipe: print pipe_id as unsigned to generate an external pipe name (Andrei
Vagin <avagin@gmail.com>)
 - cgroup: fixup nits (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm/cgroup_yard: create a test cgroup yard from the post-start hook (Andrei
Vagin <avagin@gmail.com>)
 - test/cgroup_yard: always clean up a test cgroup yard (Andrei Vagin
<avagin@gmail.com>)
 - Convert pr_msg() error messages to pr_err() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - Introduce flush_early_log_to_stderr destructor (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - arch/x86: fpu_state->fpu_state_ia32.xsave hast to be 64-byte aligned (Andrei
Vagin <avagin@gmail.com>)
 - travis: Install missing diffutils dependency (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test: implement test for new --cgroup-yard option (Michał Cłapiński
<mclapinski@google.com>)
 - Add new command line option: --cgroup-yard (Michał Cłapiński
<mclapinski@google.com>)
 - scripts: Drop Fedora 28/rawhide fix (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - compel/x86: Don't use pushq for a label (Dmitry Safonov <dima@arista.com>)
 - arch/x86: push correct eip on the stack before lretq (Andrei Vagin
<avagin@gmail.com>)
 - cr-dump: Remove redundant if-statement (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - files-reg: Drop clear_ghost_files() prototype (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Manual fixlets of code formatting (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.13 (Pavel Emelyanov <xemul@openvz.org>)
 - py: Fix tabs in code comments (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - pyimages: Add pb2dict.py to checked and fix warnings/errors (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/others: Reuse setup_swrk() (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - test/other: Resolve Py3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - py: Reformat everything into pep8 style (Andrei Vagin <avagin@gmail.com>)
 - zdtm: make inotify04 require restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - travis: add podman test case (Adrian Reber <areber@redhat.com>)
 - README: fix broken links to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - Replace references to github.com/xemul/criu (Sebastiaan van Stijn
<github@gone.nl>)
 - kerndat: remove unused code (Andrei Vagin <avagin@gmail.com>)
 - kerndat: mark functions as static which are used in kerndat.c only (Andrei
Vagin <avagin@gmail.com>)
 - vdso: Correctly track vdso position without vvar (Dmitry Safonov
<dima@arista.com>)
 - test: bring the lo interface up in each network namespace (Andrei Vagin
<avagin@gmail.com>)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - restorer: Use gettimeofday() from rt-vdso for log timings (Dmitry Safonov
<dima@arista.com>)
 - vdso: Add compatible property to vdso_maps (Dmitry Safonov <dima@arista.com>)
 - seccomp/restorer: Disable gtod from vdso in strict mode (Dmitry Safonov
<dima@arista.com>)
 - restorer/parasite-vdso: Don't move vvar if failed to move vdso (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Always track vdso/vvar positions in vdso_maps_rt (Dmitry
Safonov <dima@arista.com>)
 - vdso/restorer: Try best to preserve vdso during restore (Dmitry Safonov
<dima@arista.com>)
 - compel/std/uapi: Provide setter for gettimeofday() (Dmitry Safonov
<dima@arista.com>)
 - compel/log: Use enum as parameter for std_log_set_loglevel() (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Disable undefined name 'basestring' (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Install flake8 with dnf in Fedora (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Set PYTHON=python3 in Fedora Dockerfiles (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - scripts: Remove yaml/ipaddress Py2 fedora modules (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mount: fix inconsistent return and goto err alternation (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - scripts: remove python2 from Fedora Dockerfiles (Adrian Reber
<areber@redhat.com>)
 - scripts: add possibility to override docker with podman (Adrian Reber
<areber@redhat.com>)
 - images: convert type of child_subreaper from int32 to bool (Andrei Vagin
<avagin@gmail.com>)
 - restorer: print errors if prctl syscalls failed (Andrei Vagin
<avagin@gmail.com>)
 - make: Insert version macros in criu.h (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - mem/shmem: Fix typos for_each_shmem macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xmalloc in collect_sysv_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: More elegant entries declaration (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/shmem: Use xrealloc_safe in expand_shmem (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/pmc: Print pid for debug sake (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/pmc: Use pr_warn_once if cache is disabled (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-xfer: Add log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Sanitize struct vm_area_list (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mem/vma: Drop never used VM_AREA_LIST macro (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use vm_area_list_init where appropriate (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/vma: Use memset for vm_area_list_init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Use ssize_t for splice/tee results (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: Align members for readability sake (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - mem/page-pipe: Eliminate redundant pipe_off setup (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Add ZDTM tests for child subreaper property (Michał Cłapiński
<mclapinski@google.com>)
 - Add support for migrating CHILD_SUBREAPER prctl (Michał Cłapiński
<mclapinski@google.com>)
 - Replace libprotobuf-c0-dev with libprotobuf-c-dev (Sebastiaan van Stijn
<github@gone.nl>)
 - zdtm: use a proper page size for the host (Andrei Vagin <avagin@gmail.com>)
 - test/packet_sock_mmap: parse inode as unsigned long long (Andrei Vagin
<avagin@gmail.com>)
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - files-reg: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix clang 'null pointer passed' (Adrian Reber <areber@redhat.com>)
 - seize: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity IDENTICAL_BRANCHES (Adrian Reber <areber@redhat.com>)
 - tty: Move tty layer shared init into tty_init_restore (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - fix segmentation fault caused by uninitialized mutex (Dengguangxing
<dengguangxing@huawei.com>)
 - Documentation: Create man page for libcompel (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - flake.cfg: Update to yapf formatting (Pavel Emelyanov <xemul@virtuozzo.com>)
 - lint: Print flake8 version before checking (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - travis: Enable TLS testing (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm: Add --tls option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - rpc: Add support for TLS options (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - tls: Add --tls-no-cn-verify option (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - page-xfer: Add TLS support with X509 certificates (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - make: config -- Link with GnuTLS (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - fsnotify: More precious error handling (Cyrill Gorcunov <gorcunov@gmail.com>)
 - c-lib: Install and uninstall libcriu.a (Uchio Kondo <udzura@udzura.jp>)
 - Add CRIU_A to cleanup target (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Add lib-a into all-y targets (Uchio Kondo <udzura@udzura.jp>)
 - c-lib: Support to build a static archive (Uchio Kondo <udzura@udzura.jp>)
 - zdtm: Fix memory and resource leaks (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu/vdso: Purge CONFIG_VDSO (Dmitry Safonov <dima@arista.com>)
 - pie/build: Add CFLAGS_PIE to CFLAGS (Dmitry Safonov <dima@arista.com>)
 - util-vdso: Check chain for STN_UNDEF (Dmitry Safonov <dima@arista.com>)
 - x86/vdso: Don't insert trampolines in vsyscall (Dmitry Safonov
<dima@arista.com>)
 - rt-vdso: Be verbose if !blobs_matches() (Dmitry Safonov <dima@arista.com>)
 - arm/pie: Provide __clear_cache() (Dmitry Safonov <dima@arista.com>)
 - arm: Provide aeabi helpers in ARM format (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - arm: Build {pie-, }util-vdso with CONFIG_VDSO_32 (Dmitry Safonov
<0x7f454c46@gmail.com>)
 - vdso/arm32: Add vdso trampoline support (Dmitry Safonov <dima@arista.com>)
 - parasite-vdso: Add ugly casts for arm32 (Dmitry Safonov <dima@arista.com>)
 - vdso/arm: Add vdso symbols from kernel (Dmitry Safonov <dima@arista.com>)
 - cr-check: Add check for mremap() of special mappings (Dmitry Safonov
<dima@arista.com>)
 - pb2dict: Resolve Python 2/3 compatibility issues (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - pb2dict: Fix is_string() check for Python 2 (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Check stats file presence before reading (Pavel Emelianov
<xemul@virtuozzo.com>)
 - aarch64: Remove stack pointer from clobber list (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - test/s390: add a new patch to xtables libraries (Andrei Vagin
<avagin@gmail.com>)
 - util: use F_DUPFD when we don't want to overwrite an existing descriptor
(Andrei Vagin <avagin@gmail.com>)
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - zdtm: Check pages stats after dump (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - make: Use asciidoctor by default (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - python: Drop six dependency (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-unix: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - image: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - util: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - sk-unix: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - sk-queue: fix clang 'potential memory leak' (Adrian Reber
<areber@redhat.com>)
 - sk-inet: fix clang 'potential memory leak' (Adrian Reber <areber@redhat.com>)
 - sk-inet: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - proc_parse: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - pie/restorer: fix clang 'value is never read' (Adrian Reber
<areber@redhat.com>)
 - page-xfer: fix clang 'value is never read' (Adrian Reber <areber@redhat.com>)
 - pagemap: fix coverity FORWARD_NULL (Adrian Reber <areber@redhat.com>)
 - pagemap: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - mem: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - lsm: fix clang 'Use of memory after it is freed' (Adrian Reber
<areber@redhat.com>)
 - lib/c: fix coverity DEADCODE (Adrian Reber <areber@redhat.com>)
 - libcriu: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - log: fix coverity OVERRUN (Adrian Reber <areber@redhat.com>)
 - image: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - files-reg: fix coverity NULL_RETURNS (Adrian Reber <areber@redhat.com>)
 - files: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - cr-service: fix clang 'dereference of a null pointer' (Adrian Reber
<areber@redhat.com>)
 - cr-service: fix coverity STRING_OVERFLOW (Adrian Reber <areber@redhat.com>)
 - compel: fix clang 'value stored is never read' (Adrian Reber
<areber@redhat.com>)
 - cgroup: fix clang 'free released memory' (Adrian Reber <areber@redhat.com>)
 - autofs: fix coverity RESOURCE_LEAK (Adrian Reber <areber@redhat.com>)
 - x86/crtools: do not error when YMM is missing (Zhang Ning
<ning.a.zhang@intel.com>)
 - build/criu/pie: Move trampolines to restorer-obj-y (Dmitry Safonov
<dima@arista.com>)
 - criu/ia32: Consolidate compat vdso and move to arch/x86 (Dmitry Safonov
<dima@arista.com>)
 - make: Move CR_NOGLIBC into CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - compel: Don't use CFLAGS_PIE for libcompel.so (Dmitry Safonov
<dima@arista.com>)
 - build: Use cflags from compel for pie.lib.a (Dmitry Safonov
<dima@arista.com>)
 - Makefile.crtools: Remove bogus ccflags-y (Dmitry Safonov <dima@arista.com>)
 - make: Don't export ccflags-y (Dmitry Safonov <dima@arista.com>)
 - build: Move __ASSEMBLY__ define to the top Makefile (Dmitry Safonov
<dima@arista.com>)
 - arm/build: Move -marm cflag to CFLAGS_PIE (Dmitry Safonov <dima@arista.com>)
 - build/pie: Add comments to build files (Dmitry Safonov <dima@arista.com>)
 - lazy-pages: fix stack detection (Mike Rapoport <rppt@linux.ibm.com>)
 - crtools: Print err messages from check_options() (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - config: Exit with error if ps-socket is std fd (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - util: cr_daemon: Drop keep_fd argument (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Add UDP broadcast test (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - sk-inet: restore SO_BROADCAST option (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - zdtm: Simplify string to boolean conversion (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - [coredump]: correct the parsing of reg_files from files.img (guoqd
<dubukuangye@sina.com>)
 - test/exhaustive: Replace map by list comprehension (Harshavardhan Unnibhavi
<hvubfoss@gmail.com>)
 - cgroup: Add "ignore" mode for --manage-cgroups (Dmitry Safonov
<dima@arista.com>)
 - zdtm/thread-bomb: Limit stack size in thread-bomb (Dmitry Safonov
<dima@arista.com>)
 - x86/compel/infect: Be verbose on remote mmap failure (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Ignore vsyscall page appear (Dmitry Safonov
<dima@arista.com>)
 - zdtm/vdso/ia32: Use uint64_t for /proc/self/maps (Dmitry Safonov
<dima@arista.com>)
 - test/bers: Fix sizeof to memset (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: add missing va_end (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - files-reg: Remove redundant inner if (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - test: remove unused variables (Rikard Falkeborn <rikard.falkeborn@gmail.com>)
 - test/zdtm: Move assignment after return value check (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix return value in error path (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - compel/s390: Fix memset sizeof (Rikard Falkeborn
<rikard.falkeborn@gmail.com>)
 - criu/clone: stack size is too small for Android (Zhang Ning
<ning.a.zhang@intel.com>)
 - test: socket_udplite -- Test shudowned sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - arch: add Hygon CPU Vendor ID("HygonGenuine") checking in compel_cpuid()
(hygonsoc <hygonsoc@gmail.com>)
 - Convert spaces to tabs (Radostin Stoyanov <rstoyanov1@gmail.com>)
 - zdtm/ia32: fcntl() wrapper for old glibc(s) (Dmitry Safonov
<dima@arista.com>)
 - zdtm: Refactor seccomp_filter_{threads,tsync} (Radostin Stoyanov
<rstoyanov1@gmail.com>)
 - criu: Version 3.12.1 (Andrei Vagin <avagin@gmail.com>)
 - lsm: fix compiler error on Fedora 30 (Adrian Reber <areber@redhat.com>)
 - lsm: don't reset socket contex if SELinux is disabled (Andrei Vagin
<avagin@gmail.com>)
 - lsm: fix compiler error 'unused-result' (Adrian Reber <areber@redhat.com>)
 - selinux: add socket label test (Adrian Reber <areber@redhat.com>)
 - sockets: dump and restore xattr security labels (Adrian Reber
<areber@redhat.com>)
 - test: Verify that sockcreate does not change during restore (Adrian Reber
<areber@redhat.com>)
 - lsm: also dump and restore sockcreate (Adrian Reber <areber@redhat.com>)

* Tue Nov 10 2020 VZ Auto Builder <builder@virtuozzo.com> 3.12.6.3
 - mount: ignore root change in cgroup mounts in case of container rename (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-108126)
 - spfs: fix usage of new_cg_root_get (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-108126)

* Fri Nov 06 2020 VZ Auto Builder <builder@virtuozzo.com> 3.12.6.2
 - zdtm: add scm07 SCM_RIGHTS & SCM_CREDENTIALS case (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix SCM restore in case when SCM_RIGHTS & SCM_CREDS in one packet
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99868)
 - sk-queue: fix lost ScmEntries during SkPacketEntry copy (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-99868)

* Tue Nov 03 2020 VZ Auto Builder <builder@virtuozzo.com> 3.12.6.1
 - binfmt_misc: isolate binfmt_misc dump logic from mountinfo/mountpoint dump.
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96362)
 - build: Adjust versions for u16 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add propagation group with mount flags to mount_complex_sharing (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96308)

* Wed Apr 22 2020 Denis Silakov <dsilakov@virtuozzo.com> 3.12.3.5-2
 - Added ipset requirement (#PSBM-103070)

* Wed Apr 22 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.3.5
 - PSBM-102980 (Alexander Mikhalitsyn <alexander@mihalicyn.com>) (#PSBM-102980)

* Wed Apr 15 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.3.4
 - PSBM-102972 (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-102972)

* Mon Apr 13 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.3.3
 - PSBM-102791 (Alexander Mikhalitsyn <alexander@mihalicyn.com>) (#PSBM-102791)

* Mon Apr 06 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.3.2
 - PSBM-102605 (Alexander Mikhalitsyn <alexander@mihalicyn.com>) (#PSBM-102605)

* Tue Mar 10 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.11
 - PSBM-96385 PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96385 #PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)
 - PSBM-100080 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100080)

* Fri Feb 21 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.10
 - PSBM-100083 (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - PSBM-100083 (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-100083)
 - PSBM-99926 (Alexander Stefanov <astefanov@virtuozzo.com>) (#PSBM-99926)

* Fri Feb 14 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.8
 - PSBM-101433 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - PSBM-101433 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - PSBM-101145 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101145)
 - PSBM-101433 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101433)
 - PSBM-101433 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-101433)

* Wed Feb 05 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.7
 - PSBM-64123 (Valeriy Vdovin <valeriy.vdovin@virtuozzo.com>) (#PSBM-64123)

* Thu Jan 16 2020 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.6
 - PSBM-100775 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100775)

* Fri Dec 27 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.5
 - PSBM-99969 (Alexander Mikhalitsyn <alexander.mikhalitsyn@virtuozzo.com>) (#PSBM-99969)

* Thu Dec 19 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.2.4
 - PSBM-100053 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-100053)

* Mon Nov 18 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.2.3
 - Fixup 4fd65f5762002a8ed57c6c5b3b2f189f70ce3b74 (#PSBM-99360)

* Mon Nov 18 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.2.2
 - mount: Order call_helper_process calls (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-99360)
 - Revert "restore: Serialize access to last_pid"

* Fri Nov 15 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.2.1
 - build: Adjust versions for u13
 - restore: Serialize access to last_pid (#PSBM-99360)
 - Revert "./test/zdtm/static:conntracks: Support nftables" (#PSBM-99112)

* Tue Nov 12 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.36
 - PSBM-99194 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99194)

* Tue Nov 12 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.35
 - PSBM-99292 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99292)

* Thu Nov 07 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.34
 - pie: restorer -- Show pids statistics on thread creation failure (#PSBM-99230)

* Thu Nov 07 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.33
 - PSBM-99001 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-99001)
 - PSBM-99101 (Vitaly Ostrosablin <vostrosablin@virtuozzo.com>) (#PSBM-99101)

* Thu Oct 31 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.32
 - PSBM-98958 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958)
 - PSBM-98958 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98958)

* Fri Oct 25 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.30
 - PSBM-98888 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98888)
 - PSBM-98888 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98888)

* Mon Oct 21 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.29
 - pie/restorer: Fix typo in debug print (#PSBM-98453)

* Mon Oct 21 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.28
 - PSBM-98702 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98702)

* Fri Oct 11 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.27
 - PSBM-98502 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98502)

* Tue Oct 08 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.25
 - PSBM-98438 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98438)

* Wed Oct 02 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.24
 - PSBM-98231 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98231)

* Fri Sep 27 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.23
 - PSBM-96943 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96943)

* Wed Sep 25 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.22
 - PSBM-98094 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-98094)

* Tue Sep 17 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.21
 - PSBM-97810 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-97810)

* Fri Sep 13 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.20
 - PSBM-97787 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-97787)

* Mon Sep 09 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.19
 - test: Add pipe04 test
 - pipes: Make pipe_data_dump dynamic (#PSBM-97048)

* Fri Sep 06 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.18
 - restorer: Add debug print for clone call (#PSBM-97408)
 - mount: fix external mounts so that they pass check-mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96385)

* Thu Aug 29 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.17
 - PSBM-96981 (Cyrill Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-96981)

* Tue Aug 13 2019 VZ Auto Builder <dsilakov@virtuozzo.com> 3.12.1.15
 - PSBM-96973 (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96973)

* Wed Aug 07 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.14
 - zdtm: make grep_errors also grep warnings (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-60715)
 - inventory: skip warning in case of no parent directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-60715)
 - dedup: convert noisy warning to debug and improve messages (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-60715)
 - zdtm/inotify: add a test that no unexpected events appear after c/r (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-60715)
 - inotify: cleanup auxiliary events from queue (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-60715)
 - vtty: tty_verify_ctty -- Fix a typo (#PSBM-96852)
 - mount/restore: create mountpoint for auxiliary binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96621)

* Fri Aug 02 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.13
 - mount/restore: create mountpoint for auxiliary binfmt_misc mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96621)

* Fri Jul 26 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.12
 - mount: delay setting unbindable flag where possible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96376)
 - mount: fix error print in case of failed bind-mount (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - mount/restore: create auxiliary binfmt_misc mount in the root yard (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96082 #PSBM-96362)
 - mount: remove a leftover mnt_path check (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96087)
 - mount: check error return of cut_root_for_bind (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96087)
 - mount: fix parentheses nit in else condition in do_bind_mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96087)

* Fri Jul 19 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.1.11
 - build: Adjust version for vz7-u12
 - check-mounts/spfs: skip flags check for nfs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-96106)
 - check-mounts: check all mntnses before failing to have a full picture (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96106)
 - mount/check-mounts: remove auxiliary cr-time mount from tree after umount
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-96082)

* Mon Jul 15 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.10
 - pie/restorer: Reread last_pid on error (#PSBM-96105)
 - pie/restorer: Fix fd leaking on error path (#PSBM-96105)

* Mon Jul 15 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.9
 - seize: Print tracer pid for debug sake (#PSBM-96110)

* Thu Jul 11 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.8
 - mem/pagema-cache: Drop confusing log (#PSBM-95760)
 - mem/shmem: Use pmc_ helpers instead of accessing map directly
 - mem: generate_iovs -- Use pmc_get_pfn_from helper
 - mem/pagemap-cache: Provide api for map access
 - mem/pagema-cache: Make sure we're not accessing stale data
 - stats: Make dstats shmem (Pavel Emelianov <xemul@virtuozzo.com>)
 - shmem: Save pages stats too (Pavel Emelianov <xemul@virtuozzo.com>)
 - mem: Update stats for overflow page pipes (Pavel Emelianov
<xemul@virtuozzo.com>)
 - mem/shmem: Fix typos for_each_shmem macro
 - mem/shmem: Use xmalloc in collect_sysv_shmem
 - mem/shmem: Reorder code in expand_shmem
 - mem/shmem: Use xrealloc_safe in expand_shmem
 - mem/page-pipe: Use xrealloc_safe in page_pipe_add_hole
 - mem/pmc: Print pid for debug sake
 - mem/pmc: Use pr_warn_once if cache is disabled
 - mem/page-xfer: Add log prefix
 - mem/vma: Sanitize struct vm_area_list
 - mem/vma: Drop never used VM_AREA_LIST macro
 - mem/vma: Use vm_area_list_init where appropriate
 - mem/vma: Use memset for vm_area_list_init
 - mem/page-pipe: Use ssize_t for splice/tee results
 - mem/page-pipe: Align members for readability sake
 - mem/page-pipe: create_page_pipe -- Drop redundant zero assignment
 - mem/page-pipe: Eliminate redundant pipe_off setup

* Tue Jul  2 2019 Denis Silakov <dsilakov@virtuozzo.com> 3.12.0.7-2
 - Add phaul requirement (#PSBM-95828)

* Fri Jun 28 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.7
 - scripts/nfs: collect nfs mount servers only from ve processes (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-95775)

* Mon Jun 24 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.6
 - spfs: make spfs logs relative to criu working directory (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-59204)

* Wed Jun 19 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.5
 - pid-reuse: Ensure we're fetching params from ve0 (#PSBM-95422)

* Thu Jun 13 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.4
 - fsnotify: Allow to get updated restored wd (#PSBM-91520)
 - Revert "vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly"
 - criu.spec: Add python-ipaddress for python-criu package (#PSBM-94578)

* Wed May 29 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.3
 - vz: close_fds -- Addition to 6af5df67245755cf7e75553ee65b4a360cbdc602 (#PSBM-95035)

* Tue May 28 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.2
 - vz: close_fds -- Skip closing external service fd (#PSBM-94949)
 - netlink: Fix for 52828b9aa350cb027c2cb4c1330e0cd7ceac4b46
 - vz7: x86,cpu -- Fixup for 4d76e16247621082580e1d137aeba18791040541
 - vz7: action scripts: set spfs environment in run_scripts (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - log: Increase early log buffer

* Mon May 27 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.12.0.1
 - build: Switch to v3.12 vanilla branch
 - files-reg: Fix 847db9c3239f9951407a2d09b794eea63d24b2df
 - vz7: cpu -- Move vz_cpu_parse_cpuid_override to early_init (#PSBM-85265)
 - test: bers -- Provide --pidfile option
 - fsnotify: Add error print for nexwd failure (#PSBM-91520)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (#PSBM-93461)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - spfs: Fix typo in get_spfs_mngr_sock (#PSBM-93663)
 - spfs: When fetching sfd provide a copy of it (#PSBM-93663)
 - spfs: Return proper service fd from install_service_fd call (#PSBM-93462)
 - mount: fix order of mnt namespaces in united mount tree (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93305)
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - zdtm: use --check-mounts by default (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - rpc: Add interface for --check-mounts option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: check that mounts tree restored without any hidden problems (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - epoll: Fix qsort args passing
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022)
 - mount: temporary create needed ancestor directories for deleted root (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022)
 - arch,x86: Investigate OSPKE status when handling PKU (#PSBM-91098)
 - ve: tty -- Preallocate space for itty pool (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert
 - ve: tty -- Drop leftover comment
 - ve: tty -- Investigate master fds with a mutex taken (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (#PSBM-90662)
 - test: tty-inherit -- Don't forget to clean buffer (#PSBM-94706)
 - test: tty-inherit -- Handle parse_pid_stat errors (#PSBM-94405)
 - ve: tty -- Add tty-inherit test
 - ve: tty -- Add support of tty inheritance, v2 (#PSBM-76490)
 - crtools: Show command line in log
 - files: Select proper master fd when collecting fd (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper
 - test: netns_sub_veth -- Disable for a while
 - restore: Fix hang if root task is waiting on zombie (#PSBM-89830)
 - restore: Don't ignore errors on wait in restore_one_zombie
 - restore: Add more detailed log in wait_exiting_children
 - restore: zombie -- Add more detailed log on signals
 - inet: raw -- Add compatibility layer for old images
 - net: Add prefixes for better logging (Cyrill Gorcunov <gorcunov@gmail.com>)
 - mount: cr_pivot_root -- Try temp directory first (#PSBM-89582)
 - mount: Fix typo in message
 - ve: Add helpers for debug sake
 - fown: test -- Improve error messaging in file_fown_dead
 - fown: test -- Update file_own_dead to test O_PATH case
 - fown: Don't fail on dumping files opened wit O_PATH (#PSBM-89680)
 - fown: test -- Add file_fown_dead
 - fown: Dont fail if owner is a dead pid (#PSBM-88336)
 - .gitignore: Add patches/
 - ve: tty -- Add more detailed debug print in ctty verification
 - ve: tty -- Save pid of a task which setups a controlling terminal
 - ve: tty -- Save tty_pgrp in process tree upon read
 - unix: Don't forget to restore original errno
 - pr-warn: Add missing newlines
 - compel: Don't forget to zap remote_map pointer after release (#PSBM-89231)
 - ve: tty -- Don't stuck if several ctty opened
 - ve: tty -- Save virtual group id
 - ve: tty -- Collect real ppid, pgid, sid on dump
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
 - unix: Disable switching mount namespace (#PSBM-89126)
 - vz7: files-reg -- Show which exactly file can't be created
 - unix: Don't forget to close ns descriptor on error path
 - tun: Add compatibility with old images
 - test: bind-mount-unix -- Implement real connect
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets
 - unix: bind_unix_sk -- Add ability to skip waiters notification (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested
 - unix: make_socket -- Add more detailed logs
 - unix: break_connected -- Add a log recod
 - unix: bindmount -- Show details about queuer
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - test: sk-unix-ucred -- Make compatible with gcc 8
 - vz7: image -- Add compat layer for Core entry (#PSBM-88238)
 - test: cgroup04 -- Disable
 - unix: bindmount -- Move mounting code to be called before first mount
 - vz7: unix: Add compatibility with u7 images (#PSBM-86861)
 - unix: test -- Add bind-mount-unix test case
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Add support for bindmounted sockets
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: image -- Move uflags into enum
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Fix path resolving for sockets with abs symlinks in paths
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - spfs: suppress compilation warnings by roughly approximating path lenths
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz7/mount: show the real mount which is behind the clean mount (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz7: reenable not-failing cgroup tests in automatic runs (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - spfs: Fix nil dereference if no bindmount present (#PSBM-86775)
 - zdtm: temporary make mnt_ext_auto and private_bind_propagation noauto (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-85251)
 - net: Add net log prefix
 - vz7: net -- Add missing newline into debug message
 - files: Don't forget on stipping deleted postfix on linked files (#PSBM-84731)
 - netlink: Change NETLINK_REPAIR number (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-83415)
 - files: Don't fail on cgroup directories mode change (#PSBM-83154)
 - test: unlink_multiple_largefiles -- Make noauto
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)
 - vz: test,file_lease00 -- Disable for a while
 - vz: test,pipe03 -- Don't run in uns
 - vz: test,transition,fork -- Postpone for a while
 - vz: test,thread_different_uid_gid -- Postpone for a while
 - vz: test,sched_policy00 -- Drop ns flag for a while
 - vz: test,cgroups -- Skip testing via zdtm run
 - vz: test,tty -- Use ns flavor
 - vz: test,pty -- Use ns flavor
 - vz: zdtm,mount -- Don't fetch veid when testing and skip cr moutns
 - vz: zdtm,restore -- Skip entering veX when testing
 - vz: zdtm,dump,bc -- Skip bc read/write when testing
 - vz: zdtm,net,iptables -- Don't enter userns for a root
 - vz: kdat -- Query zdtm status runtime
 - vz: zdtm -- Export ZDTM_RUN variable to notify criu
 - vz: zdtm -- Don't fail in __construct_root if entries exist
 - vz7: net: do iptables restore in ve0 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-58574)
 - vz7: net: iptables_tool_{dump,restore} helpers introduced (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573 #PSBM-61812)
 - tty: Move session lookup leader into find_session_leader
 - tty: Fetch ctty index based on sid
 - tty: Add is_ctty helper
 - tty: Don't check for group inheritance
 - files-reg: Prepare for sysfs entries mode change (#PSBM-80585)
 - arch, x86: int80 -- Clobber all rX registers (#PSBM-80095)
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: improve prints in spfs_set_mode() and spfs_release_replace() (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: improve SPFS manager start debug and error output (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - tty: Use mnt_id for first lookup of toplevel devpts (#PSBM-78460)
 - ns: Set hookups for all namespaces (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - ns: Set nested namespaces hookups (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-58198)
 - net: execute iptables-restore in a target network namespace (Andrei Vagin
<avagin@openvz.org>) (#PSBM-75531)
 - action-scripts: Export mount namespace roots via CRIU_MNT_NS_ROOTS (#PSBM-71861)
 - mount: Add export_mnt_ns_roots helper (#PSBM-71861)
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)
 - tty: collect_one_tty_info_entry -- Move tracking setup into main cycle (#PSBM-70929)
 - tty: collect_one_tty -- Make sure the index is in range
 - tty: tty_has_active_pair -- Make sure no overflow happened
 - tty: tty_test_and_set -- Make sure no overflow happened
 - tty: Fix __tty_verify_active_pairs
 - tty: Use macros for bitmap length
 - vz7: images -- Add task_core_entry_vz730 stub (#PSBM-67671)
 - vz7: Log into /var/log/mesages large ghost files dumps (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68320)
 - vz7: page-xfer: Make error message more verbose (#PSBM-68738)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (#PSBM-68062)
 - vz7: criu: export join_ve helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: page-xfer: handle a case when splice returns zero (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68732)
 - vz7: mount: allow any types of NFS mount for a while (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-68663)
 - vz7: mounts: support NFS bind-mounts in the same shared group (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-68663)
 - vz7: criu: don't abort criu in lookup_create_item() (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-68607)
 - vz7: dump: set pid->state for threads (Andrei Vagin <avagin@virtuozzo.com>) (#PSBM-68585)
 - vz7: mounts: support only shared NFS mounts in inits mount namespace
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66945)
 - vz7: mount: Switch user_ns before mount binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-68377)
 - vz7: ve: Call binfmt_misc-mounting code in call_in_child_process() (Kirill
Tkhai <ktkhai@virtuozzo.com>)
 - vz7: mount: Move binfmt_misc-mounting code to separate function (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Consider EBUSY binfmt_misc mount return as error (Kirill Tkhai
<ktkhai@virtuozzo.com>)
 - vz7: mount: Don't search for siblings inside self (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67723)
 - vz7: sk-queue: fix non-fatal print log level (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: cr-service: Init page_ids laterly (Dmitry Safonov
<dsafonov@virtuozzo.com>)
 - vz7: images: Initialize images earlier (before page-server starts) (Dmitry
Safonov <dsafonov@virtuozzo.com>) (#PSBM-67335)
 - vz7: pages: Share page_ids between ns dump-helpers (Dmitry Safonov
<dsafonov@virtuozzo.com>) (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: forbid migration of opened device files on NFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-55590)
 - vz7: scripts: cleanup error output in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: scripts: check service mountpoint is not empty in systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-67544)
 - vz7: mounts: print NFS nested mountpoint info (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466)
 - vz7: mounts: add unsupported mount helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-67466)
 - vz7: spfs: fix usage of mi->ns_mountpoint (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66943)
 - vz7: tests: shm-unaligned -- Use unique key for simultaneous run (#PSBM-66764)
 - vz7: scripts: use absolute binaries paths systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66967)
 - vz7: scripts: skip spfs mount points in systemd-autofs-restart.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-66285)
 - vz7: scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh (Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Kirill Tkhai <ktkhai@virtuozzo.com>)
 - vz7: Makefile: Fix scripts installation
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-65483)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)
 - vz7: restore_sk_queue -- Show how many bytes already sent (#PSBM-64628)
 - vz7: sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: dump: Any non-negative return code of run_scripts means an error (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-62583)
 - vz7: seize -- Show detached pid in freezer_detach
 - vz7: Show status of uninterruptable task (#PSBM-63211)
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - vz7: test: Add ucreds test
 - vz7: Zap file size checking for "atop" (#PSBM-61459)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32 (Andrei
Vagin <avagin@virtuozzo.com>)
 - vz7: socket: don't restore ucred from kernel messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump/restore netlink options (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: restore queues and only then restore opts (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606 #PSBM-61459 #PSBM-61851)
 - vz7: criu: add more information about control messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-60643)
 - vz7: test: check ucred for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: dump and restore ucred-s for netlink messages (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-59339)
 - vz7: mount: fix mounting non-root shared mounts (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-55494)
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper
 - vz7: tty: Fix devpts mounts resolving (Cyrill Gorcunov <gorcunov@openvz.org>) (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593 #PSBM-61534 #PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: zdtm: check a netlink socket with in-kernel state (Andrei Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
(Andrew Vagin <avagin@virtuozzo.com>)
 - vz7: ghost files: don't check ghost size if it's an NFS path (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-56159)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED
 - vz7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - vz7: util: Add rmdirp helper
 - vz7: mount: handle error from restore_shared_options() (Andrei Vagin
<avagin@openvz.org>)
 - vz7: seize: Add additional diagnose messages (#PSBM-53929)
 - vz7: mount: bind-mount autofs mounts via a file descriptors (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-53194)
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-59199)
 - vz7: spfs: move SPFS manager to corresponding container's dump directory
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-52353)
 - vz7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-52320)
 - vz7: cg: Don't dump devices.list (#PSBM-50551)
 - vz7: cr-restore: use spfs helpers to control spfs manager (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: add new helpers to replces bash scripts calls (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: mount: create a temporary mount to restore shared and master groups
(Andrey Vagin <avagin@openvz.org>) (#PSBM-47508)
 - vz7: files-reg: fix silly-renamed files migration (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: improve spfs_file helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: remove obsolete code (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate "spfs" files as ghost-ones (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: conditionally dump content in dump_ghost_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: split create_ghost (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: remove obsolete scripts (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: Makefile: install spfs-release-replace.sh script (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-49726)
 - vz7: util: mkdirname helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: dump: Show task comm early
 - vz7: spfs: do not tolerate file existence on creation (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: fix freeze cgroup path discovery (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: cgroup: new_cg_root_get helper introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: remove NFS unlinked files restriction (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: files-reg: migrate spfs file as "link remap" objects (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: spfs: explicitly pass size and mode to spfs_create_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: link_remap: do not create excessive links for a single file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: mount: forbid dumping overmounted NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-48620)
 - vz7: zdtm: add a new test to check netlink sockets with queued data (Andrew
Vagin <avagin@virtuozzo.com>)
 - vz7: netlink: restore data in a received queue for netlink sockets (Andrei
Vagin <avagin@virtuozzo.com>) (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: check: check whether NETLINK_REPAIR is supported or not (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: netlink: request flags for netlink sockets (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: files-reg: forbid to dump unlinked NFS files (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: proc_parse: forbid dumping NFS remote locks (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: files-reg: create spfs file in case of parent mount is SPFS (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - restore: pidfile -- write before post-restore stage (#PSBM-90289)
 - log: Write more details in write_pidfile
 - vz7: compel -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - vz7: tty: Save task current terminal if present
 - vz7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - vz7: spfs: remove "ns_list" option from "replace" command as obsolete
(Stanislav Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: remove bogus command substitution in nfs-ports-allow.sh (Eugene
Kolomeetz <klm@virtuozzo.com>) (#PSBM-44207)
 - vz7: scripts: restart all systemd automount services (Eugene Kolomeetz
<klm@virtuozzo.com>) (#PSBM-46672)
 - vz7: util: Add cr_set_root/cr_restore_root helpers (Andrew Vagin
<avagin@virtuozzo.com>)
 - vz7: spfs: do not treat existent file as error in create_reg_file (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - vz7: scripts: spfs-release-replace.sh introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: criu: spfs -- Fixup various nits for NFS sake
 - vz7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-26967)
 - vz7: mount: Add support for NFSv4 (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFSv4 type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: mount: add support for NFS (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: NFS type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs -- Mitigate sock_seqpacket_connect
 - vz7: spfs -- Mitigate spfs_manager_socket_path
 - vz7: mount: add support for SUNRPC Pipefs (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: protobuf/mnt.proto: RPC Pipefs type added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: allow-nfs-ports.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: scripts: spfs-change-mode.sh added (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: spfs: delayed mounts facility introduced (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: filemap: collect mapped file fs type (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - vz7: aio: Don't fail if kernel does not support aio wait (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-42488)
 - vz7: Wait aio pending requests (Kirill Tkhai <ktkhai@virtuozzo.com>) (#PSBM-42488)

* Mon Apr 29 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.1.5
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-94209 #PSBM-92070)
 - Revert "spfs: Retrieve NFS server IP address from mountinfo"
 - Revert "script/spfs: resolve dns to ip for iptables utility" (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)

* Mon Apr 22 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.1.4
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-92070)

* Mon Apr 22 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.1.3
 - script/spfs: resolve dns to ip for iptables utility (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92070)

* Wed Apr 17 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.1.2
 - Revert "spfs: Retrieve NFS server IP address from mountinfo" (#PSBM-93882)

* Tue Apr 16 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.1.1
 - build: Makefile.version
 - net: add support for "net/core/*" sysctls (Jan Dakinevich
<jan.dakinevich@virtuozzo.com>) (#PSBM-91415)
 - spfs: Retrieve NFS server IP address from mountinfo (Pavel Vokhmyanin
<pvokhmyanin@virtuozzo.com>) (#PSBM-92070)
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (#PSBM-93461)
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)

* Thu Apr 11 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.16
 - sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (#PSBM-93461)

* Thu Apr 11 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.15
 - files: make rst_remaps shmalloc'ed to see it's change in other process (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-93511)
 - files: split remaps list to two one on dump one on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93511)

* Wed Apr 10 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.14
 - spfs: Fix typo in get_spfs_mngr_sock (#PSBM-93663)

* Tue Apr 09 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.13
 - spfs: When fetching sfd provide a copy of it (#PSBM-93663)

* Mon Apr 08 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.12
 - spfs: Return proper service fd from install_service_fd call (#PSBM-93462)

* Mon Apr 01 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.11
 - mount: fix order of mnt namespaces in united mount tree (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-93305)

* Fri Mar 29 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.10
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - zdtm: use --check-mounts by default (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - rpc: Add interface for --check-mounts option (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: check that mounts tree restored without any hidden problems (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: rework mount tree build step on restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - ns/restore/image: do not read namespace images for non-namespaced case (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - ns: make rst_new_ns_id static (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86686)
 - mount: remove useless check in populate_mnt_ns (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-86686)

* Thu Mar 28 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.9
 - epoll: Fix qsort args passing

* Wed Mar 27 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.8
 - test: epoll -- Add migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add suppport for migrated targets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-90012)
 - epoll: Fix typo in message when no target found (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Drop duped and closed targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: epoll -- Add file inherited case (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Ignore migrated targets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Defer queued epolls to write at the end of checkpoint (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Eliminate potential variable shadowing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Revert "test: epoll -- Add migrated target test"
 - Revert "epoll: Eliminate potential variable shadowing"
 - Revert "epoll: Defer queued epolls to write at the end of checkpoint"
 - Revert "epoll: Drop duped and closed targets"
 - Revert "epoll: Add ability to restore migrated targets"
 - Revert "epoll: Save virtual pid for targets"
 - Revert "epoll: Fix typo in flush_eventpoll_dinfo_queue"

* Mon Mar 25 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.7
 - restorer: add additional debugging on clone errors (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-92904)
 - epoll: Fix typo in flush_eventpoll_dinfo_queue (#PSBM-92672)

* Tue Mar 12 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.6
 - early_init: Force to unlimit files on early init (#PSBM-92451)

* Wed Mar 06 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.5
 - Revert "test: Add unlink_dir test"
 - Revert "files: Rework clean_one_remap to order ghost dirs removal"

* Fri Mar 01 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.4
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Rework clean_one_remap to order ghost dirs removal (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-91524)
 - files: Add file_remap_init (Cyrill Gorcunov <gorcunov@gmail.com>)
 - util: Add mkdirpat_precise helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - Revert "files: Order ghost directories enties"
 - Revert "test: Add unlink_dir test"
 - test: sockets_dgram -- Don't use /tmp (Cyrill Gorcunov <gorcunov@gmail.com>)

* Wed Feb 27 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.3
 - zdtm/mntns_deleted: check if c/r is fine with deleted directory ancestor
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022)
 - mount: temporary create needed ancestor directories for deleted root (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-77022)

* Thu Feb 07 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.2
 - test: Add unlink_dir test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - files: Order ghost directories enties (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-91524)
 - arch,x86: Investigate OSPKE status when handling PKU (#PSBM-91098)

* Mon Jan 28 2019 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.11.0.1
 - ve: tty -- Preallocate space for itty pool (#PSBM-90662)
 - ve: tty -- Eliminate possible race in ve_itty_insert
 - ve: tty -- Drop leftover comment
 - ve: tty -- Investigate master fds with a mutex taken (#PSBM-90662)
 - ve: rst,files -- Guard list with mutex (#PSBM-90662)
 - ve: tty -- Add tty-inherit test
 - ve: tty -- Add support of tty inheritance, v2 (#PSBM-76490)
 - sockets: Don't exit with error if raw module unloaded (Cyrill Gorcunov <gorcunov@gmail.com>)
 - sockets: Be more verbose in collect_err (Cyrill Gorcunov <gorcunov@gmail.com>)
 - net: libnetlink -- Drop ERROR keyword from default handler (Cyrill Gorcunov <gorcunov@gmail.com>)
 - net: sockets -- Don't spam log with known errors (Cyrill Gorcunov <gorcunov@gmail.com>)
 - net: libnetlink -- Call error handler instead of unconditional error message (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: epoll -- Add migrated target test
 - epoll: Save virtual pid for targets
 - epoll: Add ability to restore migrated targets (#PSBM-90012)
 - epoll: Drop duped and closed targets
 - epoll: Defer queued epolls to write at the end of checkpoint
 - Revert "epoll: Ignore migrated tfds on checkpoint"
 - Revert "test: epoll -- Add file inherited case"
 - zdtm.py: also check that mount flags are restored correct (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - zdtm: test dumping file on overmounted mount fails (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - files: open files on overmounted mounts are not supported (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - zdtm: ghost on readonly fs (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - mount: remount ro mounts writable before ghost-file restore (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - mount: save the result of mnt_is_overmounted (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - mount: remove unused argument of do_restore_task_mnt_ns (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82991)
 - files: don't add double slash to path in create_ghost (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - vz7: Add Makefile.version
 - crtools: Show command line in log
 - Rebase to vanilla criu v3.11

* Wed Dec 19 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.21
 - restore: pidfile -- write before post-restore stage (#PSBM-90289)
 - Revert "restore: pidfile -- Write from ve0 context"

* Fri Dec 14 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.20
 - restore: pidfile -- Write from ve0 context (#PSBM-90289)

* Thu Dec 13 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.19
 - log: Write more details in write_pidfile
 - files: Select proper master fd when collecting fd (#PSBM-90293)
 - pstree: Introduce pstree_pid_cmp helper

* Wed Nov 21 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.18
 - test: epoll -- Add file inherited case
 - epoll: Ignore migrated tfds on checkpoint (#PSBM-89961)
 - test: netns_sub_veth -- Disable for a while
 - epoll: Eliminate potential variable shadowing (#PSBM-89961)

* Thu Nov 15 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.17
 - restore: Fix hang if root task is waiting on zombie (#PSBM-89830)
 - restore: Don't ignore errors on wait in restore_one_zombie
 - restore: Add more detailed log in wait_exiting_children
 - restore: zombie -- Add more detailed log on signals

* Tue Nov 06 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.16
 - raw: Don't carry zero options into the image (#PSBM-89822)

* Thu Nov 01 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.15
 - inet: raw -- Add compatibility layer for old images
 - inet: More readable content in show methods (Cyrill Gorcunov <gorcunov@gmail.com>)
 - sockets: Improve helpers to make sockets more readable (Cyrill Gorcunov <gorcunov@gmail.com>)
 - net: Add prefixes for better logging (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Add socket-raw test (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Add checkpoint and restore of raw sockets
 - inet: raw -- Split lookup_socket helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Add preloading raw_diag module (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Add raw sockets into can_dump_inet_sk (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Skip IP_FREEBIND for ipv6 SOCK_RAW sockets (Kirill Tkhai <ktkhai@virtuozzo.com>)
 - inet: raw -- Prepare gen_uncon_sk for raw sockets (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Reuse already known family and type in gen_uncon_sk (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Fetch socket type and check for being raw in can_dump_ipproto (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Check for kernel diag module support (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Add constants needed to fetch properties of a raw socket (Cyrill Gorcunov <gorcunov@gmail.com>)
 - compiler: Add NELEMS_AS_ARRAY helper (Cyrill Gorcunov <gorcunov@gmail.com>)

* Thu Nov 01 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.14
 - mount: cr_pivot_root -- Try temp directory first (#PSBM-89582)
 - mount: Fix typo in message
 - ve: Add helpers for debug sake

* Fri Oct 26 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.13
 - fown: test -- Improve error messaging in file_fown_dead
 - fown: test -- Update file_own_dead to test O_PATH case
 - fown: Don't fail on dumping files opened wit O_PATH (#PSBM-89680)
 - fown: test -- Add file_fown_dead
 - fown: Dont fail if owner is a dead pid (#PSBM-88336)
 - .gitignore: Add patches/

* Mon Oct 22 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.12
 - ve: tty -- Add tty-inherit test
 - ve: tty -- Add support of tty inheritance, v2 (#PSBM-76490)
 - ve: tty -- Add more detailed debug print in ctty verification
 - ve: tty -- Save pid of a task which setups a controlling terminal
 - ve: tty -- Save tty_pgrp in process tree upon read
 - Revert "ve: tty -- Add support of tty inheritance"
 - Revert "ve: tty -- Fill ctty deps from the root task"
 - Revert "ve: tty -- Add tty-inherit test"
 - unix: Don't forget to restore original errno
 - pr-warn: Add missing newlines

* Fri Oct 12 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.11
 - ve: tty -- Fill ctty deps from the root task (#PSBM-89336)

* Wed Oct 10 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.10
 - image: Add missing newline into messages
 - zdtm: check criu restore with --auto-dedup (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-89056)
 - image/dedup: use userns_call to be able to open images for write (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-89056)
 - Punch holes in input files when restoring anonymous non-shared memory if --auto-dedup is enabled. (Pawel Stradomski <pstradomski@google.com>) (#PSBM-89056)

* Tue Oct 09 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.9
 - cr_pre_dump_finish: Fix ignorance of error upon enter (#PSBM-89231)
 - compel: Don't forget to zap remote_map pointer after release (#PSBM-89231)

* Mon Oct 08 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.8
 - ve: tty -- Add tty-inherit test
 - ve: tty -- Add support of tty inheritance (#PSBM-76490)
 - ve: tty -- Don't stuck if several ctty opened
 - ve: tty -- Save virtual group id
 - ve: tty -- Collect real ppid, pgid, sid on dump
 - ve: tty -- Add kdat entry to test if wa have ability to restore inhertied tty
 - x86: cpu -- Don't fail if member is not present in image (#PSBM-89215)

* Tue Oct 02 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.7
 - unix: Disable switching mount namespace (#PSBM-89126)
 - vz7: files-reg -- Show which exactly file can't be created
 - crtools: Show command line in log
 - unix: Don't forget to close ns descriptor on error path

* Tue Sep 25 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.6
 - test: tun -- Check if names are not clashed in different ns (#PSBM-88851)
 - tun: Add compatibility with old images (#PSBM-88851)

* Fri Sep 21 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.5
 - tun: Add support for multiple net ns (Cyrill Gorcunov <gorcunov@gmail.com>)
 - tun: Set net ns before opening master (Cyrill Gorcunov <gorcunov@gmail.com>) (#PSBM-88714)
 - tun: Define log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - test: sk-unix-mntns -- Check for unshare code
 - test: tun_ns -- Make sure unshare passed
 - test: bind-mount-unix -- Implement real connect
 - unix: unix_prepare_bindmount -- Allow to connect via relative name (#PSBM-88274)
 - unix: unlink_sk -- Don't unlink bindmounted sockets
 - unix: bind_unix_sk -- Add ability to skip waiters notification (#PSBM-88274)
 - unix: make_socket -- Break connected pair if requested
 - unix: make_socket -- Add more detailed logs
 - unix: break_connected -- Add a log recod
 - unix: bindmount -- Show details about queuer

* Fri Sep 14 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.4
 - Revert "vz7: scripts: use absolute binaries paths nfs-ports-allow.sh" (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - nfs: when allowing ports in CT netns on dump use host's iptables binary
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-88499)
 - python-criu: Add dependency on python-six (#PSBM-88425)

* Mon Sep 03 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.3
 - inet: raw -- Skip IP_FREEBIND for ipv6 SOCK_RAW sockets (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-88262)
 - test: sk-unix-ucred -- Make compatible with gcc 8

* Fri Aug 31 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.2
 - vz7: image -- Add compat layer for Core entry (#PSBM-88238)
 - unix: typo fix (Andrei Vagin <avagin@virtuozzo.com>)
 - unix: check that a length of a socket is less than UNIX_PATH_MAX (Andrei
Vagin <avagin@virtuozzo.com>)
 - compel: Make sure the hostprog is built early (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - compel: Move lib files into lib-y (Cyrill Gorcunov <gorcunov@gmail.com>)
 - nmk: Make collect-deps to be more precise about targets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - nmk: Add obj and lib deps gathering via helpers (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - nmk: Add collect-target-deps helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - nmk: Add collect-hostprogs-deps helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - nmk: Align continuations (Cyrill Gorcunov <gorcunov@gmail.com>)
 - nmk: Drop unneeded ld_flags (Cyrill Gorcunov <gorcunov@gmail.com>)
 - nmk: Gather reserved vars on top of build (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - nmk: Filter out already seen targets from collect-deps (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - nmk: Don't include deps on mrproper (Cyrill Gorcunov <gorcunov@gmail.com>)

* Thu Aug 30 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.10.0.1
 - x86: cpu -- Require compatibility on instruction level by default (#PSBM-88119)
 - x86: cpu -- Use native uint_x types
 - Rebase to vanilla criu v3.10

* Tue Jul 24 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.33
 - mount: fix segmentation fault in can_mount_now on no mnt_master (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-86978)

* Sat Jul 21 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.32
 - unix: Add compatibility with u7 images (#PSBM-86861)
 - unix: image -- Restore mnt_id index
 - zdtm: temporary make mnt_ext_auto and private_bind_propagation noauto (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-85251)
 - dump/files: remove a leftover from dead_pid_conflict (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-55217)
 - mount: fix regression where open_mountpoint failed on readonly fs (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)

* Mon Jul 16 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.31
 - zdtm: add a test for non-uniform shares (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: remove validate_shared as now we allow non-uniform sharings (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-78703)
 - mount: use propagation groups in propagate_mount replacing excess search
(Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: improve can_mount_now using propagation groups (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: put all mounts which propagate from each other to a list (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: check children of shared slaves restore (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix can_mount_now to wait children of master's share properly (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - zdtm: add a test for unsupported children collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add helper to check unsupported children collision (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)

* Fri Jul 06 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.30
 - inet: raw -- Storm the test with all protos (#PSBM-86357)
 - inet: raw -- Lookup for collected bit on non-raw sockets only (#PSBM-86357)

* Thu Jul 05 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.29
 - zdtm/static: add a test to check epoll file descriptors (Andrei Vagin
<avagin@virtuozzo.com>)
 - epoll: Use epoll queues to speedup multiple duped fds (#PSBM-86295)
 - files: make_gen_id -- Promote to be general helper (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Add kid_lookup_epoll_tfd helper (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Exit with error if tfd is missing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Save fields of target files in eventpoll_tfd_entry (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Add kcmp_epoll check
 - epoll: Align members in assignments (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Print efd id when showing targets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Show tfd in decimal form (Cyrill Gorcunov <gorcunov@gmail.com>)
 - epoll: Add support for multiple duped fds (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - Revert "epoll: Add support for multiple duped fds"
 - Revert "epoll: Drop unneeded variable from cycle"
 - Revert "test: eventfs00 -- Extend to test duped fd"
 - Revert "epoll: Fix typo in var type"

* Fri Jun 29 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.28
 - epoll: Fix typo in var type (#PSBM-86256)

* Thu Jun 28 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.27
 - Revert "mount: don't lose shared options for bind mounts"

* Wed Jun 27 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.26
 - fdstore: Unlimit fdstore queue on start (#PSBM-86038)
 - Revert "fdstore: Print detailed error when queue is exhausted"
 - test: eventfs00 -- Extend to test duped fd (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - epoll: Drop unneeded variable from cycle (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Add support for multiple duped fds (#PSBM-60161)
 - Revert "test: eventfs00 -- Extend to test duped fd"

* Mon Jun 25 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.25
 - fdstore: Print detailed error when queue is exhausted (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-86038)
 - zdtm: shared options should not be lost for bind mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm.py: also check that sharing options are restored for mounts (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: don't lose shared options for bind mounts (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-85251)
 - unix: test,sk-unix01 -- Fix data sending for be machines (Cyrill Gorcunov
<gorcunov@gmail.com>)

* Fri Jun 22 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.24
 - net: veth -- Don't force to create master peer index if no nsid (#PSBM-85558)
 - net: Add net log prefix

* Thu Jun 21 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.23
 - test: eventfs00 -- Extend to test duped fd (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - epoll: Use kcmp to find proper target file (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-60161)
 - epoll: Use real file transferred for target fds check (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - epoll: Pass drained fds to dump_one_file
 - epoll: kdat -- Check if we have KCMP_EPOLL_TFD support
 - kcmp: Add epoll definitions (Cyrill Gorcunov <gorcunov@gmail.com>)
 - kcmp: Drop empty line at EOF (Cyrill Gorcunov <gorcunov@openvz.org>)
 - kcmp: Beautify kcmp-ids.h (Cyrill Gorcunov <gorcunov@openvz.org>)
 - kcmp: Cleanup sources (Cyrill Gorcunov <gorcunov@openvz.org>)
 - Revert "vz7: epoll -- Dont fail on dup'ed fd restore"
 - Revert "vz7: epoll -- Use real file transferred for target fds check"

* Tue Jun 19 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.22
 - inventory: save dump_uptime for criu dump if track_mem is set (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-85936)
 - zdtm: check that pid-reuse does not break iterative memory dump (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - zdtm/lib: add pre-dump-notify test flag (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - memory: don't use parent memdump if detected possible pid reuse (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - inventory: add a helper to get entry of parent pre-dump (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - inventory: save uptime to know when dump had happened (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - parse: add a helper to obtain an uptime (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - Revert "parse: add a helper to obtain an uptime"
 - Revert "stats: save uptime to know when dump had happened"
 - Revert "stats: add a helper to get stats of parent pre-dump"
 - Revert "memory: don't use parent memdump if detected possible pid reuse"
 - Revert "mem: Fix typo in detect_pid_reuse"
 - Revert "mem: pid-reuse -- Don't fail if no stat image present"
 - Revert "pid-reuse: temporary use stat file from cwd if has no parent stats"
 - x86: cpu -- Proceed even if xsavec detected for dev reason (Cyrill Gorcunov
<gorcunov@gmail.com>)

* Fri Jun 15 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.21
 - unix: Add bind-mount-unix test case (Cyrill Gorcunov <gorcunov@openvz.org>)
 - unix: Add support for bindmounted sockets (#PSBM-82616)
 - unix: Move shared data init into early stage (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets into own list (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect images before opening mountpoints (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Collect bindmounted unix sockets
 - unix: image -- Move uflags into enum
 - unix: image -- Shift mnt_id index (Cyrill Gorcunov <gorcunov@gmail.com>)
 - zdtm: Add sstrncpy helper (Cyrill Gorcunov <gorcunov@gmail.com>)

* Fri Jun 15 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.20
 - x86: cpu -- Show which exactly features are failing in fpu capability mode
(Cyrill Gorcunov <gorcunov@gmail.com>)
 - x86: cpu -- Use rt information since it might we filtered
 - x86: cpu -- Add ability to ignore xsaves (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - compel: cpu -- Add ability to clear features (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - x86: cpu -- Report when unsupported compact xsave frame detected (#PSBM-83611)
 - x86: cpu -- Check for xsaves bit on cpu validation (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - x86: cpu -- Show additional xsave info on init (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - x86: cpu -- Add new instruction bits to check (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - x86: cpu -- Sync bits with kernel
 - crit: Show cpuinfo image
 - x86: Use uint_x types in rt_sigcontext (Cyrill Gorcunov <gorcunov@gmail.com>)
 - vz7: net -- Add missing newline into debug message

* Fri Jun 01 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.19
 - vz7: Move cpu_init into early_init (#PSBM-85265)

* Tue May 29 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.18
 - unix: test -- Add sk-unix01 test (#PSBM-82615)
 - unix: Improve debug message when collecting socket (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Add support of ghost sockets (#PSBM-82615)
 - unix: Use decimal format for inode printing (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Rename unlink_stale to unlink_sk (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Move unix_resolve_name declaration on top
 - sk-unix: don't pass a negative value to close() (Andrei Vagin
<avagin@virtuozzo.com>)
 - parasite: Rename misnamed nr_pages (Dmitry Safonov <dima@arista.com>)
 - zdtm: mount tmpfs into /run in a test root (Andrei Vagin
<avagin@virtuozzo.com>)
 - fs: take into account that cr_system overrides standard descriptors (Andrei
Vagin <avagin@virtuozzo.com>)
 - net: workaround a problem when iptables can't open /run/xtables.lock (Andrei
Vagin <avagin@openvz.org>)
 - zdtm: create /run in a test root (Andrei Vagin <avagin@virtuozzo.com>)
 - criu: fix 'criu --version'
 - service: don't cache a service descriptor
 - files: drop O_TMPFILE from file descriptor flags (Andrei Vagin
<avagin@virtuozzo.com>)
 - criu: print criu and kernel versions from log_init()
 - criu: initialize logging for libraries from log_set_loglevel()
 - zdtm: check an exit code of a straced restore (Andrey Vagin
<avagin@virtuozzo.com>)
 - zdtm.py: fix a logic about determing a test flavor in a error case (Andrei
Vagin <avagin@virtuozzo.com>)
 - unix: split dump_external_sockets() for readability (Andrey Vagin
<avagin@virtuozzo.com>)
 - unix: fix an error code in bind_unix_sk()
 - unit: don't check ui->ue->name.len twice in bind_unix_sk() (Andrey Vagin
<avagin@virtuozzo.com>)
 - unix: split bind_unix_sk() for readability (Andrey Vagin
<avagin@virtuozzo.com>)
 - unix: restore sockets on correct mount points
 - unix: resolve a socket file when a socket descriptor is available
 - kerndat: check the SIOCUNIXFILE ioctl for unix sockets
 - unix: handle sockets with USK_CALLBACK as external sockets (Andrey Vagin
<avagin@virtuozzo.com>)
 - sockets: Add sock_type_name and tcp_state_name helpers (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Unify id and ino prints (Cyrill Gorcunov <gorcunov@gmail.com>)
 - seccomp: Don't exit from __export_restore_thread (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - seccomp: Use own seccomp_metadata_t type (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - action-scripts: check a return code of get_service_fd
 - kdat: fill kdat by zero-s before initializing it (Andrei Vagin
<avagin@virtuozzo.com>)

* Thu May 17 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.17
 - files: Don't forget on stipping deleted postfix on linked files (#PSBM-84731)

* Thu May 17 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.16
 - unix: Improve init_unix_sk_info
 - unix: Unify printings on peer open (Cyrill Gorcunov <gorcunov@gmail.com>)
 - unix: Print reverted dir info if only directory provided
 - unix: Don's spam with warning if nothing to unlink (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - unix: Adjust unix_desc_ops members
 - unix: Adjust unix_sk_info members
 - unix: Use uint32_t instead of u32
 - unix: Use one word log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - arch, ppc64: Add missing atomic_dec_and_test helper (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - seccomp: Fix building issue on recent kernels (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - mem: Fix typo in detect_pid_reuse
 - seccomp: Fix typo in collect_filters
 - tun: don't leak a file descriptor (Andrei Vagin <avagin@virtuozzo.com>)
 - pie/log: print space after timestamp (Andrei Vagin <avagin@virtuozzo.com>)
 - compel/log: increase a max line length (Andrey Vagin <avagin@virtuozzo.com>)
 - sfd: Don't forget to test sfd_map when closing old fds (#PSBM-83892)

* Wed May 09 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.15
 - swrk: Don't forget to setup loggin into compel (#PSBM-84029)
 - cpu: x86 -- Call for cpu_init before kerndat_init (#PSBM-84029)

* Tue May 08 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.14
 - seccomp: Move changed ptrace flags setup after creds (#PSBM-84198)

* Sat Apr 28 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.13
 - seccomp: test,seccomp_filter_threads -- Fix compilation on old distros
 - seccomp: test -- Open in readonly mode (Cyrill Gorcunov <gorcunov@gmail.com>)
 - seccomp: test,seccomp_filter_threads -- Use multiple threads (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - seccomp: Dont forget to suspend filtering on threads (#PSBM-78762)

* Tue Apr 24 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.12
 - files: define O_TMPFILE (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-83713)

* Mon Apr 23 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.11
 - seccomp: test -- Add seccomp_filter_threads (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: Add engine to checkpoint per-thread seccomp chains (#PSBM-78762)
 - seccomp: Add engine to restore per-thread seccomp chains (#PSBM-78762)
 - seccomp: Fetch seccomp flags if kernel provides (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - seccomp: Move seccomp_info into seccomp.h (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - seccomp: Define log prefix (Cyrill Gorcunov <gorcunov@gmail.com>)
 - seccomp: compel -- Add PTRACE_SECCOMP_GET_METADATA definition (Cyrill
Gorcunov <gorcunov@gmail.com>)

* Wed Apr 18 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.8.0.10
 - pid-reuse: temporary use stat file from cwd if has no parent stats (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-82864)

* Tue Apr 17 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.8.0.9
 - files: fix clone_service_fd overlap handling (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-83472)

* Fri Apr 13 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.8.0.8
 - netlink: Change NETLINK_REPAIR number (#PSBM-83415)
 - files: Fail dump if dump_one_file() fails (Andy Tucker <agtucker@google.com>)

* Tue Apr 10 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.8.0.7
 - sfds: Fix UB in choose_service_fd_base due to calling __builtin_clz(0)
(Radoslaw Burny <rburny@google.com>)
 - files: Don't fail on cgroup directories mode change (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-83154)

* Wed Apr 04 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.6
 - files: Don't fail on cgroup directories mode change (#PSBM-83154)

* Wed Apr 04 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.8.0.5
 - zdtm: Add tun_ns test (Andrew Vagin <avagin@virtuozzo.com>)
 - net: Dump tun device net id in img (Andrew Vagin <avagin@virtuozzo.com>)
 - tun: Check that net ns of tun device is dumped
 - tun: Check tun has ioctl() cmd SIOCGSKNS
 - net: Extrack ioctl() call from kerndat_socket_netns()
 - test: unlink_multiple_largefiles -- Make noauto (Cyrill Gorcunov
<gorcunov@virtuozzo.com>)
 - zdtm: Add a test to check if we can C/R ghost files with no parent dirs.
(Vitaly Ostrosablin <vostrosablin@virtuozzo.com>)
 - restore: Do not init fdstore twice
 - sk-unix: Use unsigned values for inodes (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-82945)
 - vz: test -- Make socket_udp-corked use different port (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)

* Fri Mar 23 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.4
 - mem: pid-reuse -- Don't fail if no stat image present (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-82806)

* Thu Mar 22 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.3
 - vz: pipes -- Restore pipe size in sync mode (#PSBM-82796)
 - unix: Fix nil dereference in find_queuer_for (#PSBM-82796)

* Thu Mar 22 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.2
 - inet: raw -- Add simple socket-raw test (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - inet: raw -- Add restore of raw sockets (Cyrill Gorcunov
<gorcunov@gmail.com>) (#PSBM-82683)
 - inet: raw -- Dump raw sockets options (Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Add raw sockets into can_dump_inet_sk (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - inet: raw -- Prepare gen_uncon_sk for raw sockets (Cyrill Gorcunov
<gorcunov@gmail.com>)
 - inet: raw -- Reuse already known family and type in gen_uncon_sk (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Fetch socket type and check for being raw in can_dump_ipproto
(Cyrill Gorcunov <gorcunov@gmail.com>)
 - inet: raw -- Check for kernel diag module support
 - inet: raw -- Add constants needed to fetch properties of a raw socket (Cyrill
Gorcunov <gorcunov@gmail.com>)
 - Revert "vz7: sk-inet: Add initial support for raw sockets"
 - Revert "vz7: test: Add simple socket-raw test"
 - Revert "vz: test,socket-raw -- Disable for a while"
 - memory: don't use parent memdump if detected possible pid reuse (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - stats: add a helper to get stats of parent pre-dump (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - stats: save uptime to know when dump had happened (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-67502)
 - parse: add a helper to obtain an uptime (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>) (#PSBM-67502)

* Tue Mar 20 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.8.0.1
 - vz: net: Skip IP_FREEBIND for ipv6 SOCK_RAW sockets (Kirill Tkhai
<ktkhai@virtuozzo.com>) (#PSBM-82558)
 
* Thu Mar 01 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.202
 - seccomp: test -- Add seccomp_filter_threads (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: Allow to dump thread with different seccomps (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: Drop no longer needed comment (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: Drop filter mode on tsync propagation (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: dump_seccomp_filters -- Be ready for chains absence (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: collect_filters -- Drop unneeded parent (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: Always setup chain flags (Cyrill Gorcunov <gorcunov@openvz.org>)
 - seccomp: Try use tsync flag if possible (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seccomp: Add restore of per-thread filters (#PSBM-78762)
 - seccomp: Don't use BUG_ON in dump_seccomp_filters
 - seccomp: Rename last_filter to img_filter_pos
 - seccomp: Speedup entry cleaning
 - seccomp: Add support of per thread filters on dump
 - seccomp: Produce thread core records
 - seccomp: Drop leftover member from pstree
 - seccomp: Untaggle entries from process_tree
 - seccomp: Move filter position into seccomp_entry
 - seccomp: images,core -- Move seccomp data into per-thread origin
 - seccomp: Use tid_real member name
 - seccomp: Drop pi_creds from dmp_info
 - seccomp: Drop pstree_item from find_inherited
 - seccomp: Define prefix for logging
 - seccomp: Use collected seccomp_entry to figure out if filter is present
 - seccomp: Collect seccomp data on per-thread basis
 - seccomp: Move seccomp_info into seccomp.h
 - seccomp: Fetch seccomp flags if kernel provides
 - compel: seccomp -- Add PTRACE_SECCOMP_GET_METADATA data
 - eventpoll: Take into account number of semi-valid fds when dumping (#PSBM-81809)

* Mon Feb 26 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.39
 - eventpoll: Take into account number of semi-valid fds when dumping (#PSBM-81809)
 - check: Include sys/mount.h before linux/aio_abi.h
 - log: pr_warn_once -- Fix formatting

* Tue Feb 20 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.201
 - version: Lift up version to 200
 - tty: ctty -- Add support for multiple inherited ctty opened (#PSBM-76490)
 - tty: Move session lookup leader into find_session_leader
 - kdat: Add test for ctty inheritance
 - tty: Fetch ctty index based on sid
 - tty: Add is_ctty helper
 - tty: Don't check for group inheritance
 - check: Include sys/mount.h before linux/aio_abi.h
 - log: pr_warn_once -- Fix formatting

* Wed Feb 14 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.38
 - inotify: Use fast way of obtaining desired watch descriptor number (#PSBM-81411)
 - kdat: Add check for inotify() INOTIFY_IOC_SETNEXTWD cmd (#PSBM-81411)

* Thu Feb 08 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.37
 - inotify: Fix open_*notify_fd() never fails
 - inotify: Do not DDOS by debug message on restore watch descriptor

* Mon Jan 29 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.36
 - files: change error to warning in linkat_hard error path (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: check ghost restores on readonly fs if it is also a ghost in other
writable bind (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - files: make convert_path_from_another_mp always return relative path (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>) (#PSBM-72351)

* Tue Jan 16 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.35
 - files-reg: Prepare for sysfs entries mode change (#PSBM-80585)

* Mon Jan 15 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.34
 - vz7/cgroup: fix ifpriomap skip (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)

* Wed Jan 10 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.33
 - zdtm: improve tempfs_overmounted test (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: do remaps for child-overmount of another overmount (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: fix try_remap_mount (Pavel Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: fix mnt_resort_siblings to work as described (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - zdtm: now tempfs_overmounted will pass so remove crfail (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: make open_mountpoint handle overmouts properly (#PSBM-57362)
 - mount add umount_overmounts helper to make mount visible (Pavel Tikhomirov
<ptikhomirov@virtuozzo.com>)
 - mount: add __umount_children_overmounts helper to make mount visible (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)
 - mount: add mnt_is_overmounted helper to check mount visibility (Pavel
Tikhomirov <ptikhomirov@virtuozzo.com>)

* Tue Jan 09 2018 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.32
 - restore: Split restore_one_helper() and wait exiting zombie children

* Sat Jan 06 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.31
 - Revert "vz7: bc, restore -- Check for failcounters on error" (#PSBM-80056)

* Sat Jan 06 2018 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.30
 - arch, x86: int80 -- Clobber all rX registers (#PSBM-80095)

* Mon Dec 25 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.29
 - spfs: start SPFS manager in containers network namespace (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>) (#PSBM-79733)

* Fri Dec 22 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.28
 - spfs: switch mounts mode to STUB after root yard depopulation (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: return duplicated socket from usernsd (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-79462)
 - spfs: improve prints in spfs_set_mode() and spfs_release_replace() (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: improve SPFS manager start debug and error output (Stanislav
Kinsburskiy <skinsbursky@virtuozzo.com>)
 - spfs: remove redundant spfs_service_fd() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: improve error and debug output for spfs_mount() (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)
 - spfs: introduce request_spfs_mngr_sock)() helper (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>)

* Thu Dec 07 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.27
 - criu: Don't fail if ghost file has no parent dirs. (Vitaly Ostrosablin
<vostrosablin@virtuozzo.com>)

* Mon Dec 04 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.26
 - tty: Use mnt_id for first lookup of toplevel devpts (#PSBM-78460)
 - ns: Set hookups for all namespaces
 - ns: Set nested namespaces hookups

* Tue Nov 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.25
 - Revert "vz7: sfd: Lift up own fd limit on bootup" (#PSBM-67194)
 - vz7: service: Allow keep_open flag for a WAIT_PID command (#PSBM-58198)
 - test: static,aio01 -- Use proper type for context
 - test: sigaltstack -- Drop useless test of a leader stack (#PSBM-76744)

* Thu Nov 02 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.24
 - Revert "restore/cgroup: make root task enter cgroups before setup-namespaces
action" (#PSBM-76648 #PSBM-76609)
 - soccr: c/r ipv6 sockets which handles ipv4 connections (#PSBM-72350)

* Thu Nov 02 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.23
 - soccr: c/r ipv6 sockets which handles ipv4 connections (#PSBM-72350)

* Tue Oct 31 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.22
 - restore/cgroup: make root task enter cgroups before setup-namespaces action (#PSBM-64756)

* Tue Oct 31 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.21
 - sk-inet: restore a value of SO_REUSEADDR (#PSBM-75515)

* Mon Oct 30 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.20
 - compel: x86,compat -- Make sure mmap fits compat task size (#PSBM-76379)
 - compel: Do not loose sign of result in compat syscall (#PSBM-76379)

* Mon Oct 30 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.19
 - compel: Do not loose sign of result in compat syscall (#PSBM-76379)

* Fri Oct 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.18
 - mount: export_mnt_ns_roots -- Fix lack on ending EOS

* Fri Oct 20 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.17
 - mount: allow overmount on parent with shared group (#PSBM-69501)
 - mount: fix parent shared group dependency in can_mount_now (#PSBM-69501)

* Thu Oct 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.16
 - net: execute iptables-restore in a target network namespace (#PSBM-75531)
 - vz7: crit: Use lu for pagemap images (#PSBM-75112)
 - vz7: image-desc -- Make pagemap and pagemap-shmem images to use lu (#PSBM-75112)

* Fri Oct 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.15
 - action-scripts: Export mount namespace roots via CRIU_MNT_NS_ROOTS (#PSBM-71861)
 - mount: Add export_mnt_ns_roots helper (#PSBM-71861)
 - build: Rename snapshot to tarball

* Fri Oct 06 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.14
 - vz7: libsoccr: ignore data in a sent queue, if a connect is closed (#PSBM-67026)
 - make: Add snapshot target

* Thu Sep 28 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.13
 - scripts: add "-w" to iptables command (Stanislav Kinsburskiy
<skinsbursky@virtuozzo.com>) (#PSBM-73153)

* Thu Sep 28 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.12
 - kdat: if iptables-restore has xtable lock support do wait on lock
 - Revert "net: Call ip[6]tables-restore with -w parameter"

* Wed Sep 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.11
 - fsnotify: Filter event mask from old kernels (#PSBM-73140)

* Mon Sep 25 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.10
 - net: Call ip[6]tables-restore with -w parameter
 - Revert "net: Execute ip[6]tables-{save,restore} with -w option"

* Fri Sep 22 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.9
 - net: Execute ip[6]tables-{save,restore} with -w option (Kirill Tkhai
<ktkhai@virtuozzo.com>)

* Fri Sep 22 2017 Kirill Tkhai <ktkhai@virtuozzo.com> 3.4.0.9
 - net: Execute ip[6]tables-{save,restore} with -w option

* Wed Sep 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.8
 - autofs: use safe xatol() and xatoi() helpers (#PSBM-72109)
 - util: xatol() and xatoi() helpers introduced
 - Revert "vz7: util: xatol() and xatoi() helpers introduced"
 - Revert "vz: autofs: use safe xatol() and xatoi() helpers"
 - vz: autofs: use safe xatol() and xatoi() helpers (#PSBM-72109)
 - vz7: util: xatol() and xatoi() helpers introduced
 - zdtm: Implement different per-thread credentials testcase

* Wed Sep 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.7
 - vz: autofs: use safe xatol() and xatoi() helpers (#PSBM-72109)
 - vz7: util: xatol() and xatoi() helpers introduced
 - zdtm: Implement different per-thread credentials testcase

* Tue Sep 12 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.6
 - vz7: vdso: Map vdso with arch_prctl() if kdat.can_map_vdso (#PSBM-71884)
 - vz7: vdso/restorer: Don't map compatible vdso if it was unmapped (#PSBM-71884)
 - vz7: vdso: Don't park vdso/vvar if restoree doesn't have them (#PSBM-71884)
 - vz7: kdat: Add test for presence of vdso mapping API (#PSBM-71884)
 - vz7: vdso: Don't read pagemap or parse symtable (#PSBM-71884)

* Fri Sep 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.5
 - vz7: tests: do not try to read more than packet in AutoFS test (#PSBM-71078)
 - Revert "vz7: zdtm: print autofs request size, if read more than expected"
 - Revert "vz7: zdtm: fix autofs tes compilation"
 - Revert "vz7: zdtm: fix package memory allocation in autofs.c"

* Thu Aug 31 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.4
 - vz7: zdtm: fix package memory allocation in autofs.c (#PSBM-71078)
 - vz7: tty -- Fix TTY_BITMAP_BITS
 - vz7: image -- Add compat layer for Core entry (#PSBM-67671)

* Thu Aug 31 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.3
 - vz7: sk-unix -- Drop redundant unix_sk_cinfo reference

* Wed Aug 30 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.2
 - vz7: sk-tcp: Print libsoccr_save() error message
 - vz7: zdtm: fix autofs tes compilation (#PSBM-71041)
 - tty: collect_one_tty_info_entry -- Move tracking setup into main cycle (#PSBM-70929)
 - tty: collect_one_tty -- Make sure the index is in range
 - tty: tty_has_active_pair -- Make sure no overflow happened
 - tty: tty_test_and_set -- Make sure no overflow happened
 - tty: Fix __tty_verify_active_pairs
 - tty: Use macros for bitmap length
 - vz7: images -- Add task_core_entry_vz730 stub

* Tue Aug 29 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.4.0.1
 - Rebase on CRIU v3.4 (#PSBM-70650)

* Wed Aug 23 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.202
 - zdtm: print autofs request size, if read more than expected (#PSBM-70345)

* Mon Aug 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.201
 - test: mount -- Add bind-mount-unix
 - sk-unix: Handle bindmounted dgram sockets on restore (#PSBM-69473)
 - sk-unix: Save mnt_id for bindmounted entries (#PSBM-69473)
 - versions: Increase to not conflict with hotfix series

* Tue Aug 08 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.37
 - version: Force increase for hf1
 - fsnotify: open_handle -- Handle multiple mounts with same s_dev (#PSBM-69473)
 - Log into /var/log/mesages large ghost files dumps (#PSBM-68320)

* Tue Aug 08 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.35
 - fsnotify: open_handle -- Handle multiple mounts with same s_dev (#PSBM-69473)
 - Log into /var/log/mesages large ghost files dumps (#PSBM-68320)

* Fri Jul 28 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.34
 - pie, restorer: Fix typo in wait_helpers (#PSBM-69378)

* Thu Jul 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.33
 - page-xfer: Make error message more verbose (#PSBM-68738)

* Thu Jul 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.32
 - Revert "sfd: Reserve service descriptors early" (#PSBM-69279 #PSBM-69259)
 - Revert "sfd: Don't forget to close pre-opened tty service fd"

* Wed Jul 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.31
 - sfd: Don't forget to close pre-opened tty service fd (#PSBM-69211)

* Wed Jul 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.30
 - sfd: Reserve service descriptors early (#PSBM-68738)

* Mon Jul 24 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.29
 - vz7/cgroup: Skip for awhile ifpriomap property restore (#PSBM-66683)

* Mon Jul 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.28
 - vz7: bc, restore -- Check for failcounters on error (#PSBM-68868)
 - vz7: criu: update second "iptables restore" helper to work in VE#0 (#PSBM-58574)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint

* Mon Jul 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.27
 - vz7: criu: update second "iptables restore" helper to work in VE#0 (#PSBM-58574)
 - vz7: systemd-autofs-restart.sh: return meaningful value from
restore_mountpoint

* Mon Jul 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.26
 - vz7: criu: threads -- Allow uids/gids being different (#PSBM-68756)
 - vz7: sk-inet: udp -- Don't fail on calling shutdown on disconnected socket (#PSBM-68062)
 - vz7: mount: restore_task_mnt_ns - Lookup for mount namespace conditionally (#PSBM-68062)

* Fri Jul 21 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.25
 - net: do iptables restore in ve0 (#PSBM-58574)
 - net: iptables_tool_{dump,restore} helpers introduced
 - criu: export join_ve helper

* Thu Jul 20 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.24
 - restore: Fix deadlock when helper's child dies (#PSBM-67930)
 - page-xfer: handle a case when splice returns zero (#PSBM-68732)

* Wed Jul 19 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.23
 - mount: allow any types of NFS mount for a while (#PSBM-68663)

* Wed Jul 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.22
 - mounts: support NFS bind-mounts in the same shared group (#PSBM-68663)

* Tue Jul 18 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.21
 - criu: don't abort criu in lookup_create_item() (#PSBM-68607)
 - dump: set pid->state for threads (#PSBM-68585)
 - mounts: support only shared NFS mounts in inits mount namespace (#PSBM-66945)

* Sat Jul 15 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.20
 - mount: Switch user_ns before mount binfmt_misc (#PSBM-68377)
 - ve: Call binfmt_misc-mounting code in call_in_child_process()
 - util: Implement clone_in_child_process() helper
 - clone_noasan: Allow to create CLONE_VM|CLONE_VFORK processes
 - mount: Move binfmt_misc-mounting code to separate function
 - mount: Consider EBUSY binfmt_misc mount return as error

* Wed Jul 12 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.19
 - vz7: files -- Don't access value from stack in outer contex
 - mount: Don't search for siblings inside self (#PSBM-67723)
 - vz7: vdso: Map vdso with arch_prctl() if kdat.can_map_vdso (#PSBM-67017)
 - vdso/restorer: Don't map compatible vdso if it was unmapped
 - vdso: Don't park vdso/vvar if restoree doesn't have them
 - kdat: Add test for presence of vdso mapping API
 - vz7: vdso: Don't read pagemap or parse symtable (#PSBM-67017)
 - vdso: Introduce type for checking vdso hint in maps file
 - vz7: sk-queue: fix non-fatal print log level
 - vz7: netlink: fix warning print

* Wed Jul 12 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.18
 - vz7: vdso: Map vdso with arch_prctl() if kdat.can_map_vdso (#PSBM-67017)
 - vdso/restorer: Don't map compatible vdso if it was unmapped
 - vdso: Don't park vdso/vvar if restoree doesn't have them
 - kdat: Add test for presence of vdso mapping API
 - vz7: vdso: Don't read pagemap or parse symtable (#PSBM-67017)
 - vdso: Introduce type for checking vdso hint in maps file
 - vz7: sk-queue: fix non-fatal print log level
 - vz7: netlink: fix warning print

* Fri Jun 30 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.17
 - cr-service: Init page_ids laterly
 - images: Initialize images earlier (before page-server starts) (#PSBM-67335)
 - pages: Share page_ids between ns dump-helpers (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump
 - vz7: files-reg: forbid migration of opened device files on NFS (#PSBM-55590)

* Thu Jun 29 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.16
 - images: Initialize images earlier (before page-server starts) (#PSBM-67335)
 - pages: Share page_ids between ns dump-helpers (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump
 - vz7: files-reg: forbid migration of opened device files on NFS (#PSBM-55590)

* Thu Jun 29 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.15
 - pages: Share page_ids between ns dump-helpers (#PSBM-67335)
 - vz7: mount: check for mount is unsupported only on dump
 - vz7: files-reg: forbid migration of opened device files on NFS (#PSBM-55590)

* Fri Jun 23 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.14
 - scripts: cleanup error output in systemd-autofs-restart.sh (#PSBM-67544)
 - scripts: check service mountpoint is not empty in systemd-autofs-restart.sh (#PSBM-67544)

* Wed Jun 21 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.13
 - mem: Don't assume guard page is returned in procfs with new kernels (#PSBM-67433)
 - kerndat: Detect if we have guard page mangle in procfs output

* Tue Jun 20 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.12
 - mounts: print NFS nested mountpoint info (#PSBM-67466)
 - mounts: add unsupported mount helper (#PSBM-67466)

* Mon Jun 19 2017 Andrey Bondrov <abondrov@virtuozzo.com> 3.0.0.11-3
- Drop libcompel explicit dependency from criu

* Mon Jun 19 2017 Andrey Bondrov <abondrov@virtuozzo.com> 3.0.0.11-2
- Split libcompel and libcompel-devel to subpackages

* Fri Jun 09 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.11
 - spfs: fix usage of mi->ns_mountpoint (#PSBM-66943)
 - spfs: pass both "mountpoint" and "ns_mountpoint" paths to manager (#PSBM-66943)

* Thu Jun 08 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.10
 - Revert "vz7: sfd: Move service fd helpers into separate file" (#PSBM-65382)
 - Revert "vz7: sfd: Rework install, clone helpers to use fcntl" (#PSBM-65382)
 - Revert "vz7: sfd -- Don't forget to skip reserved fds on clone" (#PSBM-65382)
 - files: remove extra newline from a message

* Tue Jun 06 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.9
 - mount: don't use phys_stat_resolve_dev() in open_mount() (#PSBM-66981)
 - vz7: tests: shm-unaligned -- Use unique key for simultaneous run (Cyrill
Gorcunov <gorcunov@virtuozzo.com>) (#PSBM-66764)

* Fri Jun 02 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.8
 - scripts: use absolute binaries paths systemd-autofs-restart.sh (#PSBM-66967)

* Thu Jun 01 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.7
 - zdtm: run page-server via rpc
 - lib/py: allow to execute page-server as a child process
 - service: allow to execute page-server as a child process
 - scripts: use absolute binaries paths nfs-ports-allow.sh (#PSBM-66901)

* Thu Jun 01 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.6
 - ia32/feature-test: Don't check i686 libraries presence
 - nmk: Provide try-asm build check function
 - mount: Find NS_ROOT for cr-time mount on restore (#PSBM-66457)

* Thu Jun 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.5
 - vz7: sfd -- Don't forget to skip reserved fds on clone (#PSBM-66874)

* Wed May 31 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.4
 - Revert "vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump"
 - Revert "vz7: restore -- Lift up own file limits"
 - vz7: sfd: Lift up own fd limit on bootup (#PSBM-65382)
 - vz7: kdat: Add fetching files stat (#PSBM-65382)
 - vz7: sfd: Rework install, clone helpers to use fcntl (#PSBM-65382)
 - vz7: sfd: Move service fd helpers into separate file (#PSBM-65382)
 - x86/ia32: fix build with DEBUG=1 (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - vdso/compat: Don't unmap missing vdso/vvar vmas (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - pie/vdso: return back ELF header mismatch error (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - ia32/futex: restore compat_robust_list (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - ia32/futex: add dumping compat_robust_list (Dmitry Safonov <dsafonov@virtuozzo.com>)
 - restorer: remove always true `has_futex' arg (Dmitry Safonov <dsafonov@virtuozzo.com>)

* Fri May 12 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.3
 - scripts: skip spfs mount points in systemd-autofs-restart.sh (#PSBM-66285)
 - scripts: check service mount point in "skip_service" systemd-autofs-
restart.sh
 - scripts: "skip_service" helper introduced in systemd-autofs-restart.sh
 - vz7: tests -- Drop _GNU_SOURCE from source code (Cyrill Gorcunov
<gorcunov@virtuozzo.com>) (#PSBM-66278)

* Thu May 11 2017 Dmitry Safonov <dsafonov@virtuozzo.com> 3.0.0.2
 - vz7: fs: Add new argument to fstype::parse() and use it in binfmt_misc
(Cyrill Gorcunov <gorcunov@virtuozzo.com>)
 - make: Report dependencies absence more exactly
 - ia32: Rename has_compat_sigreturn => compat_cr
 - ia32: Clearify if 32bit C/R is compile-disabled

* Thu May 11 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.1
 - vz7: Makefile.version -- Adjust number for new series
 - vz7: Makefile: Fix scripts installation
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join (#PSBM-65483)
 - vz7: tty: Make sure no /dev/tty inheritance exist (#PSBM-65637)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)
 - vz7: test: sk-unix01 -- Make sure the dir with ghost files are empty
 - vz7: sk-unix: Don't wait on socketpair (#PSBM-65051)
 - vz7: sk-unix -- Add info print about slave peers
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - vz7: sk-unix -- Fix typo in namelen comparision (#PSBM-64715)
 - vz7: sk-queue: Add missing newline into log
 - vz7: restore_sk_queue -- Show how many bytes already sent (#PSBM-64628)
 - vz7: test: sk-unix01 -- Fix compilation
 - vz7: sk-unix: Don't append ghost postfix on subsequent checkpoint (#PSBM-55992)
 - test: Add sk-unix01 test
 - vz7: sk-unix: Add ability to restore sockets with deleted vfs addresses
 - vz7: sk-unix: Print cwd been restored if @name_dir is present
 - vz7: sk-unix: Don't warn if nothing to unlink
 - vz7: sk-unix: Collect deleted identical addresses in the queues
 - vz7: sk-unix: Make USK_ flags in shift form
 - vz7: sk-unix: Drop empty line at eof
 - vz7: sk-unix: Use add_post_prepare_cb_once helper
 - vz7: sk-unix: Drop empty line
 - vz7: sk-unix: Use generic xptr_pull in dump_one_unix_fd
 - vz7: sk-unix: Use native types in unix_sk_info
 - vz7: sk-unix: Adjust unix_sk_info members
 - vz7: sk-unix: Adjust unix_sk_cinfo members
 - vz7: sk-unix: Make can_dump_unix_sk being boolean
 - vz7: pipes: Use add_post_prepare_cb_once
 - vz7: tty: Use add_post_prepare_cb_once
 - vz7: restore: Add add_post_prepare_cb_once helper
 - sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: sk-queue -- Show peers in hex form (#PSBM-64009)
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: epoll -- Dont fail on dup'ed fd restore (#PSBM-63850)
 - vz7: dump: Any non-negative return code of run_scripts means an error (#PSBM-62583)
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: seize -- Show detached pid in freezer_detach
 - vz7: Show status of uninterruptable task (#PSBM-63211)
 - vz7: files -- Select proper master fd when collecting fd (#PSBM-63355)
 - vz7: pstree -- Introduce pstree_pid_cmp helper
 - vz7: page-xfer -- Handle partial splicing (#PSBM-63161)
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)
 - vz7: epoll -- Use real file transferred for target fds check (#PSBM-62108)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - test: Add ucreds test
 - vz7: pagemap -- Use ssize_t type where appropriate (#PSBM-62199)
 - vz7: compel -- Use unsigned long for arguments (#PSBM-61961)
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: Drop redundant comment
 - vz7: restore -- Lift up own file limits (#PSBM-63094)
 - vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump (#PSBM-63002)
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573)
 - vz7: kdat: Add fetching files stat
 - vz7: Don't forget to restore memory cgroup limits on pre-dupms (#PSBM-61534 #PSBM-53593)
 - vz7: Zap file size checking for "atop" (#PSBM-61459)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32
 - vz7: socket: don't restore ucred from kernel messages
 - vz7: netlink: dump/restore netlink options
 - vz7: netlink: restore queues and only then restore opts
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606 #PSBM-61459 #PSBM-61851)
 - vz7: mount -- Add lookup_first_fstype helper
 - vz7: criu: add more information about control messages (#PSBM-60643)
 - vz7: test: check ucred for netlink messages
 - vz7: netlink: dump and restore ucred-s for netlink messages (#PSBM-59339)
 - vz7: eventpoll: Skip inaccessible descriptors (#PSBM-60042)
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)
 - vz7: mount: fix mounting non-root shared mounts (#PSBM-55494)
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: tty: Fix devpts mounts resolving (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper
 - vz7: tty: Save task current terminal if present
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: Make get_dumpee_veid been exported
 - vz7: zdtm: check a netlink socket with in-kernel state
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
 - vz7: sk-inet: Fix lookup for raw sockets (#PSBM-55835)
 - vz7: shmem: skip zero pages
 - vz7: shmem: don't write zero pages into an image
 - vz7: seccomp -- Switch to prctl interface if syscall is not implemented (#PSBM-55593)
 - vz7: ghost files: don't check ghost size if it's an NFS path (#PSBM-56159)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED
 - vz7: test: Add simple socket-raw test
 - vz7: sk-inet: Add initial support for raw sockets (#PSBM-51614)
 - vz7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - vz7: util: Add rmdirp helper
 - vz7: mount: handle error from restore_shared_options()
 - vz7: seize: Add additional diagnose messages (#PSBM-53929)
 - vz7: mount: bind-mount autofs mounts via a file descriptors (#PSBM-53194)
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (#PSBM-59199)
 - vz7: spfs: move SPFS manager to corresponding container's dump directory
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (#PSBM-52353)
 - vz7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (#PSBM-52320)
 - vz7: cg: Don't dump devices.list (#PSBM-50551)
 - vz7: scripts: remove obsolete scripts
 - vz7: cr-restore: use spfs helpers to control spfs manager
 - vz7: spfs: add new helpers to replces bash scripts calls
 - vz7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
 - vz7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - vz7: files-reg: fix silly-renamed files migration
 - vz7: files-reg: improve spfs_file helper
 - vz7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - vz7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - vz7: spfs: remove obsolete code
 - vz7: files-reg: migrate "spfs" files as ghost-ones
 - vz7: files-reg: conditionally dump content in dump_ghost_file
 - vz7: util: mkdirname helper introduced
 - vz7: files-reg: split create_ghost
 - vz7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - vz7: dump: Show task comm early
 - vz7: spfs: do not tolerate file existence on creation
 - vz7: spfs: fix freeze cgroup path discovery
 - vz7: cgroup: new_cg_root_get helper introduced
 - vz7: criu: remove NFS unlinked files restriction
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects
 - vz7: files-reg: migrate spfs file as "link remap" objects
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - vz7: spfs: explicitly pass size and mode to spfs_create_file
 - vz7: link_remap: do not create excessive links for a single file
 - vz7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - vz7: zdtm: add a new test to check netlink sockets with queued data
 - vz7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages
 - vz7: check: check whether NETLINK_REPAIR is supported or not
 - vz7: netlink: request flags for netlink sockets
 - vz7: files-reg: forbid to dump unlinked NFS files
 - vz7: proc_parse: forbid dumping NFS remote locks
 - vz7: files-reg: remove "unreachable" protobuf field as redundant
 - vz7: files-reg: create spfs file in case of parent mount is SPFS
 - vz7: files-reg: do not create spfs file in case of external resource
 - vz7: spfs: remove "ns_list" option from "replace" command as obsolete
 - vz7: compel -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - vz7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - vz7: scripts: restart all systemd automount services (#PSBM-46672)
 - vz7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - vz7: util: Add cr_set_root/cr_restore_root helpers
 - vz7: spfs: do not treat existent file as error in create_reg_file
 - vz7: scripts: spfs-release-replace.sh introduced
 - vz7: criu: spfs -- Fixup various nits for NFS sake
 - vz7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - vz7: mount: Add support for NFSv4
 - vz7: protobuf/mnt.proto: NFSv4 type added
 - vz7: mount: add support for NFS
 - vz7: protobuf/mnt.proto: NFS type added
 - vz7: mount: add support for SUNRPC Pipefs
 - vz7: protobuf/mnt.proto: RPC Pipefs type added
 - vz7: scripts: allow-nfs-ports.sh added
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added
 - vz7: scripts: spfs-change-mode.sh added
 - vz7: action scripts: set spfs environment in run_scripts
 - vz7: regular files: create temporary spfs file if marked as unreachable
 - vz7: spfs: delayed mounts facility introduced
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd
 - vz7: regular files: protobuf "unreachable" field introduced
 - vz7: filemap: collect mapped file fs type
 - vz7: reg_file_entry: add "mode" variable
 - vz7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - vz7: Wait aio pending requests (#PSBM-42488)
 - vz7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - vz7: Merge vanilla 3.0

* Thu May 11 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 3.0.0.1
 - vz7: Makefile.version -- Adjust number for new series
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join (#PSBM-65483)
 - vz7: tty: Make sure no /dev/tty inheritance exist (#PSBM-65637)
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)
 - vz7: test: sk-unix01 -- Make sure the dir with ghost files are empty
 - vz7: sk-unix: Don't wait on socketpair (#PSBM-65051)
 - vz7: sk-unix -- Add info print about slave peers
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - vz7: sk-unix -- Fix typo in namelen comparision (#PSBM-64715)
 - vz7: sk-queue: Add missing newline into log
 - vz7: restore_sk_queue -- Show how many bytes already sent (#PSBM-64628)
 - vz7: test: sk-unix01 -- Fix compilation
 - vz7: sk-unix: Don't append ghost postfix on subsequent checkpoint (#PSBM-55992)
 - test: Add sk-unix01 test
 - vz7: sk-unix: Add ability to restore sockets with deleted vfs addresses
 - vz7: sk-unix: Print cwd been restored if @name_dir is present
 - vz7: sk-unix: Don't warn if nothing to unlink
 - vz7: sk-unix: Collect deleted identical addresses in the queues
 - vz7: sk-unix: Make USK_ flags in shift form
 - vz7: sk-unix: Drop empty line at eof
 - vz7: sk-unix: Use add_post_prepare_cb_once helper
 - vz7: sk-unix: Drop empty line
 - vz7: sk-unix: Use generic xptr_pull in dump_one_unix_fd
 - vz7: sk-unix: Use native types in unix_sk_info
 - vz7: sk-unix: Adjust unix_sk_info members
 - vz7: sk-unix: Adjust unix_sk_cinfo members
 - vz7: sk-unix: Make can_dump_unix_sk being boolean
 - vz7: pipes: Use add_post_prepare_cb_once
 - vz7: tty: Use add_post_prepare_cb_once
 - vz7: restore: Add add_post_prepare_cb_once helper
 - sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: sk-queue -- Show peers in hex form (#PSBM-64009)
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: epoll -- Dont fail on dup'ed fd restore (#PSBM-63850)
 - vz7: dump: Any non-negative return code of run_scripts means an error (#PSBM-62583)
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: seize -- Show detached pid in freezer_detach
 - vz7: Show status of uninterruptable task (#PSBM-63211)
 - vz7: files -- Select proper master fd when collecting fd (#PSBM-63355)
 - vz7: pstree -- Introduce pstree_pid_cmp helper
 - vz7: page-xfer -- Handle partial splicing (#PSBM-63161)
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)
 - vz7: epoll -- Use real file transferred for target fds check (#PSBM-62108)
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - test: Add ucreds test
 - vz7: pagemap -- Use ssize_t type where appropriate (#PSBM-62199)
 - vz7: compel -- Use unsigned long for arguments (#PSBM-61961)
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: Drop redundant comment
 - vz7: restore -- Lift up own file limits (#PSBM-63094)
 - vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump (#PSBM-63002)
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573)
 - vz7: kdat: Add fetching files stat
 - vz7: Don't forget to restore memory cgroup limits on pre-dupms (#PSBM-61534 #PSBM-53593)
 - vz7: Zap file size checking for "atop" (#PSBM-61459)
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32
 - vz7: socket: don't restore ucred from kernel messages
 - vz7: netlink: dump/restore netlink options
 - vz7: netlink: restore queues and only then restore opts
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606 #PSBM-61459 #PSBM-61851)
 - vz7: mount -- Add lookup_first_fstype helper
 - vz7: criu: add more information about control messages (#PSBM-60643)
 - vz7: test: check ucred for netlink messages
 - vz7: netlink: dump and restore ucred-s for netlink messages (#PSBM-59339)
 - vz7: eventpoll: Skip inaccessible descriptors (#PSBM-60042)
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)
 - vz7: mount: fix mounting non-root shared mounts (#PSBM-55494)
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: tty: Fix devpts mounts resolving (#PSBM-59223)
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper
 - vz7: tty: Save task current terminal if present
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: Make get_dumpee_veid been exported
 - vz7: zdtm: check a netlink socket with in-kernel state
 - vz7: netlink: allow to dump netlink sockets with in-progress operations
 - vz7: sk-inet: Fix lookup for raw sockets (#PSBM-55835)
 - vz7: shmem: skip zero pages
 - vz7: shmem: don't write zero pages into an image
 - vz7: seccomp -- Switch to prctl interface if syscall is not implemented (#PSBM-55593)
 - vz7: ghost files: don't check ghost size if it's an NFS path (#PSBM-56159)
 - vz7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED
 - vz7: test: Add simple socket-raw test
 - vz7: sk-inet: Add initial support for raw sockets (#PSBM-51614)
 - vz7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - vz7: util: Add rmdirp helper
 - vz7: mount: handle error from restore_shared_options()
 - vz7: seize: Add additional diagnose messages (#PSBM-53929)
 - vz7: mount: bind-mount autofs mounts via a file descriptors (#PSBM-53194)
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (#PSBM-59199)
 - vz7: spfs: move SPFS manager to corresponding container's dump directory
 - vz7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (#PSBM-52353)
 - vz7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)
 - vz7: mount: Enter/exit VE while mounting CR-time binfmt_misc (#PSBM-52320)
 - vz7: cg: Don't dump devices.list (#PSBM-50551)
 - vz7: scripts: remove obsolete scripts
 - vz7: cr-restore: use spfs helpers to control spfs manager
 - vz7: spfs: add new helpers to replces bash scripts calls
 - vz7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
 - vz7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - vz7: files-reg: fix silly-renamed files migration
 - vz7: files-reg: improve spfs_file helper
 - vz7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - vz7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - vz7: spfs: remove obsolete code
 - vz7: files-reg: migrate "spfs" files as ghost-ones
 - vz7: files-reg: conditionally dump content in dump_ghost_file
 - vz7: util: mkdirname helper introduced
 - vz7: files-reg: split create_ghost
 - vz7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - vz7: dump: Show task comm early
 - vz7: spfs: do not tolerate file existence on creation
 - vz7: spfs: fix freeze cgroup path discovery
 - vz7: cgroup: new_cg_root_get helper introduced
 - vz7: criu: remove NFS unlinked files restriction
 - vz7: files-reg: migrate spfs unlinked file as "link remap" objects
 - vz7: files-reg: migrate spfs file as "link remap" objects
 - vz7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - vz7: spfs: explicitly pass size and mode to spfs_create_file
 - vz7: link_remap: do not create excessive links for a single file
 - vz7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - vz7: zdtm: add a new test to check netlink sockets with queued data
 - vz7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - vz7: sk-queue: add an ability to dump addresses for messages
 - vz7: check: check whether NETLINK_REPAIR is supported or not
 - vz7: netlink: request flags for netlink sockets
 - vz7: files-reg: forbid to dump unlinked NFS files
 - vz7: proc_parse: forbid dumping NFS remote locks
 - vz7: files-reg: remove "unreachable" protobuf field as redundant
 - vz7: files-reg: create spfs file in case of parent mount is SPFS
 - vz7: files-reg: do not create spfs file in case of external resource
 - vz7: spfs: remove "ns_list" option from "replace" command as obsolete
 - vz7: compel -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - vz7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - vz7: scripts: restart all systemd automount services (#PSBM-46672)
 - vz7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - vz7: util: Add cr_set_root/cr_restore_root helpers
 - vz7: spfs: do not treat existent file as error in create_reg_file
 - vz7: scripts: spfs-release-replace.sh introduced
 - vz7: criu: spfs -- Fixup various nits for NFS sake
 - vz7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - vz7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - vz7: mount: Add support for NFSv4
 - vz7: protobuf/mnt.proto: NFSv4 type added
 - vz7: mount: add support for NFS
 - vz7: protobuf/mnt.proto: NFS type added
 - vz7: mount: add support for SUNRPC Pipefs
 - vz7: protobuf/mnt.proto: RPC Pipefs type added
 - vz7: scripts: allow-nfs-ports.sh added
 - vz7: action-scripts: ACT_POST_NET_LOCK stage added
 - vz7: scripts: spfs-change-mode.sh added
 - vz7: action scripts: set spfs environment in run_scripts
 - vz7: regular files: create temporary spfs file if marked as unreachable
 - vz7: spfs: delayed mounts facility introduced
 - vz7: cr-restore: declare SPFS_MNGR_SK service fd
 - vz7: regular files: protobuf "unreachable" field introduced
 - vz7: filemap: collect mapped file fs type
 - vz7: reg_file_entry: add "mode" variable
 - vz7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - vz7: Wait aio pending requests (#PSBM-42488)
 - vz7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - vz7: Merge vanilla 3.0

* Thu May 04 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.49
 - vz7: scripts: systemd-autofs-restart.sh -- Enter container net ns upon join (#PSBM-65483)

* Tue May 02 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.48
 - vz7: tty: Make sure no /dev/tty inheritance exist (#PSBM-65637)

* Thu Apr 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.47
 - vz7: fs: Populate opts.has_binfmt_misc on dump only (#PSBM-65367)

* Mon Apr 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.46
 - vz7: filesystems: binfmt -- Add debug print on dumping stage (#PSBM-65185)

* Fri Apr 21 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.45
 - vz7: test: sk-unix01 -- Make sure the dir with ghost files are empty
 - vz7: sk-unix: Don't wait on socketpair (#PSBM-65051)
 - vz7: sk-unix -- Add info print about slave peers

* Wed Apr 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.44
 - vz7: sk-unix -- Adjust default dgram qlen for systemd sake (#PSBM-64628)
 - Revert "vz7: sockets: Separate socket buffer size setting into a helper"
 - Revert "vz7: sk-unix -- Restore qlen before pushing queued data back"
 - Revert "sk-queue: Queue length must be sync"

* Tue Apr 18 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.43
 - vz7: sk-unix -- Fix typo in namelen comparision (#PSBM-64715)
 - vz7: sk-queue: Add missing newline into log
 - vz7: restore_sk_queue -- Show how many bytes already sent
 - vz7: test: sk-unix01 -- Fix compilation

* Mon Apr 17 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.42
 - vz7: sk-unix: Don't append ghost postfix on subsequent checkpoint (#PSBM-55992)

* Thu Apr 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.41
 - Revert "unix: switch into the root mount namespace before cleaning stale sockets" (#PSBM-64369)

* Wed Apr 12 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.40
 - test: Add sk-unix01 test
 - vz7: sk-unix: Add ability to restore sockets with deleted vfs addresses (#PSBM-55992)
 - vz7: sk-unix: Print cwd been restored if @name_dir is present
 - vz7: sk-unix: Don't warn if nothing to unlink
 - vz7: sk-unix: Collect deleted identical addresses in the queues
 - vz7: sk-unix: Make USK_ flags in shift form
 - vz7: sk-unix: Drop empty line at eof
 - vz7: sk-unix: Use add_post_prepare_cb_once helper
 - vz7: sk-unix: Drop empty line
 - vz7: sk-unix: Use generic xptr_pull in dump_one_unix_fd
 - vz7: sk-unix: Use native types in unix_sk_info
 - vz7: sk-unix: Adjust unix_sk_info members
 - vz7: sk-unix: Adjust unix_sk_cinfo members
 - vz7: sk-unix: Make can_dump_unix_sk being boolean
 - vz7: pipes: Use add_post_prepare_cb_once
 - vz7: tty: Use add_post_prepare_cb_once
 - vz7: restore: Add add_post_prepare_cb_once helper
 - unix: a unix name can be a non-null terminated string
 - unix: Do pr_perror() before cleanup
 - files: Sanitize helpers for scattering two-headed files
 - unix: Factor out common parts restoration (v2)
 - unix: Fix tail processing for peer-less sockets
 - unix: don't leak a file descriptor
 - unix: switch into the root mount namespace before cleaning stale sockets
 - Revert "vz7: sk-unix: Restore deleted sockets together with removed dirs"

* Mon Apr 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.39
 - sk-queue: Don't fail if we're dumping dead process queued creds (#PSBM-62778)

* Mon Apr 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.38
 - sk-queue: Queue length must be sync (#PSBM-64009)
 - vz7: sk-queue -- Show the creds we're sending (#PSBM-64009)
 - vz7: sk-queue -- Show peers in hex form (#PSBM-64009)

* Fri Apr 07 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.37
 - vz7: seize -- Wait for seize in thawed state (#PSBM-63841)
 - vz7: freezer -- Add set_freezer_state helper (#PSBM-63841)
 - vz7: epoll -- Dont fail on dup'ed fd restore (#PSBM-63850)

* Thu Apr 06 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.36
 - vz7: dump: Any non-negative return code of run_scripts means an error (#PSBM-62583)

* Wed Apr 05 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.35
 - vz7: sk-unix -- Restore qlen before pushing queued data back (#PSBM-63762)
 - vz7: sockets: Separate socket buffer size setting into a helper (#PSBM-63762)
 - vz7: seize -- Show detached pid in freezer_detach

* Tue Apr 04 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.34
 - vz7: seize -- Make sure there is enough space for eol on debug print (#PSBM-63211)
 - vz7: Show status of uninterruptable task (#PSBM-63211)

* Mon Apr 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.33
 - vz7: files -- Select proper master fd when collecting fd (#PSBM-63355)
 - vz7: pstree -- Introduce pstree_pid_cmp helper
 - vz7: page-xfer -- Handle partial splicing (#PSBM-63161)

* Tue Mar 28 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.32
 - vz7: restore -- Lift up own file limits (#PSBM-63094)
 - vz7: Make rlimit_limit_nofile_self being global

* Mon Mar 27 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.31
 - vz7: Unlimit self RLIMIT_NOFILE resource for dump/predump (#PSBM-63002)
 - Revert "vz7: Increase the number of files limit"

* Fri Mar 24 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.30
 - vz: zdtm/mnt_ext_auto: add different bind-mounts of external mount (#PSBM-46753)
 - vz7: mount: migrate bindmounts of external mounts (#PSBM-46753)
 - vz7: mount: save ext_real_root for external mounts (#PSBM-46753)
 - vz7: mount: remove excess mi->external checks
 - vz7: mount: fix confusing naming

* Wed Mar 22 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.29
 - vz7: ucred -- Drop packets from dead processes (#PSBM-62603)

* Tue Mar 21 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.28
 - vz7: epoll -- Use real file transferred for target fds check (#PSBM-62108)
 - vz7: epoll: Report error instead of BUG (#PSBM-62108)

* Mon Mar 20 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.27
 - vz7: sk-queue -- Add support of ucreds in unix sockets (#PSBM-61095)
 - test: Add ucreds test

* Wed Mar 15 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.26
 - vz7: parasite-syscall -- Move rlimit_limit_nofile into parasite_cure_remote (#PSBM-62267)

* Tue Mar 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.25
 - vz7: spfs: create control socket in /run/spfs-manager/<pid> (#PSBM-59199)
 - vz7: pagemap -- Use ssize_t type where appropriate (#PSBM-62199)
 - pagemap: Support async pages reading by chunks (v2)

* Mon Mar 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.24
 - fsnotify: skip non-direcory mounts (#PSBM-57362)

* Mon Mar 13 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.23
 - test: Add shutdown'ed UDP socket test
 - sk-inet: Add support for shutdown'ed UDP/UDPlite sockets (#PSBM-61550)

* Fri Mar 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.22
 - vz7: parasite -- Use long for memory size (#PSBM-61961)
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: parasite-syscall -- Export rlimit_[un]limit_nofile
 - vz7: Unlimit and limit file number for dump stage only (#PSBM-61812)

* Fri Mar 10 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.21
 - vz7: dump -- Set file limits back before fetching them into dump (#PSBM-61812)
 - vz7: parasite-syscall -- Export rlimit_[un]limit_nofile
 - vz7: Unlimit and limit file number for dump stage only (#PSBM-61812)

* Thu Mar 09 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.20
 - vz7: Unlimit and limit file number for dump stage only (#PSBM-61812)

* Thu Mar 09 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.19
 - vz7: Fix net_cls controllers transition (#PSBM-61851 #PSBM-60606)
 - vz7: Drop redundant comment
 - vz7: Drop debug leftover from 0a3713ab2c44f

* Tue Mar 07 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.18
 - vz7: Unlimit and limit file number resource for c/r sake (#PSBM-61573)
 - vz7: kdat: Add fetching files stat
 - vz7: parasite: Switch to map-files interface is memfd failed
 - vz7: memfd: Print detailed error if memfd_create failed
 - Revert "vz7: Dump only known controllers" (#PSBM-61768)

* Tue Mar 07 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.17
 - Revert "vz7: Dump only known controllers" (#PSBM-61768)

* Fri Mar 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.16
 - vz7: Don't forget to restore memory cgroup limits on pre-dupms (#PSBM-61534 #PSBM-53593)

* Fri Mar 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.15
 - vz7: Don't rename net_cls if no net_cls,net_prio present (#PSBM-60606 #PSBM-61459)
 - vz7: Zap file size checking for "atop" (#PSBM-61459)

* Wed Mar 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.14
 - vz7: dump_packet_cmsg -- Allow to receive timestamp data (#PSBM-61248)
 - vz7: restore_sk_queue -- Drop trailing tabs
 - vz7: dump_sk_creds -- Don't leak memory for SkUcredEntry (#PSBM-61248)

* Wed Feb 22 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.13
 - vz7: systemd-autofs-restart.sh: fix issue with removed check_fs_type
reference (#PSBM-60980)
 - vz7: Fix type conversion in dump_packet_cmsg

* Sun Feb 19 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.12
 - vz7: netlink: avoid ENOBUF when a netlink queue is dumped (#PSBM-60643)
 - vz7: netlink: skip pktinfo scm if a sender group is less than 32
 - vz7: socket: don't restore ucred from kernel messages
 - vz7: netlink: dump/restore netlink options
 - vz7: netlink: restore queues and only then restore opts

* Fri Feb 17 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.11
 - vz7: cgroup -- Rename net_cls to net_cls,net_prio on the fly (#PSBM-60606)
 - vz7: tty -- Don't fail if @mnt_id is not present in images (#PSBM-60606)
 - vz7: mount -- Add lookup_first_fstype helper

* Thu Feb 16 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.10
 - vz7: criu: add more information about control messages (#PSBM-60643)
 - docs: criu -- Explain pre-resume stage
 - action-scripts: Add "pre-resume" stage (#PSBM-58742)
 - Revert "vz7: Add ACT_POST_SIGRETURN"
 - vz7: Fix type conversion in dump_packet_cmsg

* Tue Feb 14 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.9
 - vz7: test: check ucred for netlink messages
 - vz7: netlink: dump and restore ucred-s for netlink messages (#PSBM-59339)

* Wed Feb 08 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.8
 - vz7: eventpoll: Skip inaccessible descriptors (#PSBM-60042)

* Fri Feb 03 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.7
 - vz7: pipes -- Restore pipe size via userns call (#PSBM-59829)

* Wed Feb 01 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.6
 - vz7: eventpoll: Fix dependency check (#PSBM-59550)

* Thu Jan 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.5
 - vz7: tty: Fix devpts mounts resolving (#PSBM-59223)
 - vz7: test: pty05 -- Extend test for unshared mount ns

* Thu Jan 26 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.4
 - vz7: files: Fix test and set endianess problem (#PSBM-58228)
 - vz7: tty: Optimize dependencies check
 - vz7: files: Merge collect_gen_fd() and collect_used_fd(), and call it
unconditionally
 - vz7: files: Kill pid parameter of open_fdinfos()
 - vz7: eventpoll: Use generic list for eventpoll files
 - vz7: tty: Use generic list for tty files
 - vz7: files: Move ctty fixup to open_fd()
 - vz7: tty: Set dependencies between masters, slaves and ctty
 - vz7: files: Kill struct file_desc_ops::post_open
 - vz7: files: Make recv_fd_from_peer() non-block
 - vz7: files: Add new_fd parameter to file_desc_ops::open()
 - vz7: files: Set fds event after sending fd to peer
 - vz7: eventpoll: Make post_open stage may fail
 - vz7: files: BUG on reopening already opened fle
 - vz7: timerfd: Kill post_open stage
 - vz7: inet: Use task_st futex for notification instead of per-port
 - vz7: inet: Link sockets in port_type list
 - vz7: unix: Wait a peer using task_st futex
 - vz7: unix: Link connected to peer sockets to its list
 - vz7: files: Add fdinfo_list_entry::stage
 - vz7: files: Implement {set,clear,wait}_fds_event()
 - vz7: bits: Add test_and_set_bit()
 - vz7: pstree: Add task_st bit field
 - vz7: headers: Move lock.h into include/common/
 - vz7: files: Merge states iteration into open_fdinfos()
 - vz7: files: Kill fd_open_state::receive_fd stage
 - vz7: files: Kill want_post_open_stage()
 - vz7: files: Kill fd parameter of transport_name_gen()
 - vz7: files: Kill file_desc_ops::want_transport()
 - vz7: files: Receive real fd numbers using recv_fd_from_peer()
 - vz7: files: Make sending fds to peers async
 - vz7: files: Allow to receive further fds
 - vz7: files: Add fle_init() for initialization new fdinfo_list_entry
 - vz7: files: Move derefferencing of TRANSPORT_FD_OFF to send_fd_to_peer()
 - vz7: files: Move closing fle's transport_fd to recv_fd_from_peer()
 - vz7: files: Send/receive fds with pointers on their struct fdinfo_list_entry
in receiver

* Wed Jan 25 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.3
 - pcs7: mount: fix mounting non-root shared mounts

* Mon Jan 23 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.2
 - vz7: test: pty05 -- Add testing of multiple devpts instance
 - vz7: tty: Add support for multiple devpts instances (#PSBM-58616)
 - vz7: tty: Save mount ids for terminals into image
 - vz7: tty: mount -- Add mount_resolve_devpts_mnt_id helper
 - vz7: tty: Save task current terminal if present
 - vz7: tty: Print rdev and dev pair in case of error
 - vz7: tty: Unify id printing

* Mon Jan 23 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.10.0.1
 - vz7: Makefile.version -- Adjust number for new series
 - Rebase to vanilla criu v2.10

* Mon Jan 09 2017 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.15
 - vz7: Unlimit UBC when chekpointing (#PSBM-53593)
 - vz7: restore -- Enter destination veX once usernsd is up (#PSBM-56407)
 - vz7: Add ACT_POST_SIGRETURN
 - vz7: Make get_dumpee_veid been exported
 - vz7: zdtm: check a netlink socket with in-kernel state
 - vz7: netlink: allow to dump netlink sockets with in-progress operations

* Thu Dec 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.14
 - pcs7: tcp: bind tcp sockets after enabling the repair mode (#PSBM-57413)
 - Revert "pcs7: tcp: bind tcp sockets after enabling the repair mode"

* Thu Dec 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.13
 - pcs7: tcp: bind tcp sockets after enabling the repair mode (#PSBM-57413)
 - pcs7: scripts: Print error value in case of action script fail

* Wed Dec 14 2016 Konstantin Volkov <wolf@virtuozzo.com> - 2.8.0.12-2
- Rebuild in 7.3 environment

* Tue Dec 13 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.12
 - pcs7: sk-inet: Fix lookup for raw sockets (#PSBM-55835)

* Tue Dec 13 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.11
 - zdtm: add a test to check a mount tree with overmounts (Andrei Vagin
<avagin@virtuozzo.com>)
 - mount: clone a mount namespace to open a detached mount (Andrei Vagin
<avagin@virtuozzo.com>) (#PSBM-57135)
 - mnt: try to split a mount tree to restore over-mounted mounts (Andrei Vagin
<avagin@virtuozzo.com>)
 - mnt: rename roots_mp into root_yard_mp and make it global (Andrei Vagin
<avagin@virtuozzo.com>)
 - mnt: add a sub-id to print_ns_root (Andrei Vagin <avagin@virtuozzo.com>)
 - mnt: clean up (Andrei Vagin <avagin@virtuozzo.com>)
 - mnt: add a function to check whether a mount overmounts something (Andrei
Vagin <avagin@virtuozzo.com>)

* Fri Dec 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.10
 - pcs7: shmem: skip zero pages

* Fri Dec 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.9
 - pcs7: shmem: don't write zero pages into an image

* Thu Dec 08 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.8
 - pcs7: zdtm: check sequence numbers for tcp sockets
 - pcs7: build: install libnet-dev
 - pcs7: zdtm.py: pass a test PID into zdtm hooks
 - pcs7: zdtm: add test cases on TCP_SYN_SENT
 - pcs7: zdtm: add a test for unconnected tcp sockets
 - pcs7: zdmt: add more checks into socket-closed-tcp
 - pcs7: zdtm: check sockets in the TCP_CLOSING state
 - pcs7: zdtm: add test cases on TCP_CLOSE_WAIT and TCP_LAST_ACK states
 - pcs7: zdtm: add test cases on TCP_FIN_WAIT* states
 - pcs7: tcp: add support for synsent
 - pcs7: tcp: allow to dump intermediate closing states
 - pcs7: inet: dump source and destination addresses for closed sockets
 - pcs7: soccr: add support for syn-sent sockets
 - pcs7: soccr: add support for half-closed sockets
 - pcs7: soccr: move connect from criu to soccr
 - pcs7: soccr: add source and destination addresses to libsoccr_sk_data
 - pcs7: criu: check whether tcp_repair can be enabled for half-closed sockets
 - pcs7: soccr: add prefixes for log messages and print errno
 - pcs7: soccr: add '\n' to all loge/logd
 - pcs7: criu: enable soccr logging
 - pcs7: build: only generate soccr config.h if necessary
 - pcs7: soccr: Generate config.h dynamically
 - pcs7: soccr: rectify Alpine build
 - pcs7: make, soccr: let CRIU depend on libsoccr
 - pcs7: soccr: Add soccr.h's comments
 - pcs7: soccr: Handle connection state
 - pcs7: soccr/tcp: Restore queues using library
 - pcs7: soccr/tcp: Restore socket's info after binding it
 - pcs7: soccr/tcp: Restore socket's info before binding it
 - pcs7: soccr/tcp: Prepare connection info for restore
 - pcs7: soccr/tcp: Read queues contents using library
 - pcs7: soccr/tcp: Fill actual connection info using the library
 - pcs7: soccr/tcp: Introduce blob with connection info and getter for it
 - pcs7: soccr/tcp: Add _pause and _resume to library and use it
 - pcs7: soccr: Add logging
 - pcs7: soccr: Wire into builder
 - criu.spec: Add libnet-devel requirement for tcp-close sake

* Wed Dec 07 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.7
 - pcs7: seccomp -- Switch to prctl interface if syscall is not implemented (#PSBM-55593)

* Wed Dec 07 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.6
 - pcs7: restore: Fetch mmap_minimal_address runtime (#PSBM-56797)

* Mon Dec 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.5
 - pcs7: ghost files: don't check ghost size if it's an NFS path (#PSBM-56159)

* Thu Dec 01 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.4
 - pcs7: criu: Fix open() retval analysing (#PSBM-56384)

* Thu Dec 01 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.3
 - pcs7: fs: Fix retval analysing erratum (#PSBM-56384)

* Wed Nov 30 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.2
 - pcs7: Always define CONFIG_BINFMT_MISC_VIRTUALIZED

* Wed Nov 30 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.8.0.1
 - pcs7: Adjust version for 2.8 series
 - Rebase to vanilla CRIU-2.8 series

* Mon Nov 28 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.23
 - pcs7: test: Add simple socket-raw test
 - pcs7: sk-inet: Add initial support for raw sockets (#PSBM-51614)

* Fri Nov 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.22
 - pcs7: Don't use executable stacks in @syscall_ip (#PSBM-55989)
 - Revert "pcs7: criu: proc_parse -- Add guard page the same way as kernel
detects them"
 - Revert "pcs7: parasite: Don't try to start executing syscall from guard page"

* Fri Nov 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.21
 - pcs7: parasite: Don't try to start executing syscall from guard page (#PSBM-55989)
 - pcs7: criu: proc_parse -- Add guard page the same way as kernel detects them (#PSBM-55989)

* Wed Nov 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.20
 - pcs7: test: Add del_standalone_un_dentry test
 - pcs7: sk-unix: Restore deleted sockets together with removed dirs (#PSBM-55495)
 - pcs7: util: Add rmdirp helper
 - pcs7: test: rmdir_open -- Delete two levels of directories
 - pcs7: criu: files-reg -- Create a complete path to delete dentry
 - pcs7: util: Make mkdirpat more generic

* Tue Nov 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.19
 - pcs7: mount: don't create a temporary directory if /tmp exists
 - ps7: mount: fix mounting non-root shared mounts (#PSBM-55494)
 - pcs7: mount: handle error from restore_shared_options()

* Tue Oct 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.18
 - seize: Add additional diagnose messages (#PSBM-53929)

* Sun Oct 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.17
 - pcs7: mount: bind-mount autofs mounts via a file descriptors (#PSBM-53194)

* Tue Oct 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.16
 - pcs7: Fix seize_cgroup_tree error code collide

* Sun Oct 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.15
 - pcs7: freeze -- Wait for exiting tasks to complete (#PSBM-53282)

* Thu Oct 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.14
 - pcs7: scripts -- systemd-autofs-restart.sh: explicitly return result from
get_fs_type (#PSBM-53239)

* Thu Sep 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.13
 - pcs7: spfs: move SPFS manager to corresponding container's dump directory

* Tue Sep 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.12
 - pcs7: mount: Correct s_dev conversion in mount_cr_time_mount() (#PSBM-52460)

* Mon Sep 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.11
 - pcs7: mount: Set opts.has_binfmt_misc regardless of mnt_ns level (#PSBM-52513)

* Sat Sep 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.10
 - pcs7: mount: Move adding cr-time binfmt_misc to collect_mnt_namespaces() (#PSBM-52513)
 - pcs7: mount: Do not fail on shared cr-time mounts mismatch (#PSBM-52513)

* Fri Sep 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.9
 - pcs7: restorer: add forgotten CLONE_FS flag for threads clone (#PSBM-47623)

* Thu Sep 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.8
 - pcs7: scripts: add unmasked NFS route print to nfs-ports-allow.sh (#PSBM-52353)
 - pcs7: mnt -- Fix case where ve cgroup not found

* Thu Sep 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.7
 - pcs7: mnt -- Fetch VEID from cgroup for migration sake (#PSBM-52372)

* Thu Sep 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.6
 - pcs7: mount: Corrent sibling path when parent and child have the same
mountpoint (#PSBM-52346)

* Mon Sep 19 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.5
 - pcs7: mount: Enter/exit VE while mounting CR-time binfmt_misc (#PSBM-52320)

* Fri Sep 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.4
 - mount: Prohibit second binfmt_misc superblock (#PSBM-47737)
 - mount: Restore binfmt_misc content in case of missing mount
 - mount: Forced mount unmounted binfmt_misc to do not lost its content
 - mount: Autodetect binfmt_misc
 - mount: Create binfmt_misc image w/o device suffix
 - mount: Move binfmt_misc entry restore code to subfunction
 - mount: Collect new type binfmt_misc.img image entries
 - image: Rename binfmt_misc image format as "old"
 - pcs7: shmem -- Inspect pages before the dump (#PSBM-52138)

* Mon Aug 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.3
 - pcs7: systemd-autofs-restart.sh: fix error handling in case of system
limitation (#PSBM-51299)

* Fri Aug 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.2
 - seize: collect_pstree -- Add missing error sign return (#PSBM-51428)

* Thu Aug 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.5.0.1
 - pcs7: Adjust version for v2.5.x.x series
 - pcs7: conflict resolve
 - pcs7: scritps: systemd-autofs-restart.sh -- Do not treat absence on bindmount
as error (#PSBM-50684)
 - pcs7: cg: Don't dump devices.list (#PSBM-50551)
 - unix: don't drop the path on unix sockets if they don't exist (Dmitry Safonov
<dsafonov@virtuozzo.com>)
 - pcs7: Increase the number of files limit (#PSBM-46761 #PSBM-50607)
 - pcs7: scripts: remove obsolete scripts
 - pcs7: cr-restore: use spfs helpers to control spfs manager
 - pcs7: spfs: add new helpers to replces bash scripts calls
 - pcs7: files-reg: move ghost_apply_metadata out of create_ghost_dentry
 - pcs7: Lift up local version
 - pcs7: Dump only known controllers (#PSBM-46382)
 - pcs7: log: Print version into the log (#PSBM-50239)
 - pcs7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - pcs7: files-reg: fix silly-renamed files migration
 - pcs7: files-reg: improve spfs_file helper
 - pcs7: mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - pcs7: util-vdso: correct vdso symbol's length
 - pcs7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - pcs7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - pcs7: spfs: remove obsolete code
 - pcs7: files-reg: migrate "spfs" files as ghost-ones
 - pcs7: files-reg: conditionally dump content in dump_ghost_file
 - pcs7: util: mkdirname helper introduced
 - pcs7: files-reg: split create_ghost
 - pcs7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - pcs7: seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - pcs7: dump: Move task_comm_info helpers into seize.c
 - pcs7: spfs: do not tolerate file existence on creation
 - pcs7: dump: Show task comm early
 - pcs7: spfs: add device files creation support (#PSBM-48985)
 - pcs7: spfs: fix freeze cgroup path discovery
 - pcs7: cgroup: new_cg_root_get helper introduced
 - pcs7: criu: remove NFS unlinked files restriction
 - pcs7: files-reg: migrate spfs unlinked file as "link remap" objects
 - pcs7: files-reg: migrate spfs file as "link remap" objects
 - pcs7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - pcs7: spfs: explicitly pass size and mode to spfs_create_file
 - pcs7: link_remap: do not create excessive links for a single file
 - pcs7: proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - pcs7: log: files-ext -- Show exactly which file can't be dumped
 - pcs7: criu: util -- Add __read_fd_link helper
 - pcs7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - pcs7: zdtm: add a new test to check netlink sockets with queued data
 - pcs7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - pcs7: sk-queue: add an ability to dump addresses for messages
 - pcs7: check: check whether NETLINK_REPAIR is supported or not
 - pcs7: netlink: request flags for netlink sockets
 - pcs7: files-reg: forbid to dump unlinked NFS files
 - pcs7: proc_parse: forbid dumping NFS remote locks
 - pcs7: files-reg: remove "unreachable" protobuf field as redundant
 - pcs7: files-reg: create spfs file in case of parent mount is SPFS
 - pcs7: files-reg: do not create spfs file in case of external resource
 - pcs7: spfs: remove "ns_list" option from "replace" command as obsolete
 - pcs7: namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - pcs7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - pcs7: scripts: restart all systemd automount services (#PSBM-46672)
 - pcs7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - pcs7: util: Add cr_set_root/cr_restore_root helpers
 - pcs7: spfs: do not treat existent file as error in create_reg_file
 - pcs7: seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - pcs7: scripts: spfs-release-replace.sh introduced
 - pcs7: criu: spfs -- Fixup various nits for NFS sake
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)
 - pcs7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - pcs7: Initial sync with vanilla v2.4
 - log: Print version into the log (#PSBM-50239)
 - files-reg: fix silly-renamed files migration
 - files-reg: improve spfs_file helper
 - mounts: export is_root_mount helper
 - Revert "sk-unix: forbid to dump NFS unix sockets" (#PSBM-47017)
 - mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - util-vdso: correct vdso symbol's length
 - Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - files: Allow to dump ploopX files opened (#PSBM-49723)
 - version: Adjust numbering
 - Revert "files_reg: carry rdev with regular files"
 - seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - spfs: remove obsolete code
 - files-reg: migrate "spfs" files as ghost-ones
 - files-reg: conditionally dump content in dump_ghost_file
 - util: mkdirname helper introduced
 - files-reg: split create_ghost
 - files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - dump: Move task_comm_info helpers into seize.c
 - pcs7: arch, x86 -- Fix typo in cpuid masking code (#PSBM-49423)
 - spfs: do not tolerate file existence on creation
 - dump: Show task comm early
 - spfs: add device files creation support (#PSBM-48985)
 - files_reg: carry rdev with regular files
 - spfs: fix freeze cgroup path discovery
 - cgroup: new_cg_root_get helper introduced
 - criu: remove NFS unlinked files restriction
 - files-reg: migrate spfs unlinked file as "link remap" objects
 - files-reg: migrate spfs file as "link remap" objects
 - spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - spfs: explicitly pass size and mode to spfs_create_file
 - link_remap: do not create excessive links for a single file
 - cr-dump: discover fs type in fill_fd_params_special
 - proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - tty: Don't forget to add eol when inverting slave pts paths (#PSBM-49008)
 - tty: Fix typos in vt driver choosing (#PSBM-48614)
 - mount: don't do MS_REC|MS_PRIVATE for host mounts (#PSBM-46298)
 - log: files-ext -- Show exactly which file can't be dumped
 - criu: util -- Add __read_fd_link helper
 - mount: forbid dumping overmounted NFS (#PSBM-48620)
 - zdtm: add a new test to check netlink sockets with queued data
 - netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - netlink: request flags for netlink sockets
 - sk-queue: add an ability to dump addresses for messages
 - check: check whether NETLINK_REPAIR is supported or not
 - unix: Do not autobind unnamed unix sockets (#PSBM-48446)
 - pcs7: images: Sync format with vanilla criu (#PSBM-48283)
 - sk-unix: forbid to dump NFS unix sockets
 - files-reg: forbid to dump unlinked NFS files
 - proc_parse: forbid dumping NFS remote locks
 - files-reg: remove "unreachable" protobuf field as redundant
 - files-reg: create spfs file in case of parent mount is SPFS
 - files-reg: do not create spfs file in case of external resource
 - spfs: remove "ns_list" option from "replace" command as obsolete
 - rpc: Implement @timeout interface (#PSBM-48256)
 - namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)
 - rpc: Add interface --freeze-cgroup option (#PSBM-44613)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748)
 - dump: Allocate root_item before run pre-dump scripts (#PSBM-47737)
 - scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - net/sysctl: fix ipv4 forwarding (#PSBM-47355)
 - scripts: terminate systemd-autofs-restart.sh if saved mountpoint is missing (#PSBM-44207)
 - scripts: return non zero if save_mountpoint() fails (#PSBM-44207)
 - scripts: remove bogus command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - scripts: detect EOF on read in a usual way in systemd-autofs-restart.sh (#PSBM-44207)
 - mount: don't add a separate entry for each enabled file systems
 - scripts: restart all systemd automount services (#PSBM-46672)
 - sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - util: Add cr_set_root/cr_restore_root helpers
 - zdtm/ptrace_sig: don't print from signal handlers (#PSBM-47772)
 - test: file_locks01 -- Test for dev change if only env is set (#PSBM-47714)
 - test: fanotify00 -- Test for device change if only env set
 - test: static, fanotify00 -- Don't compare @s_dev in test (#PSBM-47667)
 - spfs: do not treat existent file as error in create_reg_file
 - seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - build: Don't forget to relink arch builtins on change
 - scripts: spfs-release-replace.sh introduced
 - Revert "scripts: spfs-release-replace.sh introduced"
 - scripts: spfs-release-replace.sh introduced
 - scripts: call readlink in CT context in systemd-autofs-restart.sh
 - scripts: single style for command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - tty: Don't forget to unblock tty peers
 - tty: Save @flags unconditionaly for consistency
 - zdtm: check in-flight data in ttys
 - tty: Write unread pty buffers on post dump stage (#PSBM-41399)
 - criu: don't interrupt do_new_mount() after appling mount options (#PSBM-47489)
 - aio: Consider AIO pages as "should be dumped" (#PSBM-47489)
 - test/sockets: add test for shut down stream unix sockets (#PSBM-47023)
 - sk-unix: ignore shutdown mismatch in unix sockets
 - scripts: fix strings comparison in systemd-autofs-restart.sh
 - net/sysctl: zero-init stable_secret strings (#PSBM-30942)
 - net/sysctl: remove excess type conversions for sysctl_entry.type
 - net/sysctl: silence read error in case of CTL_FLAGS_READ_EIO_SKIP
 - zdtm/net/ipv6: add test for string stable_secret
 - sysctl: fix allocation for array of pointers
 - zdtm/net/ipv6: add test for confs
 - zdtm/net/ipv6: add devconfs6 and rand_range6
 - zdtm/net/ipv6: allow inacurate match for mldvX_unsolicited_report_interval
 - zdtm/net/ipv4: split save_and_set and check_and_restore
 - zdtm/net/ipv4: replace rand limits with rand ranges
 - zdtm/net/ipv4: make save_and_set and check_and_restore reusable
 - restore/net/ipv6: net device and def/all configuration
 - dump/net/ipv6: net device and def/all configuration
 - net/ipv6: add devconfs6 array to store config option's names
 - net/ipv6/protobuf: add device config options for ipv6
 - net/ipv4: add net_conf_op to reuse for ipv6
 - protobuf: add SysctlEntry for ipv4/ipv6 sysctl confs or some others
 - sysctl: add CTL_FLAGS_HAS to mark successful sysctl_op request
 - zdtm/net/ipv4: rename devconfs4 and rand_limit4 and dir4
 - net/ipv4: suffix devconfs with "4"
 - net/ipv4: add new sysctls
 - pcs7: criu: spfs -- Fixup various nits for NFS sake
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - pcs7: cgroup: Fix early update of @dir_name in rewrite_cgsets (#PSBM-46987)
 - plugins: Initialize plugins control by default
 - pcs7: mount: add support for external block devices (#PSBM-39381)
 - pcs7: aio: Fix mmap retval analysing
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)
 - mount: create a clean mount only if a sub directory is bind-mounted (#PSBM-46908)
 - mount: dump a file system only if a mount point isn't overmounted (#PSBM-46908)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46908)
 - Revert "mount: dump a file system only if a mount point isn't overmounted"
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere"
 - scripts: fix mountinfo parsing in systemd-autofs-restart.sh (#PSBM-46889)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46732 #PSBM-46662)
 - mount: remove an extra condition from mounts_equal()
 - mount: handle a case when parent and child mounts in the same directory
 - mount: dump a file system only if a mount point isn't overmounted
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere" (#PSBM-46732)
 - autofs: support of "hidden" catatonic mounts (#PSBM-46572)
 - autofs: rework pipe search logic a bit
 - build: Add ability to generate gprof output
 - pcs7: scripts -- Make sure -1 pid is not passed (#PSBM-46572)
 - pcs7: Increase the number of files limit (#PSBM-46761)
 - scripts: do not use stat to discover fs type in systemd-autofs-restart.sh (#PSBM-46756)
 - scripts: save and restore target mount for autofs service (#PSBM-46672)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46662)
 - pcs7: Dump only known controllers (#PSBM-46382)
 - Revert "cg: Add ability to dump predefined controllers only"
 - Revert "pcs7: Increase the number of files limit"
 - criu: dump filemap as soon as possible (#PSBM-46355)
 - autofs: collect new pipe fd as used (#PSBM-46601)
 - autofs: do not create dentries for indirect mount on bind-mounts (#PSBM-46572)
 - pcs7: Increase the number of files limit (#PSBM-46355)
 - build: install -- Don't forget to init DESTDIR
 - scripts: fix typo in binary path in systemd-autofs-restart.sh
 - restore: Wait for userns being prepared before moving into cgroups (v3)
 - Revert "restore: Wait for userns being prepared before moving into cgroups
(v2)"
 - cg: Add ability to dump predefined controllers only (#PSBM-46382)
 - scripts: join pid namespace in systemd-autofs-restart.sh (#PSBM-46470)
 - files: try to change fsuid only if linkat() failed (#PSBM-46201)
 - criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - restore: Wait for userns being prepared before moving into cgroups (v2) (#PSBM-46360)
 - Revert "restore: Wait for userns being prepared before moving into cgroups"
 - autofs: use temporary value for virtual pgrp on dump
 - restore: Wait for userns being prepared before moving into cgroups (#PSBM-46360)
 - files: Correctly handle tasks with no open file descriptors (#PSBM-46269)
 - autofs: install -- Fix libexec prefix (#PSBM-46249)
 - autofs: install -- Ship scripts/systemd-autofs-restart.sh (#PSBM-46249)
 - pcs7: Update Makefile.local
 - criu: action-scripts -- Don't access @root_item_pid if not present
 - zdtm: check the mem_dirty_track if --pre or --snap is set (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - ppc64le: fix build with UFFD (Pavel Emelyanov <xemul@virtuozzo.com>)
 - Fix compilation of action-scripts.c (Pavel Emelyanov <xemul@virtuozzo.com>)
 - kdat: Remove tcp_max_rshare (Pavel Emelyanov <xemul@virtuozzo.com>)
 - tcp: Send as much as possible (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: Fix join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - sk: handle erorors of lseek (Pavel Emelyanov <xemul@virtuozzo.com>)
 - util: don't leak a socket (Pavel Emelyanov <xemul@virtuozzo.com>)
 - namespaces: don't leak memory on error paths (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: set NS_PID environment variable before "post-resume" hook (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - scripts: systemd-autofs-restart.sh added (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: Add export of sublevels and extra (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: compel -- Drop double targeting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: "post-resume" hook introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - criu: opts -- Shuffle init_opts order (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: Drop config.h from deps (Pavel Emelyanov <xemul@virtuozzo.com>)
 - ns: Options join-ns and unshare are conflicting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: Initial commit for standalone tool (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: piegen -- Introduce actions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @arch option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @uapi-dir option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: perform join_namespace according to join-ns opts (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns option to criu CLI and RPC (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd: add handling of zero pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: introduce uffd_handle_page (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: increment uffd_copied_pages only in one place (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move the code out of the 'main' function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: make some variable static global (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move code into subfunctions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: remove unused variable vma_size (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked opts in autofs_mount (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked info in autofs_mount on error path (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked AutofsEntry in autofs_dump_entry (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: do not close NULL image (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: remove handling of VDSO pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: do not treat VDSO pages as lazy (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: Fix pr_debug format for vma start (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix device id modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: fix device id printf modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: do not treat old kernel as error in autofs_parse() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: include limit.h before auto_fs.h (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix build on Fedora 22 (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: do not call unneeded functions (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: move add_ns_shared_cb declaration to include/namespaces.h (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - Fix userfaultfd code with newer compilers (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - check: "autofs" feature added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - zdtm.py: create "dev/autofs" root contruction (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: add autofs test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - mount: create target directory for AutoFS indirect mounts. (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: restore stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: declare ioctl helpers and constants (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pipes: export collect_one_pipe_ops() helper (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new dup_fdinfo() and dup_fle() helpers introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new "used" files list introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: dump fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: parse fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf: autofs entry introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - devices: add support for /dev/autofs (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf/mnt.proto: AutoFS type added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Check private remount error code (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Define UNSHARE_MOUNT_PROC constant (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: try to find a free pid between busy pids (v2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: use rbtree to find a specified pid (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: prepare to store all pid-s in rb-tree (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: split alloc_pstree_helper (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pstree: move state from pstree_item to pid (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 1) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Remove static from prepare_task_entries function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Make skip_pages function available criu-wide (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Support pidns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Mount new proc (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Support mntns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Preparations and CLI option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pcs7: Extend version output via local build (#PSBM-45009)
 - build: criu -- Don't forget to cleanup arch directory
 - cg: Add rollback in get_cg_set (#PSBM-45553)
 - cg: Add rollback for add_cgroup (#PSBM-45553)
 - cg: Fix use-after-free in put_ctls (#PSBM-45553)
 - pie: open_detach_mount -- Use pr_perror for regular build
 - util: return aligned pointers from shmalloc()
 - Makefile: drop 'rebuild' from help message
 - nmk: build.mk -- Add @libso-y helper
 - nmk: build.mk -- Add @hostprogs-y mode
 - nmk: msg.mk -- Add host- messages
 - nmk: build.mk -- Shrink gen-cc-rules
 - nmk: build.mk -- Drop any-match rule
 - nmk: build.mk -- Fix deps for target mode
 - nmk: build.mk -- Squash gen-rule-x into gen-cc-rules
 - nmk: Drop rules.mk
 - nmk: rules.mk -- Fix AFLAGS typo
 - tests: remap_dead_pid[_root] -- Run in namespace only
 - log: add gnu-styled output to stdout
 - build: images -- Add missing cleanups
 - namespaces: zero struct ns_id when allocating
 - criu: use strsignal to describe kill reason
 - nmk: build.mk -- Fix ar rule for external libs
 - nmk: build.mk -- Make process depend on Makefile itself
 - nmk: build.mk -- On cleanup use cleanup-y only
 - nmk: utils.mk -- Add cleanify helper
 - nmk: utils.mk -- Drop redundant spaces
 - nmk: build.mk -- Fix typo in gen-ar-target-rule
 - nmk: rules.mk -- Add per-obj flags
 - nmk: build.mk -- Drop unused objlist target
 - nmk: rules.mk -- Drop @CFLAGS_ and @ASFLAGS_ but add ability to bring them
via param
 - build: add mrproper target
 - build/nmk: add mrproper-y
 - build: Drop @images
 - nmk: scritps/macro.mk -- Enhance gen-built-in
 - x86/restorer: drop unused struct pt_regs
 - types: Remove setns override with sys_setns
 - rst-malloc: adjust free_bytes in rst_mem_align_cpos
 - netfilter: add -n to iptables and ip6tables calls
 - build: docs -- Use autogenerated footer
 - pstree: try to find a free pid between busy pids (v2)
 - pstree: use rbtree to find a specified pid (v3)
 - pstree: prepare to store all pid-s in rb-tree (v3)
 - pstree: split alloc_pstree_helper
 - pstree: move state from pstree_item to pid
 - criu: seize -- Don't left dangling @processes_to_wait_pids pointer
 - libnetlink: back port a fix for nlattr_parse()
 - netlink: Use nlattr instead of rtattr
 - criu: pstree_switch_state -- Fix nil deref on error path
 - irmap: use kdev everywere
 - dump: check for conflicts with the dead processes
 - irmap: don't try to dereference a null pointer
 - mounts: handle device numbers in different formats properly
 - criu: Use __NR_memfd_create for testing memfd presence
 - build: Conditionally defined SYS_* constants
 - build: criu -- Don't link with syscalls library
 - mount: don't use a shared mount to get a clean mount
 - mount: master_id should be 0 for new mounts
 - mount: restore a shared group for propagated mounts
 - build: clean up various other bits
 - build: Add verbose message on packages needed for CRIU building
 - build: Unify phony forms usage
 - pre-dump: don't waste time in error cases
 - dump: pre-dump should never kill processes
 - make: Improve tar generation
 - pcs7: Update local version
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)
 - mounts: Skip already bound siblings in propagate_siblings()
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)
 - plugin: Add PRE_DUMP stage into plugins
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)

* Fri Aug 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.6
 - pcs7: scritps: systemd-autofs-restart.sh -- Do not treat absence on bindmount
as error (#PSBM-50684)

* Fri Aug 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.5
 - pcs7: cg: Don't dump devices.list (#PSBM-50551)

* Thu Aug 04 2016 Dmitry Safonov <dsafonov@virtuozzo.com> 2.4.0.4
 - unix: don't drop the path on unix sockets if they don't exist

* Wed Aug 03 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.3
 - pcs7: Increase the number of files limit (#PSBM-50607)
 - pcs7: scripts: remove obsolete scripts
 - pcs7: cr-restore: use spfs helpers to control spfs manager
 - pcs7: spfs: add new helpers to replces bash scripts calls

* Tue Aug 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.2
 - pcs7: files-reg: move ghost_apply_metadata out of create_ghost_dentry

* Tue Aug 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.4.0.1
 - pcs7: Lift up local version
 - pcs7: Dump only known controllers (#PSBM-46382)
 - pcs7: log: Print version into the log (#PSBM-50239)
 - pcs7: mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - pcs7: files-reg: fix silly-renamed files migration
 - pcs7: files-reg: improve spfs_file helper
 - pcs7: mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - pcs7: util-vdso: correct vdso symbol's length
 - pcs7: Makefile: install spfs-release-replace.sh script (#PSBM-49726)
 - pcs7: files: Allow to dump ploopX files opened (#PSBM-49723)
 - pcs7: spfs: remove obsolete code
 - pcs7: files-reg: migrate "spfs" files as ghost-ones
 - pcs7: files-reg: conditionally dump content in dump_ghost_file
 - pcs7: util: mkdirname helper introduced
 - pcs7: files-reg: split create_ghost
 - pcs7: files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - pcs7: seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - pcs7: dump: Move task_comm_info helpers into seize.c
 - pcs7: spfs: do not tolerate file existence on creation
 - pcs7: dump: Show task comm early
 - pcs7: spfs: add device files creation support (#PSBM-48985)
 - pcs7: spfs: fix freeze cgroup path discovery
 - pcs7: cgroup: new_cg_root_get helper introduced
 - pcs7: criu: remove NFS unlinked files restriction
 - pcs7: files-reg: migrate spfs unlinked file as "link remap" objects
 - pcs7: files-reg: migrate spfs file as "link remap" objects
 - pcs7: spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - pcs7: spfs: explicitly pass size and mode to spfs_create_file
 - pcs7: link_remap: do not create excessive links for a single file
 - pcs7: proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - pcs7: log: files-ext -- Show exactly which file can't be dumped
 - pcs7: criu: util -- Add __read_fd_link helper
 - pcs7: mount: forbid dumping overmounted NFS (#PSBM-48620)
 - pcs7: zdtm: add a new test to check netlink sockets with queued data
 - pcs7: netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - pcs7: sk-queue: add an ability to dump addresses for messages
 - pcs7: check: check whether NETLINK_REPAIR is supported or not
 - pcs7: netlink: request flags for netlink sockets
 - pcs7: files-reg: forbid to dump unlinked NFS files
 - pcs7: proc_parse: forbid dumping NFS remote locks
 - pcs7: files-reg: remove "unreachable" protobuf field as redundant
 - pcs7: files-reg: create spfs file in case of parent mount is SPFS
 - pcs7: files-reg: do not create spfs file in case of external resource
 - pcs7: spfs: remove "ns_list" option from "replace" command as obsolete
 - pcs7: namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748 #PSBM-49423)
 - pcs7: scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)
 - pcs7: scripts: restart all systemd automount services (#PSBM-46672)
 - pcs7: sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - pcs7: util: Add cr_set_root/cr_restore_root helpers
 - pcs7: spfs: do not treat existent file as error in create_reg_file
 - pcs7: seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - pcs7: scripts: spfs-release-replace.sh introduced
 - pcs7: criu: spfs -- Fixup various nits for NFS sake
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)
 - pcs7: criu: tty -- Restore tty params synchronously (#PSBM-46382)
 - pcs7: Initial sync with vanilla v2.4

* Thu Jul 28 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.5
 - log: Print version into the log (#PSBM-50239)
 - files-reg: fix silly-renamed files migration
 - files-reg: improve spfs_file helper
 - mounts: export is_root_mount helper

* Tue Jul 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.4
 - Revert "sk-unix: forbid to dump NFS unix sockets" (#PSBM-47017)

* Tue Jul 26 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.3
 - mount: sysfs -- Use slave mounting for the root (#PSBM-50010)
 - util-vdso: correct vdso symbol's length

* Wed Jul 20 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.2
 - Makefile: install spfs-release-replace.sh script (#PSBM-49726)

* Mon Jul 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.1.1
 - files: Allow to dump ploopX files opened (#PSBM-49723)
 - version: Adjust numbering
 - Revert "files_reg: carry rdev with regular files"

* Tue Jul 12 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.49
 - seize: Wait the freezer to complete before processing tags (#PSBM-49439)
 - spfs: remove obsolete code
 - files-reg: migrate "spfs" files as ghost-ones
 - files-reg: conditionally dump content in dump_ghost_file
 - util: mkdirname helper introduced
 - files-reg: split create_ghost
 - files_reg: remove unused "struct ghost_file" from mkreg_ghost prototype
 - dump: Move task_comm_info helpers into seize.c

* Thu Jul 07 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.48
 - pcs7: arch, x86 -- Fix typo in cpuid masking code (#PSBM-49423)
 - spfs: do not tolerate file existence on creation

* Wed Jul 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.47
 - dump: Show task comm early
 - spfs: add device files creation support (#PSBM-48985)
 - files_reg: carry rdev with regular files

* Wed Jul 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.46
 - spfs: fix freeze cgroup path discovery
 - cgroup: new_cg_root_get helper introduced
 - criu: remove NFS unlinked files restriction
 - files-reg: migrate spfs unlinked file as "link remap" objects
 - files-reg: migrate spfs file as "link remap" objects
 - spfs: pass mount ID instead of namespace descriptor to spfs_create_file
 - spfs: explicitly pass size and mode to spfs_create_file
 - link_remap: do not create excessive links for a single file
 - cr-dump: discover fs type in fill_fd_params_special
 - proc_parse: fix vma file open mode recognition (#PSBM-49199)
 - Set hash for -u1 branch

* Mon Jun 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.45
 - tty: Don't forget to add eol when inverting slave pts paths (#PSBM-49008)

* Wed Jun 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.44
 - tty: Fix typos in vt driver choosing (#PSBM-48614)

* Wed Jun 22 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.43
 - mount: don't do MS_REC|MS_PRIVATE for host mounts (#PSBM-46298)
 - log: files-ext -- Show exactly which file can't be dumped
 - criu: util -- Add __read_fd_link helper

* Mon Jun 20 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.42
 - mount: forbid dumping overmounted NFS (#PSBM-48620)

* Sat Jun 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.41
 - zdtm: add a new test to check netlink sockets with queued data
 - netlink: restore data in a received queue for netlink sockets (#PSBM-28386)
 - netlink: request flags for netlink sockets
 - sk-queue: add an ability to dump addresses for messages
 - check: check whether NETLINK_REPAIR is supported or not
 - unix: Do not autobind unnamed unix sockets (#PSBM-48446)
 - pcs7: images: Sync format with vanilla criu (#PSBM-48283)
 - sk-unix: forbid to dump NFS unix sockets
 - files-reg: forbid to dump unlinked NFS files
 - proc_parse: forbid dumping NFS remote locks
 - files-reg: remove "unreachable" protobuf field as redundant
 - files-reg: create spfs file in case of parent mount is SPFS
 - files-reg: do not create spfs file in case of external resource

* Wed Jun 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.40
 - spfs: remove "ns_list" option from "replace" command as obsolete

* Tue Jun 14 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.39
 - rpc: Implement @timeout interface (#PSBM-48256)

* Sat Jun 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.38
 - namespace: mark mount namespaces as populated after the forking stage (#PSBM-48222)

* Sat Jun 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.37
 - rpc: Add interface --freeze-cgroup option (#PSBM-44613)
 - pcs7: arch, x86 -- Add support for vz7 specific cpuid masking (#PSBM-47748)
 - dump: Allocate root_item before run pre-dump scripts (#PSBM-47737)
 - scripts: remove bogus command substitution in nfs-ports-allow.sh (#PSBM-44207)

* Wed Jun 08 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.36
 - net/sysctl: fix ipv4 forwarding (#PSBM-47355)
 - scripts: terminate systemd-autofs-restart.sh if saved mountpoint is missing (#PSBM-44207)
 - scripts: return non zero if save_mountpoint() fails (#PSBM-44207)
 - scripts: remove bogus command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - scripts: detect EOF on read in a usual way in systemd-autofs-restart.sh (#PSBM-44207)

* Mon Jun 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.35
 - mount: don't add a separate entry for each enabled file systems (#PSBM-47221)

* Mon Jun 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.34
 - scripts: restart all systemd automount services (#PSBM-46672)

* Sat Jun 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.33
 - sk-unix: Fix path resolving for sockets with abs symlinks in paths
 - util: Add cr_set_root/cr_restore_root helpers

* Thu Jun 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.32
 - zdtm/ptrace_sig: don't print from signal handlers (#PSBM-47772)
 - test: file_locks01 -- Test for dev change if only env is set (#PSBM-47714)
 - test: fanotify00 -- Test for device change if only env set
 - test: static, fanotify00 -- Don't compare @s_dev in test (#PSBM-47667)

* Fri May 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.31
 - spfs: do not treat existent file as error in create_reg_file
 - seize: Take --timeout option into account when freezing processes (#PSBM-47539 #PSBM-47538)
 - mount: create a temporary mount to restore shared and master groups (#PSBM-47508)
 - build: Don't forget to relink arch builtins on change
 - scripts: spfs-release-replace.sh introduced
 - Revert "scripts: spfs-release-replace.sh introduced"
 - scripts: spfs-release-replace.sh introduced
 - scripts: call readlink in CT context in systemd-autofs-restart.sh
 - scripts: single style for command substitution in systemd-autofs-restart.sh (#PSBM-44207)
 - tty: Don't forget to unblock tty peers
 - tty: Save @flags unconditionaly for consistency
 - zdtm: check in-flight data in ttys
 - tty: Write unread pty buffers on post dump stage (#PSBM-41399)

* Tue May 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.30
 - criu: don't interrupt do_new_mount() after appling mount options (#PSBM-47489)

* Tue May 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.29
 - aio: Consider AIO pages as "should be dumped" (#PSBM-47489)
 - test/sockets: add test for shut down stream unix sockets (#PSBM-47023)
 - sk-unix: ignore shutdown mismatch in unix sockets
 - scripts: fix strings comparison in systemd-autofs-restart.sh

* Tue May 24 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.28
 - net/sysctl: zero-init stable_secret strings (#PSBM-30942)
 - net/sysctl: remove excess type conversions for sysctl_entry.type
 - net/sysctl: silence read error in case of CTL_FLAGS_READ_EIO_SKIP
 - zdtm/net/ipv6: add test for string stable_secret
 - sysctl: fix allocation for array of pointers
 - zdtm/net/ipv6: add test for confs
 - zdtm/net/ipv6: add devconfs6 and rand_range6
 - zdtm/net/ipv6: allow inacurate match for mldvX_unsolicited_report_interval
 - zdtm/net/ipv4: split save_and_set and check_and_restore
 - zdtm/net/ipv4: replace rand limits with rand ranges
 - zdtm/net/ipv4: make save_and_set and check_and_restore reusable
 - restore/net/ipv6: net device and def/all configuration
 - dump/net/ipv6: net device and def/all configuration
 - net/ipv6: add devconfs6 array to store config option's names
 - net/ipv6/protobuf: add device config options for ipv6
 - net/ipv4: add net_conf_op to reuse for ipv6
 - protobuf: add SysctlEntry for ipv4/ipv6 sysctl confs or some others
 - sysctl: add CTL_FLAGS_HAS to mark successful sysctl_op request
 - zdtm/net/ipv4: rename devconfs4 and rand_limit4 and dir4
 - net/ipv4: suffix devconfs with "4"
 - net/ipv4: add new sysctls
 - pcs7: criu: spfs -- Fixup various nits for NFS sake

* Wed May 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.27
 - pcs7: nfs: build -- Add install of spfs-change-mode.sh and nfs-ports-allow.sh
 - pcs7: mounts: mount spfs instead of NFSv3 and NFSv4 (#PSBM-26967)
 - pcs7: mount: add support for NFSv4
 - pcs7: protobuf/mnt.proto: NFSv4 type added
 - pcs7: mount: add support for NFS
 - pcs7: protobuf/mnt.proto: NFS type added
 - pcs7: mount: add support for SUNRPC Pipefs
 - pcs7: protobuf/mnt.proto: RPC Pipefs type added
 - pcs7: scripts: allow-nfs-ports.sh added
 - pcs7: action-scripts: ACT_POST_NET_LOCK stage added
 - pcs7: scripts: spfs-change-mode.sh added
 - pcs7: action scripts: set spfs environment in run_scripts
 - pcs7: regular files: create temporary spfs file if marked as unreachable
 - pcs7: spfs: delayed mounts facility introduced
 - pcs7: cr-restore: declare SPFS_MNGR_SK service fd
 - pcs7: regular files: protobuf "unreachable" field introduced
 - pcs7: filemap: collect mapped file fs type
 - pcs7: reg_file_entry: add "mode" variable
 - Add requirement for spfs package

* Wed May 18 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.26
 - pcs7: cgroup: Fix early update of @dir_name in rewrite_cgsets (#PSBM-46987)
 - plugins: Initialize plugins control by default

* Tue May 17 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.25
 - pcs7: mount: add support for external block devices (#PSBM-39381)

* Fri May 13 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.24
 - pcs7: aio: Fix mmap retval analysing

* Wed May 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.23
 - pcs7: aio: Don't fail if kernel does not support aio wait (#PSBM-42488)
 - pcs7: Wait aio pending requests (#PSBM-42488)

* Wed May 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.22
 - mount: create a clean mount only if a sub directory is bind-mounted (#PSBM-46908)
 - mount: dump a file system only if a mount point isn't overmounted (#PSBM-46908)
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46908)
 - Revert "mount: dump a file system only if a mount point isn't overmounted"
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere"

* Tue May 10 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.21
 - scripts: fix mountinfo parsing in systemd-autofs-restart.sh (#PSBM-46889)

* Fri May 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.20
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46732 #PSBM-46662)
 - mount: remove an extra condition from mounts_equal()
 - mount: handle a case when parent and child mounts in the same directory
 - mount: dump a file system only if a mount point isn't overmounted
 - Revert "mount: don't overmount a mount if it should be bind-mounted
somewhere" (#PSBM-46732)
 - autofs: support of "hidden" catatonic mounts (#PSBM-46572)
 - autofs: rework pipe search logic a bit
 - build: Add ability to generate gprof output

* Thu May 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.19
 - autofs: support of "hidden" catatonic mounts (#PSBM-46572)
 - autofs: rework pipe search logic a bit
 - build: Add ability to generate gprof output

* Wed May 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.18
 - pcs7: scripts -- Make sure -1 pid is not passed (#PSBM-46572)

* Wed May 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.17
 - pcs7: Increase the number of files limit (#PSBM-46761)

* Mon May 02 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.16
 - scripts: do not use stat to discover fs type in systemd-autofs-restart.sh (#PSBM-46756)

* Fri Apr 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.15
 - scripts: save and restore target mount for autofs service (#PSBM-46672)

* Fri Apr 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.14
 - mount: don't overmount a mount if it should be bind-mounted somewhere (#PSBM-46662)

* Thu Apr 28 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.13
 - pcs7: Dump only known controllers (#PSBM-46382)
 - Revert "cg: Add ability to dump predefined controllers only"

* Wed Apr 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.12
 - Revert "pcs7: Increase the number of files limit"
 - criu: dump filemap as soon as possible (#PSBM-46355)

* Wed Apr 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.11
 - autofs: collect new pipe fd as used (#PSBM-46601)

* Wed Apr 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.10
 - autofs: do not create dentries for indirect mount on bind-mounts (#PSBM-46572)

* Sat Apr 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.9
 - pcs7: Increase the number of files limit (#PSBM-46355)
 - build: install -- Don't forget to init DESTDIR
 - scripts: fix typo in binary path in systemd-autofs-restart.sh
 - restore: Wait for userns being prepared before moving into cgroups (v3)
 - Revert "restore: Wait for userns being prepared before moving into cgroups
(v2)"
 - cg: Add ability to dump predefined controllers only (#PSBM-46382)

* Thu Apr 21 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.8
 - scripts: join pid namespace in systemd-autofs-restart.sh (#PSBM-46470)
 - files: try to change fsuid only if linkat() failed (#PSBM-46201)
 - criu: tty -- Restore tty params synchronously (#PSBM-46382)

* Thu Apr 21 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.7
 - restore: Wait for userns being prepared before moving into cgroups (v2) (#PSBM-46360)
 - Revert "restore: Wait for userns being prepared before moving into cgroups"

* Wed Apr 20 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.6
 - autofs: use temporary value for virtual pgrp on dump
 - restore: Wait for userns being prepared before moving into cgroups (#PSBM-46360)

* Tue Apr 19 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.5
 - files: Correctly handle tasks with no open file descriptors (#PSBM-46269)

* Fri Apr 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.4
 - autofs: install -- Fix libexec prefix (#PSBM-46249)
 - autofs: install -- Ship scripts/systemd-autofs-restart.sh (#PSBM-46249)

* Fri Apr 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.3
 - autofs: install -- Ship scripts/systemd-autofs-restart.sh (#PSBM-46249)
 - autofs: install -- Ship {_libexecdir}

* Thu Apr 14 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.1.0.1
 - pcs7: Update Makefile.local
 - criu: action-scripts -- Don't access @root_item_pid if not present
 - zdtm: check the mem_dirty_track if --pre or --snap is set (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - ppc64le: fix build with UFFD (Pavel Emelyanov <xemul@virtuozzo.com>)
 - Fix compilation of action-scripts.c (Pavel Emelyanov <xemul@virtuozzo.com>)
 - kdat: Remove tcp_max_rshare (Pavel Emelyanov <xemul@virtuozzo.com>)
 - tcp: Send as much as possible (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: Fix join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - sk: handle erorors of lseek (Pavel Emelyanov <xemul@virtuozzo.com>)
 - util: don't leak a socket (Pavel Emelyanov <xemul@virtuozzo.com>)
 - namespaces: don't leak memory on error paths (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: set NS_PID environment variable before "post-resume" hook (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - scripts: systemd-autofs-restart.sh added (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: Add export of sublevels and extra (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - build: compel -- Drop double targeting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: "post-resume" hook introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - criu: opts -- Shuffle init_opts order (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: Drop config.h from deps (Pavel Emelyanov <xemul@virtuozzo.com>)
 - ns: Options join-ns and unshare are conflicting (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: Initial commit for standalone tool (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - compel: piegen -- Introduce actions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @arch option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - compel: piegen -- Add @uapi-dir option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns zdtm test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - join-ns: perform join_namespace according to join-ns opts (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - join-ns: add join-ns option to criu CLI and RPC (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd: add handling of zero pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: introduce uffd_handle_page (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: increment uffd_copied_pages only in one place (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move the code out of the 'main' function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: make some variable static global (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - uffd.c: move code into subfunctions (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: remove unused variable vma_size (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked opts in autofs_mount (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked info in autofs_mount on error path (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: free leaked AutofsEntry in autofs_dump_entry (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: do not close NULL image (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: remove handling of VDSO pages (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: do not treat VDSO pages as lazy (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd: Fix pr_debug format for vma start (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix device id modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: fix device id printf modifier on error path in autofs_mnt_open (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - autofs: do not treat old kernel as error in autofs_parse() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: include limit.h before auto_fs.h (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: fix build on Fedora 22 (Pavel Emelyanov <xemul@virtuozzo.com>)
 - uffd.c: do not call unneeded functions (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - cr-restore: move add_ns_shared_cb declaration to include/namespaces.h (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - Fix userfaultfd code with newer compilers (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - check: "autofs" feature added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - zdtm.py: create "dev/autofs" root contruction (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: add autofs test (Pavel Emelyanov <xemul@virtuozzo.com>)
 - mount: create target directory for AutoFS indirect mounts. (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: restore stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: declare ioctl helpers and constants (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pipes: export collect_one_pipe_ops() helper (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new dup_fdinfo() and dup_fle() helpers introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - files: new "used" files list introduced (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - autofs: dump fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - autofs: parse fsinfo stage introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf: autofs entry introduced (Pavel Emelyanov <xemul@virtuozzo.com>)
 - devices: add support for /dev/autofs (Pavel Emelyanov <xemul@virtuozzo.com>)
 - protobuf/mnt.proto: AutoFS type added (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Check private remount error code (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Define UNSHARE_MOUNT_PROC constant (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: try to find a free pid between busy pids (v2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: use rbtree to find a specified pid (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: prepare to store all pid-s in rb-tree (v3) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - pstree: split alloc_pstree_helper (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pstree: move state from pstree_item to pid (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 2) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Try to include userfaultfd with criu (part 1) (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Remove static from prepare_task_entries function (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - Make skip_pages function available criu-wide (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - unshare: Support pidns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Mount new proc (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Support mntns (Pavel Emelyanov <xemul@virtuozzo.com>)
 - unshare: Preparations and CLI option (Pavel Emelyanov <xemul@virtuozzo.com>)
 - pcs7: Extend version output via local build (#PSBM-45009)
 - build: criu -- Don't forget to cleanup arch directory
 - cg: Add rollback in get_cg_set (#PSBM-45553)
 - cg: Add rollback for add_cgroup (#PSBM-45553)
 - cg: Fix use-after-free in put_ctls (#PSBM-45553)
 - pie: open_detach_mount -- Use pr_perror for regular build
 - util: return aligned pointers from shmalloc()
 - Makefile: drop 'rebuild' from help message
 - nmk: build.mk -- Add @libso-y helper
 - nmk: build.mk -- Add @hostprogs-y mode
 - nmk: msg.mk -- Add host- messages
 - nmk: build.mk -- Shrink gen-cc-rules
 - nmk: build.mk -- Drop any-match rule
 - nmk: build.mk -- Fix deps for target mode
 - nmk: build.mk -- Squash gen-rule-x into gen-cc-rules
 - nmk: Drop rules.mk
 - nmk: rules.mk -- Fix AFLAGS typo
 - tests: remap_dead_pid[_root] -- Run in namespace only
 - log: add gnu-styled output to stdout
 - build: images -- Add missing cleanups
 - namespaces: zero struct ns_id when allocating
 - criu: use strsignal to describe kill reason
 - nmk: build.mk -- Fix ar rule for external libs
 - nmk: build.mk -- Make process depend on Makefile itself
 - nmk: build.mk -- On cleanup use cleanup-y only
 - nmk: utils.mk -- Add cleanify helper
 - nmk: utils.mk -- Drop redundant spaces
 - nmk: build.mk -- Fix typo in gen-ar-target-rule
 - nmk: rules.mk -- Add per-obj flags
 - nmk: build.mk -- Drop unused objlist target
 - nmk: rules.mk -- Drop @CFLAGS_ and @ASFLAGS_ but add ability to bring them
via param
 - build: add mrproper target
 - build/nmk: add mrproper-y
 - build: Drop @images
 - nmk: scritps/macro.mk -- Enhance gen-built-in
 - x86/restorer: drop unused struct pt_regs
 - types: Remove setns override with sys_setns
 - rst-malloc: adjust free_bytes in rst_mem_align_cpos
 - netfilter: add -n to iptables and ip6tables calls
 - build: docs -- Use autogenerated footer
 - pstree: try to find a free pid between busy pids (v2)
 - pstree: use rbtree to find a specified pid (v3)
 - pstree: prepare to store all pid-s in rb-tree (v3)
 - pstree: split alloc_pstree_helper
 - pstree: move state from pstree_item to pid
 - criu: seize -- Don't left dangling @processes_to_wait_pids pointer
 - libnetlink: back port a fix for nlattr_parse()
 - netlink: Use nlattr instead of rtattr
 - criu: pstree_switch_state -- Fix nil deref on error path
 - irmap: use kdev everywere
 - dump: check for conflicts with the dead processes
 - irmap: don't try to dereference a null pointer
 - mounts: handle device numbers in different formats properly
 - criu: Use __NR_memfd_create for testing memfd presence
 - build: Conditionally defined SYS_* constants
 - build: criu -- Don't link with syscalls library
 - mount: don't use a shared mount to get a clean mount
 - mount: master_id should be 0 for new mounts
 - mount: restore a shared group for propagated mounts
 - build: clean up various other bits
 - build: Add verbose message on packages needed for CRIU building
 - build: Unify phony forms usage
 - pre-dump: don't waste time in error cases
 - dump: pre-dump should never kill processes
 - make: Improve tar generation
 - pcs7: Update local version
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)
 - mounts: Skip already bound siblings in propagate_siblings()
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)
 - plugin: Add PRE_DUMP stage into plugins
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)

* Wed Apr 06 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.8
 - pcs7: Extend version output via local build (#PSBM-45009)

* Tue Apr 05 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.7
 - build: criu -- Don't forget to cleanup arch directory
 - cg: Add rollback in get_cg_set (#PSBM-45553)
 - cg: Add rollback for add_cgroup (#PSBM-45553)
 - cg: Fix use-after-free in put_ctls (#PSBM-45553)
 - pie: open_detach_mount -- Use pr_perror for regular build
 - util: return aligned pointers from shmalloc()
 - Makefile: drop 'rebuild' from help message
 - nmk: build.mk -- Add @libso-y helper
 - nmk: build.mk -- Add @hostprogs-y mode
 - nmk: msg.mk -- Add host- messages
 - nmk: build.mk -- Shrink gen-cc-rules
 - nmk: build.mk -- Drop any-match rule
 - nmk: build.mk -- Fix deps for target mode
 - nmk: build.mk -- Squash gen-rule-x into gen-cc-rules
 - nmk: Drop rules.mk
 - nmk: rules.mk -- Fix AFLAGS typo
 - tests: remap_dead_pid[_root] -- Run in namespace only
 - log: add gnu-styled output to stdout
 - build: images -- Add missing cleanups
 - namespaces: zero struct ns_id when allocating
 - criu: use strsignal to describe kill reason
 - nmk: build.mk -- Fix ar rule for external libs
 - nmk: build.mk -- Make process depend on Makefile itself
 - nmk: build.mk -- On cleanup use cleanup-y only
 - nmk: utils.mk -- Add cleanify helper
 - nmk: utils.mk -- Drop redundant spaces
 - nmk: build.mk -- Fix typo in gen-ar-target-rule
 - nmk: rules.mk -- Add per-obj flags
 - nmk: build.mk -- Drop unused objlist target
 - nmk: rules.mk -- Drop @CFLAGS_ and @ASFLAGS_ but add ability to bring them
via param
 - build: add mrproper target
 - build/nmk: add mrproper-y
 - build: Drop @images
 - nmk: scritps/macro.mk -- Enhance gen-built-in
 - x86/restorer: drop unused struct pt_regs
 - types: Remove setns override with sys_setns

* Fri Mar 25 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.6
 - rst-malloc: adjust free_bytes in rst_mem_align_cpos

* Wed Mar 23 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.5
 - netfilter: add -n to iptables and ip6tables calls
 - build: docs -- Use autogenerated footer
 - pstree: try to find a free pid between busy pids (v2)
 - pstree: use rbtree to find a specified pid (v3)
 - pstree: prepare to store all pid-s in rb-tree (v3)
 - pstree: split alloc_pstree_helper
 - pstree: move state from pstree_item to pid

* Thu Mar 17 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.4
 - criu: seize -- Don't left dangling @processes_to_wait_pids pointer

* Wed Mar 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.3
 - libnetlink: back port a fix for nlattr_parse()
 - netlink: Use nlattr instead of rtattr

* Wed Mar 16 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.2
 - criu: pstree_switch_state -- Fix nil deref on error path

* Tue Mar 15 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 2.0.0.1
 - irmap: use kdev everywere
 - dump: check for conflicts with the dead processes
 - irmap: don't try to dereference a null pointer
 - mounts: handle device numbers in different formats properly
 - criu: Use __NR_memfd_create for testing memfd presence
 - build: Conditionally defined SYS_* constants
 - build: criu -- Don't link with syscalls library
 - mount: don't use a shared mount to get a clean mount
 - mount: master_id should be 0 for new mounts
 - mount: restore a shared group for propagated mounts
 - build: clean up various other bits
 - build: Add verbose message on packages needed for CRIU building
 - build: Unify phony forms usage
 - pre-dump: don't waste time in error cases
 - dump: pre-dump should never kill processes
 - make: Improve tar generation
 - pcs7: Update local version
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)
 - mounts: Skip already bound siblings in propagate_siblings()
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)
 - plugin: Add PRE_DUMP stage into plugins
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)
 - Add dep for libnl3-devel

* Tue Mar 01 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.15
 - dump: don't call rollback actions from a signal handler (#PSBM-44371)

* Wed Feb 17 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.14
 - mounts: Skip already bound siblings in propagate_siblings()

* Thu Feb 11 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.13
 - PCS7: cgroup: Always restore predefined VE props (#PSBM-41406)

* Wed Feb 10 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.12
 - files-reg: Fix rm_parent_dirs() counter
 - files-reg: Delete ghost file numeric index
 - files-reg: Revert: Make try_clean_ghost() use struct ghost_file ptr
 - zdtm: Disable unlink_regular00 by default
 - zdtm: Add unlink_regular00 test
 - files-reg: Recreate deleted parent directories during restore of ghost file
 - files-reg: Create ghost files in first existing parent directory
 - files-reg: Move applying ghost file metadata from create_ghost() to separate
function
 - files-reg: Make try_clean_ghost() use struct ghost_file ptr
 - files-reg: Refactor create_ghost()

* Tue Feb 09 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.11
 - seize: detach from external processes before killing dumped processes (v2) (#PSBM-43795)

* Thu Feb 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.10
 - mount: separate private remount conditions for external and non-external (#PSBM-42829)

* Thu Feb 04 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.9
 - plugin: Add PRE_DUMP stage into plugins

* Fri Jan 29 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.8
 - dump: save master_id for the root mount (#PSBM-43260)
 - crtools: describe the inherit-fd option
 - parasite: Don't left memfd opened inside dumpee (#PSBM-43199)

* Wed Jan 27 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.7
 - gitignore: ignore some more generated testcases (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - seize: remove extra \n from the error message (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - seize: don't detach from a task if a freezer cgroup is set (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - seize: detach from all processes before waiting the root task (Pavel
Emelyanov <xemul@virtuozzo.com>) (#PSBM-43089)
 - zdtm: Add suid flag to binfmt_misc test (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - ns: Remove __rst_new_ns_id (Pavel Emelyanov <xemul@virtuozzo.com>)
 - fds: Remove unused arg from close_old_fds() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - tmpfs: don't try to dump mountpoint at 0 fd (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - criu [PATCH] post-setup-namespaces (Pavel Emelyanov <xemul@virtuozzo.com>)
 - service: add support for the --external option (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - dump: add some stray newlines to pr_infos (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - binfmt_misc: Make debug printed using pr_debug() (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: Add binfmt_misc test (Pavel Emelyanov <xemul@virtuozzo.com>)

* Tue Jan 19 2016 Cyrill Gorcunov <gorcunov@virtuozzo.com> 1.8.0.6
 - scripts: post-setup-namespaces
 - seize: remove extra \n from the error message (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: don't detach from a task if a freezer cgroup is set (Cyrill Gorcunov
<gorcunov@openvz.org>)
 - seize: detach from all processes before waiting the root task (Cyrill
Gorcunov <gorcunov@openvz.org>) (#PSBM-43089)
 - make: Add Makefile.version (Cyrill Gorcunov <gorcunov@openvz.org>)
 - ppc64: introduce CPU feature checking operations (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm/test: Fix live/static/netns-nf dependency (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm.py: Add optional dependency support (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - mem: Handle the case when kernel doesn't support dirty track reset (Pavel
Emelyanov <xemul@virtuozzo.com>)
 - kdat: Handle pagemaps with zeroed pfns (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: Use /usr/bin/diff instead of /bin/diff (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - remap: fix dead pid remap of /proc/<pid> (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - test/session00: close a signal pipe in all processes (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - fix compilation after previous commit (Pavel Emelyanov <xemul@virtuozzo.com>)
 - util: Optimize vaddr_to_pfn (Pavel Emelyanov <xemul@virtuozzo.com>)
 - zdtm/chroot: wait when a child closes a descriptor (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - make: update target to measure code coverage (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm/session00: wait when a child closes fd (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - zdtm: Correct syscall numbers for fanotify00 testcase (Pavel Emelyanov
<xemul@virtuozzo.com>)
 - define macro for stack alignment (Pavel Emelyanov <xemul@virtuozzo.com>)
 - tty: use PRIx64 to print dev_t (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Force per-test logs if report is requested (Pavel Emelyanov
<xemul@parallels.com>)
 - arch: define the readlinkat syscall for all architectures (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Align stack pointer for arm64 (Pavel Emelyanov <xemul@parallels.com>)
 - restorer: Update RESTORE_ALIGN_STACK for arm64 (Pavel Emelyanov
<xemul@parallels.com>)
 - restore: Align stack to 16 bytes for arm64 (Pavel Emelyanov
<xemul@parallels.com>)
 - arm: Fix wrong system call number (Pavel Emelyanov <xemul@parallels.com>)
 - criu-log: introduce print_once (Pavel Emelyanov <xemul@parallels.com>)
 - kerndat: do not report errors on feature test (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: write an inventory image after dumping all processes (Pavel Emelyanov
<xemul@parallels.com>)
 - test: add a new test to check external terminals (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: add a new test to check inherited tty-s (Pavel Emelyanov
<xemul@parallels.com>)
 - tty: allow to dump and restore external terminals (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - crtools: add ability to set list of external resources (Pavel Emelyanov
<xemul@parallels.com>)
 - tty: use a pair of dev and rdev to identify a terminal (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: add a script to check inherit file descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - mnt: Allow for external mounts to be fsroot ones (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: unfreeze test processes before killing them (Pavel Emelyanov
<xemul@parallels.com>)
 - syscall: use a correct type for timer_t (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: Fix spelling error in a error message (Pavel Emelyanov
<xemul@parallels.com>)
 - arm: proc_parse -- Fix u64 format warnings (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: change the root master_id on restore only (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-check: add logiuid feature (Pavel Emelyanov <xemul@parallels.com>)
 - criu: fetch kdat.has_loginuid value on C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: add has_loginuid to kerndat_s (Pavel Emelyanov
<xemul@parallels.com>)
 - creds: restore -- Honor rst_mem_alloc rules (Pavel Emelyanov
<xemul@parallels.com>)
 - tcp: Try harder to restore recv queue (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: When no logs, do not add them to report (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Mark nouser tests as such (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add user mode job (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Fix aio mapping detection (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Check how user-mode works (Pavel Emelyanov <xemul@parallels.com>)
 - parasite: Load code blobs via memfd (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Use smaps path for file (Pavel Emelyanov <xemul@parallels.com>)
 - pagemap-cache: Use greedy mode if pagemap inaccessible (Pavel Emelyanov
<xemul@parallels.com>)
 - vdso: Don't fail if pagemap is not accessbile (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: Dont read prohibited kernel files (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: Read anon shmem dev via maps (Pavel Emelyanov <xemul@parallels.com>)
 - util: Ability to ignore errno when opening proc (Pavel Emelyanov
<xemul@parallels.com>)
 - parasite: Add @pad argument for syscall run (Pavel Emelyanov
<xemul@parallels.com>)
 - proc: Get full file path into handle_vma (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: Remove security (Pavel Emelyanov <xemul@parallels.com>)
 - test: different_creds -- Enhance the testing (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Add ARRAY_SIZE into the header (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: set the dumpable flag after setuid (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if a test class doesn't have ns() and static() (Pavel
Emelyanov <xemul@parallels.com>)
 - test/inhfd: use os.fdopen instead of a home-made class (Pavel Emelyanov
<xemul@parallels.com>)
 - cpt/rst: access and modification time of ghost files (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - creds: dump -- Implement per-thread dump of credentials (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: restore -- Implement per-thread restore of credentials (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: Move proc_status_creds::cap_X at the end of structure (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: Allocate CredsEntry for every thread in core_entry_alloc (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: protobuf -- Move @creds_entry into @thread_core_entry (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - xmalloc: Add xmemdup helper (Pavel Emelyanov <xemul@parallels.com>)
 - arm: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - ppc64: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - x86: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix 'mnt_path' may be used uninitialized in this function (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm_ct: Mount binfmt misc in ct creation (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Mount binfmt misc in run_ct (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: build criu with debuginfo (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/file_locks04: use test_waitsig() to synchronize child and parent (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm/fifo_wronly: wait when a child opens a file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: remove warnings about existent directories (Pavel Emelyanov
<xemul@parallels.com>)
 - binfmt_misc: Skip dumping if it's not virtual (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Test how freeze cgroup works (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/pstree: check return codes (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/pstree: read from a correct file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - test: wait when a prepartion stage will be completed (Pavel Emelyanov
<xemul@parallels.com>)
 - pipe00: when while a child is preparing file descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/socket_close_data01: wait a child before c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/sigpending: wait a child before C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: don't hardcode file names in test soruces (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read10 -- Wait for children to create (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read_10 -- Fix typo in testing opened file descriptor (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm:mntns_open: wait when a child process opens descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/mountpoints: wait when a child process opens descriptors (Pavel
Emelyanov <xemul@parallels.com>)
 - files-reg: fix compilation issues (Pavel Emelyanov <xemul@parallels.com>)
 - mountpoints: don't re-create /dev/null (Pavel Emelyanov
<xemul@parallels.com>)
 - rst: set mode on ghost-files after write (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - dump: add timeout for collecting processes (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: factor out cleanup code into separate functions (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: fix return code in message on pre-dump failure (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: slightly cleanup collect_pstree() exit path. (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-restore: optimize {loginuid,oom_score_adj} restoring (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xsprintf() in resolve_external_mounts() (Pavel Emelyanov
<xemul@parallels.com>)
 - sysfs_parse: use xsprintf() in fixup_aufs_vma_fd() (Pavel Emelyanov
<xemul@parallels.com>)
 - irmap: use xsprintf() in irmap_update_dir() (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroup: use xsprintf() in rewrite_cgsets() (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xstrcat() in attach_option() (Pavel Emelyanov
<xemul@parallels.com>)
 - util: new string helpers introduced (Pavel Emelyanov <xemul@parallels.com>)
 - test: block prctl in seccomp_filter (Pavel Emelyanov <xemul@parallels.com>)
 - pie: move seccomp before creds to avoid resoring them after setuid (Pavel
Emelyanov <xemul@parallels.com>)
 - test: setuid in seccomp_filter test to have it fail (Pavel Emelyanov
<xemul@parallels.com>)
 - ptrace: start tracing processes before restoring creds (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: check shared mounts more carefully (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: do nothing if a root mount isn't slave (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: fix comparing files, maps and mounts (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix compilation after previous commit (Pavel Emelyanov <xemul@parallels.com>)
 - files-reg: restore PR_SET_DUMPABLE flag after setfsuid (Pavel Emelyanov
<xemul@parallels.com>)
 - unix: Fix double restoring of peerless unix sockets, which are peers for
others (Pavel Emelyanov <xemul@parallels.com>)
 - loginuid: save value of loginuid from a target userns (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: don't leak apparmor string in the case of "unconfined" (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: tests should not inherite file descriptors from zdtm.py (Pavel
Emelyanov <xemul@parallels.com>)
 - seize: do not try to detach killed tasks (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Change oom_score_adj score value (Pavel Emelyanov
<xemul@parallels.com>)
 - files: check fd flags after restore (Pavel Emelyanov <xemul@parallels.com>)
 - restore: restore freezer cgroup state (Pavel Emelyanov <xemul@parallels.com>)
 - restore: split finalize_restore into two stages (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroups: save freezer state during dump (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: The 'mems' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'fds' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'ps' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Explore action and stubs (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: bind-mount a test root as slave (Pavel Emelyanov
<xemul@parallels.com>)
 - makefile: use zdtm.py to execute tests (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: compare a set of mounts before and after c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: fix a value of ZDTM_THREAD_BOMB (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't mix tab and spaces (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: collect fds and maps for all test processes (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't take into acount the root master_id (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't remount a slave mount as private when it isn't required (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add loginuid restore test (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: add test for oom_score_adj restore (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: unset loginuid value before creating userns (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: restore loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: dump loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - make: Fix @install-criu target (Pavel Emelyanov <xemul@parallels.com>)
 - test: report actual errno on seccomp prctl failure (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add action for cleaning nsroot (Pavel Emelyanov
<xemul@parallels.com>)
 - Rename cr_opts.ps_port into port (Pavel Emelyanov <xemul@parallels.com>)
 - Introduce the read_into_buffer helper (Pavel Emelyanov <xemul@parallels.com>)
 - seize: don't wory if a cgroup contains some extra tasks (v3) (Pavel Emelyanov
<xemul@parallels.com>)
 - fstype: "mount" callback introduced (Pavel Emelyanov <xemul@parallels.com>)
 - pstree: more pstree-related helpers (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: No parallelizm for group test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add write perms for all bins in test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Fix compilation after previous commit (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Add groups (Pavel Emelyanov <xemul@parallels.com>)
 - freebind: Use different ports (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix deps for group start (Pavel Emelyanov <xemul@parallels.com>)
 - criu: tty: pick only master as a control terminal (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-42093)
 - test: Add inotify02 into the Makefile (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Speed up jenkins test ~60 times (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Fix ipc load/dump for io.BytesIO input/output (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add dump for semaphores (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add handling of msgqueue (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add dump method for shmem pages (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add payload handler for shmem pages (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add payload handler for semaphore images (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add step-by-step execution (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Print out and strace file names (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Print test output on screen when possible (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: catch KeyError instead of ValueError for sets (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix a race between restoring namespaces and file mappings (v2) (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to set ROOT_FD_OFF (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Fix casts for fixed and sfixed types (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: get_freezer_state -- Relax stack (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: set a type argument for mknod (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if uns isn't in run_flavs (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: stop doing anything if populate_mnt_ns() failed (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't worry if a binfmt_misc image is empty (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Fix CRIT test to skip non-criu images and provide cumulative output
(Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't add dot to a path (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Pretty print vma flags and status (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: umount a temporary mount with MTN_DETACH (Pavel Emelyanov
<xemul@parallels.com>)
 - pagemap-cache: add const-qualifier to pmc's vma (Pavel Emelyanov
<xemul@parallels.com>)
 - page-xfer: fix wrong hole address offset (Pavel Emelyanov
<xemul@parallels.com>)
 - test: Add inotify02 (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix zdtm_test._env data type (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: don't skip erros (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: really skip missing entries in __nonuserns_sysctl_op() (Pavel
Emelyanov <xemul@parallels.com>)
 - criu: x86_32: change stack align to 16 bit on parasite head (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: add the mnt_id feature if a test uses more than one mntns (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm.py: skip the uns flavor if userns isn't suppported (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: add a --lsm-profile flag (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Encode back pretty IP addresses (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Show devices nicely (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add test for crit de/encode correctness (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Run tests in best flavor (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Count skipped tests (Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't rewrite root for external mounts (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41932)
 - unix: Add support for restoring receive queue for unix DGRAM sockets (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add mntns_rw_ro_rw to the test list (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix restoring a bind-mount when its root is overmounted (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: refactor do_bind_mount() (Pavel Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to bind mount a point in a tmp place (Pavel
Emelyanov <xemul@parallels.com>)
 - mnt: Carry run-time device ID in mount_info (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41610)
 - zdtm.py: The groups_test class for running groups (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Generator of groups of tests (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Prepare zdtm_test and flavors for mass test start (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Remove unneeded re-exec (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Factor out ps showing code (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Introduce explicit prepare_namespaces() routine (Pavel Emelyanov
<xemul@parallels.com>)
 - fs: Add binfmt_misc support (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Add socket_close_data01 test (Pavel Emelyanov <xemul@parallels.com>)
 - Update source (Cyrill Gorcunov <gorcunov@gmail.com>)
 - Remove obsoleted patches (Dmitry Mishin <dim@virtuozzo.com>)

* Tue Dec 29 2015 Dmitry Mishin <dim@virtuozzo.com> 1.8.0.3
 - mnt: Allow for external mounts to be fsroot ones (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: unfreeze test processes before killing them (Pavel Emelyanov
<xemul@parallels.com>)
 - syscall: use a correct type for timer_t (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: Fix spelling error in a error message (Pavel Emelyanov
<xemul@parallels.com>)
 - arm: proc_parse -- Fix u64 format warnings (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: change the root master_id on restore only (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-check: add logiuid feature (Pavel Emelyanov <xemul@parallels.com>)
 - criu: fetch kdat.has_loginuid value on C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: add has_loginuid to kerndat_s (Pavel Emelyanov
<xemul@parallels.com>)
 - creds: restore -- Honor rst_mem_alloc rules (Pavel Emelyanov
<xemul@parallels.com>)
 - tcp: Try harder to restore recv queue (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: When no logs, do not add them to report (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Mark nouser tests as such (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add user mode job (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Fix aio mapping detection (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Check how user-mode works (Pavel Emelyanov <xemul@parallels.com>)
 - parasite: Load code blobs via memfd (Pavel Emelyanov <xemul@parallels.com>)
 - proc: Use smaps path for file (Pavel Emelyanov <xemul@parallels.com>)
 - pagemap-cache: Use greedy mode if pagemap inaccessible (Pavel Emelyanov
<xemul@parallels.com>)
 - vdso: Don't fail if pagemap is not accessbile (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: Dont read prohibited kernel files (Pavel Emelyanov
<xemul@parallels.com>)
 - kerndat: Read anon shmem dev via maps (Pavel Emelyanov <xemul@parallels.com>)
 - util: Ability to ignore errno when opening proc (Pavel Emelyanov
<xemul@parallels.com>)
 - parasite: Add @pad argument for syscall run (Pavel Emelyanov
<xemul@parallels.com>)
 - proc: Get full file path into handle_vma (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: Remove security (Pavel Emelyanov <xemul@parallels.com>)
 - test: different_creds -- Enhance the testing (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Add ARRAY_SIZE into the header (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: set the dumpable flag after setuid (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if a test class doesn't have ns() and static() (Pavel
Emelyanov <xemul@parallels.com>)
 - test/inhfd: use os.fdopen instead of a home-made class (Pavel Emelyanov
<xemul@parallels.com>)
 - cpt/rst: access and modification time of ghost files (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - creds: dump -- Implement per-thread dump of credentials (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: restore -- Implement per-thread restore of credentials (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: Move proc_status_creds::cap_X at the end of structure (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - creds: Allocate CredsEntry for every thread in core_entry_alloc (Pavel
Emelyanov <xemul@parallels.com>)
 - creds: protobuf -- Move @creds_entry into @thread_core_entry (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41416)
 - xmalloc: Add xmemdup helper (Pavel Emelyanov <xemul@parallels.com>)
 - arm: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - ppc64: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - x86: syscalls -- Wire in sys_setgroups (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix 'mnt_path' may be used uninitialized in this function (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm_ct: Mount binfmt misc in ct creation (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Mount binfmt misc in run_ct (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: build criu with debuginfo (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/file_locks04: use test_waitsig() to synchronize child and parent (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm/fifo_wronly: wait when a child opens a file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: remove warnings about existent directories (Pavel Emelyanov
<xemul@parallels.com>)
 - binfmt_misc: Skip dumping if it's not virtual (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Test how freeze cgroup works (v2) (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/pstree: check return codes (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm/pstree: read from a correct file descriptor (Pavel Emelyanov
<xemul@parallels.com>)
 - test: wait when a prepartion stage will be completed (Pavel Emelyanov
<xemul@parallels.com>)
 - pipe00: when while a child is preparing file descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/socket_close_data01: wait a child before c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/sigpending: wait a child before C/R (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: don't hardcode file names in test soruces (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read10 -- Wait for children to create (Pavel Emelyanov
<xemul@parallels.com>)
 - test: write_read_10 -- Fix typo in testing opened file descriptor (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm:mntns_open: wait when a child process opens descriptors (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm/mountpoints: wait when a child process opens descriptors (Pavel
Emelyanov <xemul@parallels.com>)
 - files-reg: fix compilation issues (Pavel Emelyanov <xemul@parallels.com>)
 - mountpoints: don't re-create /dev/null (Pavel Emelyanov
<xemul@parallels.com>)
 - rst: set mode on ghost-files after write (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41401)
 - dump: add timeout for collecting processes (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: factor out cleanup code into separate functions (Pavel Emelyanov
<xemul@parallels.com>)
 - dump: fix return code in message on pre-dump failure (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: slightly cleanup collect_pstree() exit path. (Pavel Emelyanov
<xemul@parallels.com>)
 - cr-restore: optimize {loginuid,oom_score_adj} restoring (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xsprintf() in resolve_external_mounts() (Pavel Emelyanov
<xemul@parallels.com>)
 - sysfs_parse: use xsprintf() in fixup_aufs_vma_fd() (Pavel Emelyanov
<xemul@parallels.com>)
 - irmap: use xsprintf() in irmap_update_dir() (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroup: use xsprintf() in rewrite_cgsets() (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: use xstrcat() in attach_option() (Pavel Emelyanov
<xemul@parallels.com>)
 - util: new string helpers introduced (Pavel Emelyanov <xemul@parallels.com>)
 - test: block prctl in seccomp_filter (Pavel Emelyanov <xemul@parallels.com>)
 - pie: move seccomp before creds to avoid resoring them after setuid (Pavel
Emelyanov <xemul@parallels.com>)
 - test: setuid in seccomp_filter test to have it fail (Pavel Emelyanov
<xemul@parallels.com>)
 - ptrace: start tracing processes before restoring creds (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: check shared mounts more carefully (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: do nothing if a root mount isn't slave (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: fix comparing files, maps and mounts (Pavel Emelyanov
<xemul@parallels.com>)
 - Fix compilation after previous commit (Pavel Emelyanov <xemul@parallels.com>)
 - files-reg: restore PR_SET_DUMPABLE flag after setfsuid (Pavel Emelyanov
<xemul@parallels.com>)
 - unix: Fix double restoring of peerless unix sockets, which are peers for
others (Pavel Emelyanov <xemul@parallels.com>)
 - loginuid: save value of loginuid from a target userns (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: don't leak apparmor string in the case of "unconfined" (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: tests should not inherite file descriptors from zdtm.py (Pavel
Emelyanov <xemul@parallels.com>)
 - seize: do not try to detach killed tasks (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Change oom_score_adj score value (Pavel Emelyanov
<xemul@parallels.com>)
 - files: check fd flags after restore (Pavel Emelyanov <xemul@parallels.com>)
 - restore: restore freezer cgroup state (Pavel Emelyanov <xemul@parallels.com>)
 - restore: split finalize_restore into two stages (Pavel Emelyanov
<xemul@parallels.com>)
 - cgroups: save freezer state during dump (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: The 'mems' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'fds' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: The 'ps' explorer (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Explore action and stubs (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: bind-mount a test root as slave (Pavel Emelyanov
<xemul@parallels.com>)
 - makefile: use zdtm.py to execute tests (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: compare a set of mounts before and after c/r (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: fix a value of ZDTM_THREAD_BOMB (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't mix tab and spaces (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: collect fds and maps for all test processes (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't take into acount the root master_id (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't remount a slave mount as private when it isn't required (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add loginuid restore test (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: add test for oom_score_adj restore (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: unset loginuid value before creating userns (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: restore loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - criu: dump loginuid & oom_score_adj values (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41993)
 - make: Fix @install-criu target (Pavel Emelyanov <xemul@parallels.com>)
 - test: report actual errno on seccomp prctl failure (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add action for cleaning nsroot (Pavel Emelyanov
<xemul@parallels.com>)
 - Rename cr_opts.ps_port into port (Pavel Emelyanov <xemul@parallels.com>)
 - Introduce the read_into_buffer helper (Pavel Emelyanov <xemul@parallels.com>)
 - seize: don't wory if a cgroup contains some extra tasks (v3) (Pavel Emelyanov
<xemul@parallels.com>)
 - fstype: "mount" callback introduced (Pavel Emelyanov <xemul@parallels.com>)
 - pstree: more pstree-related helpers (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: No parallelizm for group test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add write perms for all bins in test (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Fix compilation after previous commit (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Add groups (Pavel Emelyanov <xemul@parallels.com>)
 - freebind: Use different ports (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix deps for group start (Pavel Emelyanov <xemul@parallels.com>)
 - criu: tty: pick only master as a control terminal (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-42093)
 - test: Add inotify02 into the Makefile (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Speed up jenkins test ~60 times (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Fix ipc load/dump for io.BytesIO input/output (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add dump for semaphores (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add handling of msgqueue (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add dump method for shmem pages (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Add payload handler for shmem pages (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Add payload handler for semaphore images (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Add step-by-step execution (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Print out and strace file names (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Print test output on screen when possible (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: catch KeyError instead of ValueError for sets (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix a race between restoring namespaces and file mappings (v2) (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to set ROOT_FD_OFF (Pavel Emelyanov
<xemul@parallels.com>)
 - crit: Fix casts for fixed and sfixed types (Pavel Emelyanov
<xemul@parallels.com>)
 - seize: get_freezer_state -- Relax stack (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.sh: set a type argument for mknod (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: don't worry if uns isn't in run_flavs (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: stop doing anything if populate_mnt_ns() failed (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: don't worry if a binfmt_misc image is empty (Pavel Emelyanov
<xemul@parallels.com>)
 - jenkins: Fix CRIT test to skip non-criu images and provide cumulative output
(Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't add dot to a path (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Pretty print vma flags and status (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: umount a temporary mount with MTN_DETACH (Pavel Emelyanov
<xemul@parallels.com>)
 - pagemap-cache: add const-qualifier to pmc's vma (Pavel Emelyanov
<xemul@parallels.com>)
 - page-xfer: fix wrong hole address offset (Pavel Emelyanov
<xemul@parallels.com>)
 - test: Add inotify02 (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Fix zdtm_test._env data type (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: don't skip erros (Pavel Emelyanov <xemul@parallels.com>)
 - sysctl: really skip missing entries in __nonuserns_sysctl_op() (Pavel
Emelyanov <xemul@parallels.com>)
 - criu: x86_32: change stack align to 16 bit on parasite head (Pavel Emelyanov
<xemul@parallels.com>)
 - criu: add the mnt_id feature if a test uses more than one mntns (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm.py: skip the uns flavor if userns isn't suppported (Pavel Emelyanov
<xemul@parallels.com>)
 - lsm: add a --lsm-profile flag (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Encode back pretty IP addresses (Pavel Emelyanov <xemul@parallels.com>)
 - crit: Show devices nicely (Pavel Emelyanov <xemul@parallels.com>)
 - jenkins: Add test for crit de/encode correctness (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Run tests in best flavor (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Count skipped tests (Pavel Emelyanov <xemul@parallels.com>)
 - mount: don't rewrite root for external mounts (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41932)
 - unix: Add support for restoring receive queue for unix DGRAM sockets (Pavel
Emelyanov <xemul@parallels.com>)
 - zdtm: add mntns_rw_ro_rw to the test list (Pavel Emelyanov
<xemul@parallels.com>)
 - mount: fix restoring a bind-mount when its root is overmounted (Pavel
Emelyanov <xemul@parallels.com>)
 - mount: refactor do_bind_mount() (Pavel Emelyanov <xemul@parallels.com>)
 - mount: pick out a function to bind mount a point in a tmp place (Pavel
Emelyanov <xemul@parallels.com>)
 - mnt: Carry run-time device ID in mount_info (Pavel Emelyanov
<xemul@parallels.com>) (#PSBM-41610)
 - zdtm.py: The groups_test class for running groups (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm.py: Generator of groups of tests (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm.py: Prepare zdtm_test and flavors for mass test start (Pavel Emelyanov
<xemul@parallels.com>)
 - zdtm: Remove unneeded re-exec (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Factor out ps showing code (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Introduce explicit prepare_namespaces() routine (Pavel Emelyanov
<xemul@parallels.com>)
 - fs: Add binfmt_misc support (Pavel Emelyanov <xemul@parallels.com>)
 - zdtm: Add socket_close_data01 test (Pavel Emelyanov <xemul@parallels.com>)
 - fixed repository url
 - Prepare for builds from forked repository

* Wed Dec 23 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-6
- backport 0004-criu-tty-pick-only-master-as-a-control-terminal.patch, #PSBM-42590

* Thu Dec 17 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-5
- backport 0003-seize-don-t-wory-if-a-cgroup-contains-some-extra-tas.patch, #PSBM-42145

* Wed Dec 9 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-4
- backport 0002-mnt-Carry-run-time-device-ID-in-mount_info.patch, #PSBM-41610

* Mon Dec 7 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-3
- backport 0001-mount-dont-rewrite-root-for-external-mounts.patch, #PSBM-41932

* Mon Dec 7 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-2
- Update to 1.8

* Mon Nov 30 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.8-1.rc1
- criu segmentation fault, coredump created, #PSBM-41394

* Mon Nov 16 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-7
- backport 0009-tty-open-all-terminals-with-O_NOCTTY.patch

* Mon Nov 16 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-6
- backport 0008-tty-Restore-controlling-terminal-once-per-session.patch

* Thu Nov 12 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-5
- remove 0008-rst-Re-use-opened-fd-when-restoring-private-mappings.patch

* Wed Nov 11 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-4
- backport 0007-page-server-Fine-grained-corking-control-v3.patch
- backport 0008-rst-Re-use-opened-fd-when-restoring-private-mappings.patch

* Tue Nov 3 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-3
- backport 0006-fsnotify-Add-ability-to-force-resolve-paths-for-watc.patch

* Thu Oct 29 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2-2
- backport 0001-ptrace-don-t-stop-a-process-if-it-was-not-in-the-sto.patch
- backport 0002-bfd-add-breadchr.patch
- backport 0003-proc-read-all-data-from-proc-pid-task-tid-children-v.patch
- backport 0004-proc-parse_children-appens-new-processes-to-a-specif.patch
- backport 0005-seize-don-t-catch-all-processes-from-a-freezer-cgrou.patch

* Wed Oct 28 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.2
- Update to 1.7.2

* Mon Oct 26 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.1-2
- backport 0001-ipc-save-local-user-and-group-id-s-for-ipc-objects.patch
- backport 0002-sk-unix-Fix-typo-in-name-length-estimation.patch

* Fri Oct 23 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7.1
- Update to 1.7.1

* Tue Oct 20 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7-2
- Add criu-d150d6f2-freezer_dont_catch_kernel_threads.patch

* Mon Sep 7 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.7
- Update to 1.7

* Wed Aug 12 2015 Nikita Spiridonov <nspiridonov@odin.com> 1.6.1
- Update to 1.6.1

* Tue Jul 7 2015 Nikita Spiridonov <nspiridonov@odin.com> - 1.6-2
- Rebuild with new protobuf-c package

* Thu Jun 18 2015 Nikita Spiridonov <nspiridonov@odin.com> - 1.6
- Update to 1.6

* Sun Apr 19 2015 Nikita Spiridonov <nspiridonov@odin.com> - 1.5.1-2
- Create python-criu and crit subpackages

* Tue Mar 31 2015 Andrew Vagin <avagin@openvz.org> - 1.5.1
- Update to 1.5.1

* Sat Dec 06 2014 Adrian Reber <adrian@lisas.de> - 1.4-1
- Update to 1.4

* Tue Sep 23 2014 Adrian Reber <adrian@lisas.de> - 1.3.1-1
- Update to 1.3.1 (#1142896)

* Tue Sep 02 2014 Adrian Reber <adrian@lisas.de> - 1.3-1
- Update to 1.3
- Dropped all upstreamed patches
- included pkgconfig file in -devel

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Thu Aug 07 2014 Andrew Vagin <avagin@openvz.org> - 1.2-4
- Include inttypes.h for PRI helpers

* Thu Aug 07 2014 Andrew Vagin <avagin@openvz.org> - 1.2-3
- Rebuilt for https://bugzilla.redhat.com/show_bug.cgi?id=1126751

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Feb 28 2014 Adrian Reber <adrian@lisas.de> - 1.2-1
- Update to 1.2
- Dropped all upstreamed patches

* Tue Feb 04 2014 Adrian Reber <adrian@lisas.de> - 1.1-4
- Create -devel subpackage

* Wed Dec 11 2013 Andrew Vagin <avagin@openvz.org> - 1.0-3
- Fix the epoch of crtools

* Tue Dec 10 2013 Andrew Vagin <avagin@openvz.org> - 1.0-2
- Rename crtools to criu #1034677

* Wed Nov 27 2013 Andrew Vagin <avagin@openvz.org> - 1.0-1
- Update to 1.0

* Thu Oct 24 2013 Andrew Vagin <avagin@openvz.org> - 0.8-1
- Update to 0.8

* Tue Sep 10 2013 Andrew Vagin <avagin@openvz.org> - 0.7-1
- Update to 0.7

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 24 2013 Andrew Vagin <avagin@openvz.org> - 0.6-3
- Delete all kind of -fstack-protector gcc options

* Wed Jul 24 2013 Andrew Vagin <avagin@openvz.org> - 0.6-3
- Added arm macro to ExclusiveArch

* Wed Jul 03 2013 Andrew Vagin <avagin@openvz.org> - 0.6-2
- fix building on ARM
- fix null pointer dereference

* Tue Jul 02 2013 Adrian Reber <adrian@lisas.de> - 0.6-1
- updated to 0.6
- upstream moved binaries to sbin
- using upstream's make install

* Tue May 14 2013 Adrian Reber <adrian@lisas.de> - 0.5-1
- updated to 0.5

* Fri Feb 22 2013 Adrian Reber <adrian@lisas.de> - 0.4-1
- updated to 0.4

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Tue Jan 22 2013 Adrian Reber <adrian@lisas.de> - 0.3-3
- added ExclusiveArch blocker bug

* Fri Jan 18 2013 Adrian Reber <adrian@lisas.de> - 0.3-2
- improved Summary and Description

* Mon Jan 14 2013 Adrian Reber <adrian@lisas.de> - 0.3-1
- updated to 0.3
- fix building Documentation/

* Tue Aug 21 2012 Adrian Reber <adrian@lisas.de> - 0.2-2
- remove macros like %%{__mkdir_p} and %%{__install}
- add comment why it is only x86_64

* Tue Aug 21 2012 Adrian Reber <adrian@lisas.de> - 0.2-1
- initial release
